# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `blas` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

drotg = utils._EngineState._get_symbol('drotg')
drotg.restype = None
drotg.argtypes = (
    utils._BYREF_FLOAT64, # Input/Output, a.
    utils._BYREF_FLOAT64, # Input/Output, b.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_FLOAT64, # Output, s.
)
f06aaf = utils._EngineState._get_symbol('f06aaf')
f06aaf.restype = drotg.restype
f06aaf.argtypes = drotg.argtypes

drotgc = utils._EngineState._get_symbol('f06baf')
drotgc.restype = None
drotgc.argtypes = (
    utils._BYREF_FLOAT64, # Input/Output, a.
    utils._BYREF_FLOAT64, # Input/Output, b.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_FLOAT64, # Output, s.
)

dcsg = utils._EngineState._get_symbol('f06bcf')
dcsg.restype = None
dcsg.argtypes = (
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_FLOAT64, # Output, s.
)

drotj = utils._EngineState._get_symbol('f06bef')
drotj.restype = None
drotj.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_FLOAT64, # Input/Output, x.
    utils._BYREF_FLOAT64, # Input/Output, y.
    utils._BYREF_FLOAT64, # Input/Output, z.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_FLOAT64, # Output, s.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)

drot2 = utils._EngineState._get_symbol('f06bhf')
drot2.restype = None
drot2.argtypes = (
    utils._BYREF_FLOAT64, # Input/Output, x.
    utils._BYREF_FLOAT64, # Input/Output, y.
    utils._BYREF_FLOAT64, # Input/Output, z.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_FLOAT64, # Input, s.
)

ddiv = utils._EngineState._get_symbol('f06blf')
ddiv.restype = utils._EngineFloat64ScalarType.c_type
ddiv.argtypes = (
    utils._BYREF_FLOAT64, # Input, a.
    utils._BYREF_FLOAT64, # Input, b.
    utils._BYREF_LOGICAL, # Output, fail.
)

dnorm = utils._EngineState._get_symbol('f06bmf')
dnorm.restype = utils._EngineFloat64ScalarType.c_type
dnorm.argtypes = (
    utils._BYREF_FLOAT64, # Input, scal.
    utils._BYREF_FLOAT64, # Input, ssq.
)

dpyth = utils._EngineState._get_symbol('f06bnf')
dpyth.restype = utils._EngineFloat64ScalarType.c_type
dpyth.argtypes = (
    utils._BYREF_FLOAT64, # Input, a.
    utils._BYREF_FLOAT64, # Input, b.
)

deig2 = utils._EngineState._get_symbol('f06bpf')
deig2.restype = utils._EngineFloat64ScalarType.c_type
deig2.argtypes = (
    utils._BYREF_FLOAT64, # Input, a.
    utils._BYREF_FLOAT64, # Input, b.
    utils._BYREF_FLOAT64, # Input, c.
)

zrotgc = utils._EngineState._get_symbol('f06caf')
zrotgc.restype = None
zrotgc.argtypes = (
    utils._BYREF_COMPLEX128, # Input/Output, a.
    utils._BYREF_COMPLEX128, # Input/Output, b.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_COMPLEX128, # Output, s.
)

zrotgs = utils._EngineState._get_symbol('f06cbf')
zrotgs.restype = None
zrotgs.argtypes = (
    utils._BYREF_COMPLEX128, # Input/Output, a.
    utils._BYREF_COMPLEX128, # Input/Output, b.
    utils._BYREF_COMPLEX128, # Output, c.
    utils._BYREF_FLOAT64, # Output, s.
)

zcsg = utils._EngineState._get_symbol('f06ccf')
zcsg.restype = None
zcsg.argtypes = (
    utils._BYREF_COMPLEX128, # Input, t.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_COMPLEX128, # Output, s.
)

zcsgs = utils._EngineState._get_symbol('f06cdf')
zcsgs.restype = None
zcsgs.argtypes = (
    utils._BYREF_COMPLEX128, # Input, t.
    utils._BYREF_COMPLEX128, # Output, c.
    utils._BYREF_FLOAT64, # Output, s.
)

zrot2 = utils._EngineState._get_symbol('f06chf')
zrot2.restype = None
zrot2.argtypes = (
    utils._BYREF_COMPLEX128, # Input/Output, x.
    utils._BYREF_COMPLEX128, # Input/Output, y.
    utils._BYREF_COMPLEX128, # Input/Output, z.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_COMPLEX128, # Input, s.
)

zdiv = None # Not supported: com-valued function

iload = utils._EngineState._get_symbol('f06dbf')
iload.restype = None
iload.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, con.
    utils._EngineIntArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

icopy = utils._EngineState._get_symbol('f06dff')
icopy.restype = None
icopy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineIntArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)

ddot = utils._EngineState._get_symbol('ddot')
ddot.restype = utils._EngineFloat64ScalarType.c_type
ddot.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06eaf = utils._EngineState._get_symbol('f06eaf')
f06eaf.restype = ddot.restype
f06eaf.argtypes = ddot.argtypes

daxpy = utils._EngineState._get_symbol('daxpy')
daxpy.restype = None
daxpy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06ecf = utils._EngineState._get_symbol('f06ecf')
f06ecf.restype = daxpy.restype
f06ecf.argtypes = daxpy.argtypes

dscal = utils._EngineState._get_symbol('dscal')
dscal.restype = None
dscal.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06edf = utils._EngineState._get_symbol('f06edf')
f06edf.restype = dscal.restype
f06edf.argtypes = dscal.argtypes

dcopy = utils._EngineState._get_symbol('dcopy')
dcopy.restype = None
dcopy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06eff = utils._EngineState._get_symbol('f06eff')
f06eff.restype = dcopy.restype
f06eff.argtypes = dcopy.argtypes

dswap = utils._EngineState._get_symbol('dswap')
dswap.restype = None
dswap.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06egf = utils._EngineState._get_symbol('f06egf')
f06egf.restype = dswap.restype
f06egf.argtypes = dswap.argtypes

dnrm2 = utils._EngineState._get_symbol('dnrm2')
dnrm2.restype = utils._EngineFloat64ScalarType.c_type
dnrm2.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06ejf = utils._EngineState._get_symbol('f06ejf')
f06ejf.restype = dnrm2.restype
f06ejf.argtypes = dnrm2.argtypes

dasum = utils._EngineState._get_symbol('dasum')
dasum.restype = utils._EngineFloat64ScalarType.c_type
dasum.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06ekf = utils._EngineState._get_symbol('f06ekf')
f06ekf.restype = dasum.restype
f06ekf.argtypes = dasum.argtypes

drot = utils._EngineState._get_symbol('drot')
drot.restype = None
drot.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_FLOAT64, # Input, s.
)
f06epf = utils._EngineState._get_symbol('f06epf')
f06epf.restype = drot.restype
f06epf.argtypes = drot.argtypes

ddoti = utils._EngineState._get_symbol('ddoti')
ddoti.restype = utils._EngineFloat64ScalarType.c_type
ddoti.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
)
f06erf = utils._EngineState._get_symbol('f06erf')
f06erf.restype = ddoti.restype
f06erf.argtypes = ddoti.argtypes

daxpyi = utils._EngineState._get_symbol('daxpyi')
daxpyi.restype = None
daxpyi.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._BYREF_FLOAT64, # Input, a.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
)
f06etf = utils._EngineState._get_symbol('f06etf')
f06etf.restype = daxpyi.restype
f06etf.argtypes = daxpyi.argtypes

dgthr = utils._EngineState._get_symbol('dgthr')
dgthr.restype = None
dgthr.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._EngineFloat64ArrayType.c_type, # Output, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
)
f06euf = utils._EngineState._get_symbol('f06euf')
f06euf.restype = dgthr.restype
f06euf.argtypes = dgthr.argtypes

dgthrz = utils._EngineState._get_symbol('dgthrz')
dgthrz.restype = None
dgthrz.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._EngineFloat64ArrayType.c_type, # Output, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
)
f06evf = utils._EngineState._get_symbol('f06evf')
f06evf.restype = dgthrz.restype
f06evf.argtypes = dgthrz.argtypes

dsctr = utils._EngineState._get_symbol('dsctr')
dsctr.restype = None
dsctr.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
)
f06ewf = utils._EngineState._get_symbol('f06ewf')
f06ewf.restype = dsctr.restype
f06ewf.argtypes = dsctr.argtypes

droti = utils._EngineState._get_symbol('droti')
droti.restype = None
droti.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_FLOAT64, # Input, s.
)
f06exf = utils._EngineState._get_symbol('f06exf')
f06exf.restype = droti.restype
f06exf.argtypes = droti.argtypes

dvcos = utils._EngineState._get_symbol('f06faf')
dvcos.restype = utils._EngineFloat64ScalarType.c_type
dvcos.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, j.
    utils._BYREF_FLOAT64, # Input, tolx.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, toly.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
)

dload = utils._EngineState._get_symbol('f06fbf')
dload.restype = None
dload.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, con.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

ddscl = utils._EngineState._get_symbol('f06fcf')
ddscl.restype = None
ddscl.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._BYREF_INT, # Input, incd.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

axpzy = utils._EngineState._get_symbol('f06fdf')
axpzy.restype = None
axpzy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)

drscl = utils._EngineState._get_symbol('f06fef')
drscl.restype = None
drscl.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

dnegv = utils._EngineState._get_symbol('f06fgf')
dnegv.restype = None
dnegv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

dssq = utils._EngineState._get_symbol('f06fjf')
dssq.restype = None
dssq.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input/Output, scal.
    utils._BYREF_FLOAT64, # Input/Output, sumsq.
)

dnrm2w = utils._EngineState._get_symbol('f06fkf')
dnrm2w.restype = utils._EngineFloat64ScalarType.c_type
dnrm2w.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, w[*].
    utils._BYREF_INT, # Input, incw.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)

darang = utils._EngineState._get_symbol('f06flf')
darang.restype = None
darang.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Output, xmax.
    utils._BYREF_FLOAT64, # Output, xmin.
)

drots = utils._EngineState._get_symbol('f06fpf')
drots.restype = None
drots.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_FLOAT64, # Input, s.
)

dsrotg = utils._EngineState._get_symbol('f06fqf')
dsrotg.restype = None
dsrotg.argtypes = (
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input/Output, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

dnhousg = utils._EngineState._get_symbol('f06frf')
dnhousg.restype = None
dnhousg.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input/Output, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_FLOAT64, # Output, zeta.
)

dlhousg = utils._EngineState._get_symbol('f06fsf')
dlhousg.restype = None
dlhousg.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input/Output, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_FLOAT64, # Output, z1.
)

dnhous = utils._EngineState._get_symbol('f06ftf')
dnhous.restype = None
dnhous.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input/Output, delta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_FLOAT64, # Input, zeta.
    utils._EngineFloat64ArrayType.c_type, # Input, z[*].
    utils._BYREF_INT, # Input, incz.
)

dlhous = utils._EngineState._get_symbol('f06fuf')
dlhous.restype = None
dlhous.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, z[*].
    utils._BYREF_INT, # Input, incz.
    utils._BYREF_FLOAT64, # Input, z1.
    utils._BYREF_FLOAT64, # Input/Output, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

zdotu = None # Not supported: com-valued function

zdotc = None # Not supported: com-valued function

zaxpy = utils._EngineState._get_symbol('zaxpy')
zaxpy.restype = None
zaxpy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06gcf = utils._EngineState._get_symbol('f06gcf')
f06gcf.restype = zaxpy.restype
f06gcf.argtypes = zaxpy.argtypes

zscal = utils._EngineState._get_symbol('zscal')
zscal.restype = None
zscal.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06gdf = utils._EngineState._get_symbol('f06gdf')
f06gdf.restype = zscal.restype
f06gdf.argtypes = zscal.argtypes

zcopy = utils._EngineState._get_symbol('zcopy')
zcopy.restype = None
zcopy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06gff = utils._EngineState._get_symbol('f06gff')
f06gff.restype = zcopy.restype
f06gff.argtypes = zcopy.argtypes

zswap = utils._EngineState._get_symbol('zswap')
zswap.restype = None
zswap.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)
f06ggf = utils._EngineState._get_symbol('f06ggf')
f06ggf.restype = zswap.restype
f06ggf.argtypes = zswap.argtypes

zdotui = None # Not supported: com-valued function

zdotci = None # Not supported: com-valued function

zaxpyi = utils._EngineState._get_symbol('zaxpyi')
zaxpyi.restype = None
zaxpyi.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._BYREF_COMPLEX128, # Input, a.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
)
f06gtf = utils._EngineState._get_symbol('f06gtf')
f06gtf.restype = zaxpyi.restype
f06gtf.argtypes = zaxpyi.argtypes

zgthr = utils._EngineState._get_symbol('zgthr')
zgthr.restype = None
zgthr.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, y[*].
    utils._EngineComplex128ArrayType.c_type, # Output, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
)
f06guf = utils._EngineState._get_symbol('f06guf')
f06guf.restype = zgthr.restype
f06guf.argtypes = zgthr.argtypes

zgthrz = utils._EngineState._get_symbol('zgthrz')
zgthrz.restype = None
zgthrz.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._EngineComplex128ArrayType.c_type, # Output, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
)
f06gvf = utils._EngineState._get_symbol('f06gvf')
f06gvf.restype = zgthrz.restype
f06gvf.argtypes = zgthrz.argtypes

zsctr = utils._EngineState._get_symbol('zsctr')
zsctr.restype = None
zsctr.argtypes = (
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._EngineIntArrayType.c_type, # Input, indx[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
)
f06gwf = utils._EngineState._get_symbol('f06gwf')
f06gwf.restype = zsctr.restype
f06gwf.argtypes = zsctr.argtypes

zload = utils._EngineState._get_symbol('f06hbf')
zload.restype = None
zload.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, con.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

zdscl = utils._EngineState._get_symbol('f06hcf')
zdscl.restype = None
zdscl.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, d[*].
    utils._BYREF_INT, # Input, incd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

zaxpzy = utils._EngineState._get_symbol('f06hdf')
zaxpzy.restype = None
zaxpzy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)

znegv = utils._EngineState._get_symbol('f06hgf')
znegv.restype = None
znegv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

zrot = utils._EngineState._get_symbol('zrot')
zrot.restype = None
zrot.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, cx[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, cy[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_COMPLEX128, # Input, s.
)
f06hmf = utils._EngineState._get_symbol('f06hmf')
f06hmf.restype = zrot.restype
f06hmf.argtypes = zrot.argtypes

zcrot = utils._EngineState._get_symbol('f06hpf')
zcrot.restype = None
zcrot.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_COMPLEX128, # Input, c.
    utils._BYREF_COMPLEX128, # Input, s.
)

zsrotg = utils._EngineState._get_symbol('f06hqf')
zsrotg.restype = None
zsrotg.argtypes = (
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input/Output, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._EngineComplex128ArrayType.c_type, # Output, s[n].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

zhousg = utils._EngineState._get_symbol('f06hrf')
zhousg.restype = None
zhousg.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input/Output, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_COMPLEX128, # Output, theta.
)

zhous = utils._EngineState._get_symbol('f06htf')
zhous.restype = None
zhous.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input/Output, delta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_COMPLEX128, # Input, theta.
    utils._EngineComplex128ArrayType.c_type, # Input, z[*].
    utils._BYREF_INT, # Input, incz.
)

zdscal = utils._EngineState._get_symbol('zdscal')
zdscal.restype = None
zdscal.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06jdf = utils._EngineState._get_symbol('f06jdf')
f06jdf.restype = zdscal.restype
f06jdf.argtypes = zdscal.argtypes

dznrm2 = utils._EngineState._get_symbol('dznrm2')
dznrm2.restype = utils._EngineFloat64ScalarType.c_type
dznrm2.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06jjf = utils._EngineState._get_symbol('f06jjf')
f06jjf.restype = dznrm2.restype
f06jjf.argtypes = dznrm2.argtypes

dzasum = utils._EngineState._get_symbol('dzasum')
dzasum.restype = utils._EngineFloat64ScalarType.c_type
dzasum.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06jkf = utils._EngineState._get_symbol('f06jkf')
f06jkf.restype = dzasum.restype
f06jkf.argtypes = dzasum.argtypes

idamax = utils._EngineState._get_symbol('idamax')
idamax.restype = utils._EngineIntScalarType.c_type
idamax.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06jlf = utils._EngineState._get_symbol('f06jlf')
f06jlf.restype = idamax.restype
f06jlf.argtypes = idamax.argtypes

izamax = utils._EngineState._get_symbol('izamax')
izamax.restype = utils._EngineIntScalarType.c_type
izamax.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
)
f06jmf = utils._EngineState._get_symbol('f06jmf')
f06jmf.restype = izamax.restype
f06jmf.argtypes = izamax.argtypes

zddscl = utils._EngineState._get_symbol('f06kcf')
zddscl.restype = None
zddscl.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._BYREF_INT, # Input, incd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

zdaxpzy = utils._EngineState._get_symbol('f06kdf')
zdaxpzy.restype = None
zdaxpzy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)

zdrscl = utils._EngineState._get_symbol('f06kef')
zdrscl.restype = None
zdrscl.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
)

zdcopy = utils._EngineState._get_symbol('f06kff')
zdcopy.restype = None
zdcopy.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
)

dzssq = utils._EngineState._get_symbol('f06kjf')
dzssq.restype = None
dzssq.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input/Output, scal.
    utils._BYREF_FLOAT64, # Input/Output, sumsq.
)

idrank = utils._EngineState._get_symbol('f06klf')
idrank.restype = utils._EngineIntScalarType.c_type
idrank.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, tol.
)

zdrot = utils._EngineState._get_symbol('zdrot')
zdrot.restype = None
zdrot.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_FLOAT64, # Input, s.
)
f06kpf = utils._EngineState._get_symbol('f06kpf')
f06kpf.restype = zdrot.restype
f06kpf.argtypes = zdrot.argtypes

dgemv = utils._EngineState._get_symbol('dgemv')
dgemv.restype = None
dgemv.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06paf = utils._EngineState._get_symbol('f06paf')
f06paf.restype = dgemv.restype
f06paf.argtypes = dgemv.argtypes

dgbmv = utils._EngineState._get_symbol('dgbmv')
dgbmv.restype = None
dgbmv.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06pbf = utils._EngineState._get_symbol('f06pbf')
f06pbf.restype = dgbmv.restype
f06pbf.argtypes = dgbmv.argtypes

dsymv = utils._EngineState._get_symbol('dsymv')
dsymv.restype = None
dsymv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06pcf = utils._EngineState._get_symbol('f06pcf')
f06pcf.restype = dsymv.restype
f06pcf.argtypes = dsymv.argtypes

dsbmv = utils._EngineState._get_symbol('dsbmv')
dsbmv.restype = None
dsbmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06pdf = utils._EngineState._get_symbol('f06pdf')
f06pdf.restype = dsbmv.restype
f06pdf.argtypes = dsbmv.argtypes

dspmv = utils._EngineState._get_symbol('dspmv')
dspmv.restype = None
dspmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06pef = utils._EngineState._get_symbol('f06pef')
f06pef.restype = dspmv.restype
f06pef.argtypes = dspmv.argtypes

dtrmv = utils._EngineState._get_symbol('dtrmv')
dtrmv.restype = None
dtrmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06pff = utils._EngineState._get_symbol('f06pff')
f06pff.restype = dtrmv.restype
f06pff.argtypes = dtrmv.argtypes

dtbmv = utils._EngineState._get_symbol('dtbmv')
dtbmv.restype = None
dtbmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06pgf = utils._EngineState._get_symbol('f06pgf')
f06pgf.restype = dtbmv.restype
f06pgf.argtypes = dtbmv.argtypes

dtpmv = utils._EngineState._get_symbol('dtpmv')
dtpmv.restype = None
dtpmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06phf = utils._EngineState._get_symbol('f06phf')
f06phf.restype = dtpmv.restype
f06phf.argtypes = dtpmv.argtypes

dtrsv = utils._EngineState._get_symbol('dtrsv')
dtrsv.restype = None
dtrsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06pjf = utils._EngineState._get_symbol('f06pjf')
f06pjf.restype = dtrsv.restype
f06pjf.argtypes = dtrsv.argtypes

dtbsv = utils._EngineState._get_symbol('dtbsv')
dtbsv.restype = None
dtbsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06pkf = utils._EngineState._get_symbol('f06pkf')
f06pkf.restype = dtbsv.restype
f06pkf.argtypes = dtbsv.argtypes

dtpsv = utils._EngineState._get_symbol('dtpsv')
dtpsv.restype = None
dtpsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06plf = utils._EngineState._get_symbol('f06plf')
f06plf.restype = dtpsv.restype
f06plf.argtypes = dtpsv.argtypes

dger = utils._EngineState._get_symbol('dger')
dger.restype = None
dger.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
)
f06pmf = utils._EngineState._get_symbol('f06pmf')
f06pmf.restype = dger.restype
f06pmf.argtypes = dger.argtypes

dsyr = utils._EngineState._get_symbol('dsyr')
dsyr.restype = None
dsyr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06ppf = utils._EngineState._get_symbol('f06ppf')
f06ppf.restype = dsyr.restype
f06ppf.argtypes = dsyr.argtypes

dspr = utils._EngineState._get_symbol('dspr')
dspr.restype = None
dspr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06pqf = utils._EngineState._get_symbol('f06pqf')
f06pqf.restype = dspr.restype
f06pqf.argtypes = dspr.argtypes

dsyr2 = utils._EngineState._get_symbol('dsyr2')
dsyr2.restype = None
dsyr2.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06prf = utils._EngineState._get_symbol('f06prf')
f06prf.restype = dsyr2.restype
f06prf.argtypes = dsyr2.argtypes

dspr2 = utils._EngineState._get_symbol('dspr2')
dspr2.restype = None
dspr2.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06psf = utils._EngineState._get_symbol('f06psf')
f06psf.restype = dspr2.restype
f06psf.argtypes = dspr2.argtypes

dmcopy = utils._EngineState._get_symbol('f06qff')
dmcopy.restype = None
dmcopy.argtypes = (
    utils._BYREF_STRING, # Input, matrix(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of matrix.
)

dmload = utils._EngineState._get_symbol('f06qhf')
dmload.restype = None
dmload.argtypes = (
    utils._BYREF_STRING, # Input, matrix(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, con.
    utils._BYREF_FLOAT64, # Input, diag.
    utils._EngineFloat64ArrayType.c_type, # Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of matrix.
)

dgeap = utils._EngineState._get_symbol('f06qjf')
dgeap.restype = None
dgeap.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, perm[*].
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)

dgeapr = utils._EngineState._get_symbol('f06qkf')
dgeapr.restype = None
dgeapr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, perm[*].
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)

dsysrc = utils._EngineState._get_symbol('f06qmf')
dsysrc.restype = None
dsysrc.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

dutr1 = utils._EngineState._get_symbol('f06qpf')
dutr1.restype = None
dutr1.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, c[n-1].
    utils._EngineFloat64ArrayType.c_type, # Output, s[n-1].
)

dutupd = utils._EngineState._get_symbol('f06qqf')
dutupd.restype = None
dutupd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
)

duhqr = utils._EngineState._get_symbol('f06qrf')
duhqr.restype = None
duhqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Output, c[k2-1].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[k2-1].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

dusqr = utils._EngineState._get_symbol('f06qsf')
dusqr.restype = None
dusqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Output, c[k2-1].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

dutsqr = utils._EngineState._get_symbol('f06qtf')
dutsqr.restype = None
dutsqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

dutsrh = utils._EngineState._get_symbol('f06qvf')
dutsrh.restype = None
dutsrh.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

dutsrs = utils._EngineState._get_symbol('f06qwf')
dutsrs.restype = None
dutsrs.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

dgesrc = utils._EngineState._get_symbol('f06qxf')
dgesrc.restype = None
dgesrc.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[k2-1].
    utils._EngineFloat64ArrayType.c_type, # Input, s[k2-1].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

dlange = utils._EngineState._get_symbol('f06raf')
dlange.restype = utils._EngineFloat64ScalarType.c_type
dlange.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

dlangb = utils._EngineState._get_symbol('f06rbf')
dlangb.restype = utils._EngineFloat64ScalarType.c_type
dlangb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

dlansy = utils._EngineState._get_symbol('f06rcf')
dlansy.restype = utils._EngineFloat64ScalarType.c_type
dlansy.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

dlansp = utils._EngineState._get_symbol('f06rdf')
dlansp.restype = utils._EngineFloat64ScalarType.c_type
dlansp.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

dlansb = utils._EngineState._get_symbol('f06ref')
dlansb.restype = utils._EngineFloat64ScalarType.c_type
dlansb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

dlantr = utils._EngineState._get_symbol('f06rjf')
dlantr.restype = utils._EngineFloat64ScalarType.c_type
dlantr.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

dlantp = utils._EngineState._get_symbol('f06rkf')
dlantp.restype = utils._EngineFloat64ScalarType.c_type
dlantp.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

dlantb = utils._EngineState._get_symbol('f06rlf')
dlantb.restype = utils._EngineFloat64ScalarType.c_type
dlantb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

dlanhs = utils._EngineState._get_symbol('f06rmf')
dlanhs.restype = utils._EngineFloat64ScalarType.c_type
dlanhs.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

dlangt = utils._EngineState._get_symbol('f06rnf')
dlangt.restype = utils._EngineFloat64ScalarType.c_type
dlangt.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

dlanst = utils._EngineState._get_symbol('f06rpf')
dlanst.restype = utils._EngineFloat64ScalarType.c_type
dlanst.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

zgemv = utils._EngineState._get_symbol('zgemv')
zgemv.restype = None
zgemv.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06saf = utils._EngineState._get_symbol('f06saf')
f06saf.restype = zgemv.restype
f06saf.argtypes = zgemv.argtypes

zgbmv = utils._EngineState._get_symbol('zgbmv')
zgbmv.restype = None
zgbmv.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06sbf = utils._EngineState._get_symbol('f06sbf')
f06sbf.restype = zgbmv.restype
f06sbf.argtypes = zgbmv.argtypes

zhemv = utils._EngineState._get_symbol('zhemv')
zhemv.restype = None
zhemv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06scf = utils._EngineState._get_symbol('f06scf')
f06scf.restype = zhemv.restype
f06scf.argtypes = zhemv.argtypes

zhbmv = utils._EngineState._get_symbol('zhbmv')
zhbmv.restype = None
zhbmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06sdf = utils._EngineState._get_symbol('f06sdf')
f06sdf.restype = zhbmv.restype
f06sdf.argtypes = zhbmv.argtypes

zhpmv = utils._EngineState._get_symbol('zhpmv')
zhpmv.restype = None
zhpmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06sef = utils._EngineState._get_symbol('f06sef')
f06sef.restype = zhpmv.restype
f06sef.argtypes = zhpmv.argtypes

ztrmv = utils._EngineState._get_symbol('ztrmv')
ztrmv.restype = None
ztrmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06sff = utils._EngineState._get_symbol('f06sff')
f06sff.restype = ztrmv.restype
f06sff.argtypes = ztrmv.argtypes

ztbmv = utils._EngineState._get_symbol('ztbmv')
ztbmv.restype = None
ztbmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06sgf = utils._EngineState._get_symbol('f06sgf')
f06sgf.restype = ztbmv.restype
f06sgf.argtypes = ztbmv.argtypes

ztpmv = utils._EngineState._get_symbol('ztpmv')
ztpmv.restype = None
ztpmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06shf = utils._EngineState._get_symbol('f06shf')
f06shf.restype = ztpmv.restype
f06shf.argtypes = ztpmv.argtypes

ztrsv = utils._EngineState._get_symbol('ztrsv')
ztrsv.restype = None
ztrsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06sjf = utils._EngineState._get_symbol('f06sjf')
f06sjf.restype = ztrsv.restype
f06sjf.argtypes = ztrsv.argtypes

ztbsv = utils._EngineState._get_symbol('ztbsv')
ztbsv.restype = None
ztbsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06skf = utils._EngineState._get_symbol('f06skf')
f06skf.restype = ztbsv.restype
f06skf.argtypes = ztbsv.argtypes

ztpsv = utils._EngineState._get_symbol('ztpsv')
ztpsv.restype = None
ztpsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06slf = utils._EngineState._get_symbol('f06slf')
f06slf.restype = ztpsv.restype
f06slf.argtypes = ztpsv.argtypes

zgeru = utils._EngineState._get_symbol('zgeru')
zgeru.restype = None
zgeru.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
)
f06smf = utils._EngineState._get_symbol('f06smf')
f06smf.restype = zgeru.restype
f06smf.argtypes = zgeru.argtypes

zgerc = utils._EngineState._get_symbol('zgerc')
zgerc.restype = None
zgerc.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
)
f06snf = utils._EngineState._get_symbol('f06snf')
f06snf.restype = zgerc.restype
f06snf.argtypes = zgerc.argtypes

zher = utils._EngineState._get_symbol('zher')
zher.restype = None
zher.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06spf = utils._EngineState._get_symbol('f06spf')
f06spf.restype = zher.restype
f06spf.argtypes = zher.argtypes

zhpr = utils._EngineState._get_symbol('zhpr')
zhpr.restype = None
zhpr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06sqf = utils._EngineState._get_symbol('f06sqf')
f06sqf.restype = zhpr.restype
f06sqf.argtypes = zhpr.argtypes

zher2 = utils._EngineState._get_symbol('zher2')
zher2.restype = None
zher2.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06srf = utils._EngineState._get_symbol('f06srf')
f06srf.restype = zher2.restype
f06srf.argtypes = zher2.argtypes

zhpr2 = utils._EngineState._get_symbol('zhpr2')
zhpr2.restype = None
zhpr2.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06ssf = utils._EngineState._get_symbol('f06ssf')
f06ssf.restype = zhpr2.restype
f06ssf.argtypes = zhpr2.argtypes

zsymv = utils._EngineState._get_symbol('f06taf')
zsymv.restype = None
zsymv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zsyr = utils._EngineState._get_symbol('f06tbf')
zsyr.restype = None
zsyr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zspmv = utils._EngineState._get_symbol('f06tcf')
zspmv.restype = None
zspmv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zspr = utils._EngineState._get_symbol('f06tdf')
zspr.restype = None
zspr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zmcopy = utils._EngineState._get_symbol('f06tff')
zmcopy.restype = None
zmcopy.argtypes = (
    utils._BYREF_STRING, # Input, matrix(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of matrix.
)

zmload = utils._EngineState._get_symbol('f06thf')
zmload.restype = None
zmload.argtypes = (
    utils._BYREF_STRING, # Input, matrix(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, con.
    utils._BYREF_COMPLEX128, # Input, diag.
    utils._EngineComplex128ArrayType.c_type, # Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of matrix.
)

zhesrc = utils._EngineState._get_symbol('f06tmf')
zhesrc.restype = None
zhesrc.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineComplex128ArrayType.c_type, # Input, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

zutr1 = utils._EngineState._get_symbol('f06tpf')
zutr1.restype = None
zutr1.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input, y[*].
    utils._BYREF_INT, # Input, incy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, c[n-1].
    utils._EngineComplex128ArrayType.c_type, # Output, s[n].
)

zutupd = utils._EngineState._get_symbol('f06tqf')
zutupd.restype = None
zutupd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._BYREF_INT, # Input, incx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._EngineComplex128ArrayType.c_type, # Output, s[n].
)

zuhqr = utils._EngineState._get_symbol('f06trf')
zuhqr.restype = None
zuhqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineComplex128ArrayType.c_type, # Output, c[k2].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

zusqr = utils._EngineState._get_symbol('f06tsf')
zusqr.restype = None
zusqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Output, c[k2-1].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

zutsqr = utils._EngineState._get_symbol('f06ttf')
zutsqr.restype = None
zutsqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

zutsrh = utils._EngineState._get_symbol('f06tvf')
zutsrh.restype = None
zutsrh.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineComplex128ArrayType.c_type, # Input, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

zutsrs = utils._EngineState._get_symbol('f06twf')
zutsrs.restype = None
zutsrs.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)

zgesrc = utils._EngineState._get_symbol('f06txf')
zgesrc.restype = None
zgesrc.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineComplex128ArrayType.c_type, # Input, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

zgesrs = utils._EngineState._get_symbol('f06tyf')
zgesrs.restype = None
zgesrs.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineComplex128ArrayType.c_type, # Input, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

zlange = utils._EngineState._get_symbol('f06uaf')
zlange.restype = utils._EngineFloat64ScalarType.c_type
zlange.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

zlangb = utils._EngineState._get_symbol('f06ubf')
zlangb.restype = utils._EngineFloat64ScalarType.c_type
zlangb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

zlanhe = utils._EngineState._get_symbol('f06ucf')
zlanhe.restype = utils._EngineFloat64ScalarType.c_type
zlanhe.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zlanhp = utils._EngineState._get_symbol('f06udf')
zlanhp.restype = utils._EngineFloat64ScalarType.c_type
zlanhp.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zlanhb = utils._EngineState._get_symbol('f06uef')
zlanhb.restype = utils._EngineFloat64ScalarType.c_type
zlanhb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zlansy = utils._EngineState._get_symbol('f06uff')
zlansy.restype = utils._EngineFloat64ScalarType.c_type
zlansy.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zlansp = utils._EngineState._get_symbol('f06ugf')
zlansp.restype = utils._EngineFloat64ScalarType.c_type
zlansp.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zlansb = utils._EngineState._get_symbol('f06uhf')
zlansb.restype = utils._EngineFloat64ScalarType.c_type
zlansb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

zlantr = utils._EngineState._get_symbol('f06ujf')
zlantr.restype = utils._EngineFloat64ScalarType.c_type
zlantr.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

zlantp = utils._EngineState._get_symbol('f06ukf')
zlantp.restype = utils._EngineFloat64ScalarType.c_type
zlantp.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

zlantb = utils._EngineState._get_symbol('f06ulf')
zlantb.restype = utils._EngineFloat64ScalarType.c_type
zlantb.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

zlanhs = utils._EngineState._get_symbol('f06umf')
zlanhs.restype = utils._EngineFloat64ScalarType.c_type
zlanhs.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

zlangt = utils._EngineState._get_symbol('f06unf')
zlangt.restype = utils._EngineFloat64ScalarType.c_type
zlangt.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

zlanht = utils._EngineState._get_symbol('f06upf')
zlanht.restype = utils._EngineFloat64ScalarType.c_type
zlanht.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, e[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)

zgeap = utils._EngineState._get_symbol('f06vjf')
zgeap.restype = None
zgeap.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, perm[*].
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)

zgeapr = utils._EngineState._get_symbol('f06vkf')
zgeapr.restype = None
zgeapr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, perm[*].
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)

zsgesr = utils._EngineState._get_symbol('f06vxf')
zsgesr.restype = None
zsgesr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, pivot(len=1).
    utils._BYREF_STRING, # Input, direct(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k1.
    utils._BYREF_INT, # Input, k2.
    utils._EngineFloat64ArrayType.c_type, # Input, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pivot.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of direct.
)

dlansf = utils._EngineState._get_symbol('dlansf')
dlansf.restype = utils._EngineFloat64ScalarType.c_type
dlansf.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06waf = utils._EngineState._get_symbol('f06waf')
f06waf.restype = dlansf.restype
f06waf.argtypes = dlansf.argtypes

dtfsm = utils._EngineState._get_symbol('dtfsm')
dtfsm.restype = None
dtfsm.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06wbf = utils._EngineState._get_symbol('f06wbf')
f06wbf.restype = dtfsm.restype
f06wbf.argtypes = dtfsm.argtypes

dsfrk = utils._EngineState._get_symbol('dsfrk')
dsfrk.restype = None
dsfrk.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[n*(n+1)/2].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06wcf = utils._EngineState._get_symbol('f06wcf')
f06wcf.restype = dsfrk.restype
f06wcf.argtypes = dsfrk.argtypes

zlanhf = utils._EngineState._get_symbol('zlanhf')
zlanhf.restype = utils._EngineFloat64ScalarType.c_type
zlanhf.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06wnf = utils._EngineState._get_symbol('f06wnf')
f06wnf.restype = zlanhf.restype
f06wnf.argtypes = zlanhf.argtypes

ztfsm = utils._EngineState._get_symbol('ztfsm')
ztfsm.restype = None
ztfsm.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06wpf = utils._EngineState._get_symbol('f06wpf')
f06wpf.restype = ztfsm.restype
f06wpf.argtypes = ztfsm.argtypes

zhfrk = utils._EngineState._get_symbol('zhfrk')
zhfrk.restype = None
zhfrk.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[n*(n+1)/2].
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06wqf = utils._EngineState._get_symbol('f06wqf')
f06wqf.restype = zhfrk.restype
f06wqf.argtypes = zhfrk.argtypes

dgemm = utils._EngineState._get_symbol('dgemm')
dgemm.restype = None
dgemm.argtypes = (
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, transb(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transb.
)
f06yaf = utils._EngineState._get_symbol('f06yaf')
f06yaf.restype = dgemm.restype
f06yaf.argtypes = dgemm.argtypes

dsymm = utils._EngineState._get_symbol('dsymm')
dsymm.restype = None
dsymm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06ycf = utils._EngineState._get_symbol('f06ycf')
f06ycf.restype = dsymm.restype
f06ycf.argtypes = dsymm.argtypes

dtrmm = utils._EngineState._get_symbol('dtrmm')
dtrmm.restype = None
dtrmm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06yff = utils._EngineState._get_symbol('f06yff')
f06yff.restype = dtrmm.restype
f06yff.argtypes = dtrmm.argtypes

dtrsm = utils._EngineState._get_symbol('dtrsm')
dtrsm.restype = None
dtrsm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06yjf = utils._EngineState._get_symbol('f06yjf')
f06yjf.restype = dtrsm.restype
f06yjf.argtypes = dtrsm.argtypes

dsyrk = utils._EngineState._get_symbol('dsyrk')
dsyrk.restype = None
dsyrk.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06ypf = utils._EngineState._get_symbol('f06ypf')
f06ypf.restype = dsyrk.restype
f06ypf.argtypes = dsyrk.argtypes

dsyr2k = utils._EngineState._get_symbol('dsyr2k')
dsyr2k.restype = None
dsyr2k.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06yrf = utils._EngineState._get_symbol('f06yrf')
f06yrf.restype = dsyr2k.restype
f06yrf.argtypes = dsyr2k.argtypes

zgemm = utils._EngineState._get_symbol('zgemm')
zgemm.restype = None
zgemm.argtypes = (
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, transb(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transb.
)
f06zaf = utils._EngineState._get_symbol('f06zaf')
f06zaf.restype = zgemm.restype
f06zaf.argtypes = zgemm.argtypes

zhemm = utils._EngineState._get_symbol('zhemm')
zhemm.restype = None
zhemm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06zcf = utils._EngineState._get_symbol('f06zcf')
f06zcf.restype = zhemm.restype
f06zcf.argtypes = zhemm.argtypes

ztrmm = utils._EngineState._get_symbol('ztrmm')
ztrmm.restype = None
ztrmm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06zff = utils._EngineState._get_symbol('f06zff')
f06zff.restype = ztrmm.restype
f06zff.argtypes = ztrmm.argtypes

ztrsm = utils._EngineState._get_symbol('ztrsm')
ztrsm.restype = None
ztrsm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f06zjf = utils._EngineState._get_symbol('f06zjf')
f06zjf.restype = ztrsm.restype
f06zjf.argtypes = ztrsm.argtypes

zherk = utils._EngineState._get_symbol('zherk')
zherk.restype = None
zherk.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06zpf = utils._EngineState._get_symbol('f06zpf')
f06zpf.restype = zherk.restype
f06zpf.argtypes = zherk.argtypes

zher2k = utils._EngineState._get_symbol('zher2k')
zher2k.restype = None
zher2k.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06zrf = utils._EngineState._get_symbol('f06zrf')
f06zrf.restype = zher2k.restype
f06zrf.argtypes = zher2k.argtypes

zsymm = utils._EngineState._get_symbol('zsymm')
zsymm.restype = None
zsymm.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f06ztf = utils._EngineState._get_symbol('f06ztf')
f06ztf.restype = zsymm.restype
f06ztf.argtypes = zsymm.argtypes

zsyrk = utils._EngineState._get_symbol('zsyrk')
zsyrk.restype = None
zsyrk.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06zuf = utils._EngineState._get_symbol('f06zuf')
f06zuf.restype = zsyrk.restype
f06zuf.argtypes = zsyrk.argtypes

zsyr2k = utils._EngineState._get_symbol('zsyr2k')
zsyr2k.restype = None
zsyr2k.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f06zwf = utils._EngineState._get_symbol('f06zwf')
f06zwf.restype = zsyr2k.restype
f06zwf.argtypes = zsyr2k.argtypes
