# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `contab` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

chisq = utils._EngineState._get_symbol('g11aaf')
chisq.restype = None
chisq.argtypes = (
    utils._BYREF_INT, # Input, nrow.
    utils._BYREF_INT, # Input, ncol.
    utils._EngineIntArrayType.c_type, # Input, nobs[ldnobs, ncol].
    utils._BYREF_INT, # Input, ldnobs.
    utils._EngineFloat64ArrayType.c_type, # Output, expt[ldnobs, ncol].
    utils._EngineFloat64ArrayType.c_type, # Output, chist[ldnobs, ncol].
    utils._BYREF_FLOAT64, # Output, prob.
    utils._BYREF_FLOAT64, # Output, chi.
    utils._BYREF_FLOAT64, # Output, g.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_INT, # Input/Output, ifail.
)

tabulate_stat = utils._EngineState._get_symbol('g11baf')
tabulate_stat.restype = None
tabulate_stat.argtypes = (
    utils._BYREF_STRING, # Input, stat(len=1).
    utils._BYREF_STRING, # Input, update(len=1).
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nfac.
    utils._EngineIntArrayType.c_type, # Input, isf[nfac].
    utils._EngineIntArrayType.c_type, # Input, lfac[nfac].
    utils._EngineIntArrayType.c_type, # Input, ifac[ldf, nfac].
    utils._BYREF_INT, # Input, ldf.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, table[maxt].
    utils._BYREF_INT, # Input, maxt.
    utils._BYREF_INT, # Input/Output, ncells.
    utils._BYREF_INT, # Output, ndim.
    utils._EngineIntArrayType.c_type, # Output, idim[nfac].
    utils._EngineIntArrayType.c_type, # Input/Output, icount[maxt].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, auxt[*].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[2*nfac].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of stat.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of update.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

tabulate_percentile = utils._EngineState._get_symbol('g11bbf')
tabulate_percentile.restype = None
tabulate_percentile.argtypes = (
    utils._BYREF_STRING, # Input, typ(len=1).
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nfac.
    utils._EngineIntArrayType.c_type, # Input, isf[nfac].
    utils._EngineIntArrayType.c_type, # Input, lfac[nfac].
    utils._EngineIntArrayType.c_type, # Input, ifac[ldf, nfac].
    utils._BYREF_INT, # Input, ldf.
    utils._BYREF_FLOAT64, # Input, percnt.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineFloat64ArrayType.c_type, # Output, table[maxt].
    utils._BYREF_INT, # Input, maxt.
    utils._BYREF_INT, # Output, ncells.
    utils._BYREF_INT, # Output, ndim.
    utils._EngineIntArrayType.c_type, # Output, idim[nfac].
    utils._EngineIntArrayType.c_type, # Output, icount[maxt].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[2*nfac+n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[2*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of typ.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

tabulate_margin = utils._EngineState._get_symbol('g11bcf')
tabulate_margin.restype = None
tabulate_margin.argtypes = (
    utils._BYREF_STRING, # Input, stat(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, table[ncells].
    utils._BYREF_INT, # Input, ncells.
    utils._BYREF_INT, # Input, ndim.
    utils._EngineIntArrayType.c_type, # Input, idim[ndim].
    utils._EngineIntArrayType.c_type, # Input, isdim[ndim].
    utils._EngineFloat64ArrayType.c_type, # Output, stable[maxst].
    utils._BYREF_INT, # Input, maxst.
    utils._BYREF_INT, # Output, mcells.
    utils._BYREF_INT, # Output, mdim.
    utils._EngineIntArrayType.c_type, # Output, mlevel[ndim].
    utils._EngineFloat64ArrayType.c_type, # Output, auxt[*].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[3*ndim].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[ncells].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of stat.
)

condl_logistic = utils._EngineState._get_symbol('g11caf')
condl_logistic.restype = None
condl_logistic.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, ns.
    utils._EngineFloat64ArrayType.c_type, # Input, z[ldz, m].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Input, isz[m].
    utils._BYREF_INT, # Input, ip.
    utils._EngineIntArrayType.c_type, # Input, ic[n].
    utils._EngineIntArrayType.c_type, # Input, isi[n].
    utils._BYREF_FLOAT64, # Output, dev.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, se[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, sc[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, cov[ip*(ip+1)/2].
    utils._EngineIntArrayType.c_type, # Output, nca[ns].
    utils._EngineIntArrayType.c_type, # Output, nct[ns].
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_INT, # Input, iprint.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[lwk].
    utils._BYREF_INT, # Input, lwk.
    utils._BYREF_INT, # Input/Output, ifail.
)

binary = utils._EngineState._get_symbol('g11saf')
binary.restype = None
binary.argtypes = (
    utils._BYREF_INT, # Input, ip.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_LOGICAL, # Input, gprob.
    utils._BYREF_INT, # Input, ns.
    utils._EngineLogicalArrayType.c_type, # Input/Output, x[ldx, ip].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input/Output, irl[ns].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[ip].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ip].
    utils._BYREF_INT, # Input, iprint.
    utils._BYREF_FLOAT64, # Input, cgetol.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_LOGICAL, # Input, chisqr.
    utils._BYREF_INT, # Input, ishow.
    utils._BYREF_INT, # Output, niter.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, pigam[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, cm[ldcm, 2*ip].
    utils._BYREF_INT, # Input, ldcm.
    utils._EngineFloat64ArrayType.c_type, # Output, g[2*ip].
    utils._EngineFloat64ArrayType.c_type, # Output, expp[ldexpp, ip].
    utils._BYREF_INT, # Input, ldexpp.
    utils._EngineFloat64ArrayType.c_type, # Output, obs[ldexpp, ip].
    utils._EngineFloat64ArrayType.c_type, # Output, exf[ns].
    utils._EngineFloat64ArrayType.c_type, # Output, y[ns].
    utils._EngineFloat64ArrayType.c_type, # Output, xl[ns].
    utils._EngineIntArrayType.c_type, # Output, iob[ns].
    utils._BYREF_FLOAT64, # Output, rlogl.
    utils._BYREF_FLOAT64, # Output, chi.
    utils._BYREF_INT, # Output, idf.
    utils._BYREF_FLOAT64, # Output, siglev.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w[lw].
    utils._BYREF_INT, # Input, lw.
    utils._BYREF_INT, # Input/Output, ifail.
)

binary_service = utils._EngineState._get_symbol('g11sbf')
binary_service.restype = None
binary_service.argtypes = (
    utils._BYREF_INT, # Input, ip.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Output, ns.
    utils._EngineLogicalArrayType.c_type, # Input/Output, x[ldx, ip].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Output, irl[n].
    utils._BYREF_INT, # Input/Output, ifail.
)
