# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `eigen` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

real_gen_eigsys = utils._EngineState._get_symbol('f02ecf')
real_gen_eigsys.restype = None
real_gen_eigsys.argtypes = (
    utils._BYREF_STRING, # Input, crit(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, wl.
    utils._BYREF_FLOAT64, # Input, wu.
    utils._BYREF_INT, # Input, mest.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[n].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, mest].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, vi[ldvi, mest].
    utils._BYREF_INT, # Input, ldvi.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of crit.
)

real_gen_sparse_arnoldi_monit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, ncv.
    utils._BYREF_INT, # Input, niter.
    utils._BYREF_INT, # Input, nconv.
    utils._EngineComplex128ArrayType.c_type, # Input, w[ncv].
    utils._EngineFloat64ArrayType.c_type, # Input, rzest[ncv].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_sparse_arnoldi_option = utils._EngineState._sys_functype(
    None,
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_sparse_arnoldi = utils._EngineState._get_symbol('f02ekf')
real_gen_sparse_arnoldi.restype = None
real_gen_sparse_arnoldi.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nnz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[nnz].
    utils._EngineIntArrayType.c_type, # Input, icolzp[n+1].
    utils._EngineIntArrayType.c_type, # Input, irowix[nnz].
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._BYREF_FLOAT64, # Input, sigma.
    real_gen_sparse_arnoldi_monit,
    real_gen_sparse_arnoldi_option,
    utils._BYREF_INT, # Output, nconv.
    utils._EngineComplex128ArrayType.c_type, # Output, w[ncv].
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, resid[nev+1].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

arnoldi_option = utils._EngineState._get_symbol('f02eky')
arnoldi_option.restype = None
arnoldi_option.argtypes = (
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)

arnoldi_monit_gen = utils._EngineState._get_symbol('f02ekz')
arnoldi_monit_gen.restype = None
arnoldi_monit_gen.argtypes = (
    utils._BYREF_INT, # Input, ncv.
    utils._BYREF_INT, # Input, niter.
    utils._BYREF_INT, # Input, nconv.
    utils._EngineComplex128ArrayType.c_type, # Input, w[ncv].
    utils._EngineFloat64ArrayType.c_type, # Input, rzest[ncv].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)

real_symm_sparse_eigsys_dot = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, z[n].
    utils._EngineFloat64ArrayType.c_type, # Input, w[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Input, lruser.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._BYREF_INT, # Input, liuser.
)
real_symm_sparse_eigsys_image = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, z[n].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Input, lruser.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._BYREF_INT, # Input, liuser.
)
real_symm_sparse_eigsys_monit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, istate.
    utils._BYREF_INT, # Input, nextit.
    utils._BYREF_INT, # Input, nevals.
    utils._BYREF_INT, # Input, nevecs.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, f[k].
    utils._EngineFloat64ArrayType.c_type, # Input, d[k].
)
real_symm_sparse_eigsys = utils._EngineState._get_symbol('f02fjf')
real_symm_sparse_eigsys.restype = None
real_symm_sparse_eigsys.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input/Output, m.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input/Output, noits.
    utils._BYREF_FLOAT64, # Input, tol.
    real_symm_sparse_eigsys_dot,
    real_symm_sparse_eigsys_image,
    real_symm_sparse_eigsys_monit,
    utils._BYREF_INT, # Input, novecs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, k].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, d[k].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Input, lruser.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._BYREF_INT, # Input, liuser.
    utils._BYREF_INT, # Input/Output, ifail.
)

monit = utils._EngineState._get_symbol('f02fjz')
monit.restype = None
monit.argtypes = (
    utils._BYREF_INT, # Input, istate.
    utils._BYREF_INT, # Input, nextit.
    utils._BYREF_INT, # Input, nevals.
    utils._BYREF_INT, # Input, nevecs.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, f[k].
    utils._EngineFloat64ArrayType.c_type, # Input, d[k].
)

real_symm_sparse_arnoldi_monit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, ncv.
    utils._BYREF_INT, # Input, niter.
    utils._BYREF_INT, # Input, nconv.
    utils._EngineFloat64ArrayType.c_type, # Input, w[ncv].
    utils._EngineFloat64ArrayType.c_type, # Input, rzest[ncv].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_symm_sparse_arnoldi_option = utils._EngineState._sys_functype(
    None,
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_symm_sparse_arnoldi = utils._EngineState._get_symbol('f02fkf')
real_symm_sparse_arnoldi.restype = None
real_symm_sparse_arnoldi.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nnz.
    utils._EngineFloat64ArrayType.c_type, # Input, a[nnz].
    utils._EngineIntArrayType.c_type, # Input, irow[nnz].
    utils._EngineIntArrayType.c_type, # Input, icol[nnz].
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._BYREF_FLOAT64, # Input, sigma.
    real_symm_sparse_arnoldi_monit,
    real_symm_sparse_arnoldi_option,
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, w[ncv].
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, resid[nev].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

arnoldi_monit_symm = utils._EngineState._get_symbol('f02fkz')
arnoldi_monit_symm.restype = None
arnoldi_monit_symm.argtypes = (
    utils._BYREF_INT, # Input, ncv.
    utils._BYREF_INT, # Input, niter.
    utils._BYREF_INT, # Input, nconv.
    utils._EngineFloat64ArrayType.c_type, # Input, w[ncv].
    utils._EngineFloat64ArrayType.c_type, # Input, rzest[ncv].
    utils._BYREF_INT, # Input/Output, istat.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)

complex_gen_eigsys = utils._EngineState._get_symbol('f02gcf')
complex_gen_eigsys.restype = None
complex_gen_eigsys.argtypes = (
    utils._BYREF_STRING, # Input, crit(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, wl.
    utils._BYREF_FLOAT64, # Input, wu.
    utils._BYREF_INT, # Input, mest.
    utils._BYREF_INT, # Output, m.
    utils._EngineComplex128ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, mest].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of crit.
)

real_gen_quad = utils._EngineState._get_symbol('f02jcf')
real_gen_quad.restype = None
real_gen_quad.argtypes = (
    utils._BYREF_INT, # Input, scal.
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, sense.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[2*n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[2*n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[2*n].
    utils._EngineFloat64ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, bevl[*].
    utils._EngineFloat64ArrayType.c_type, # Output, bevr[*].
    utils._BYREF_INT, # Output, iwarn.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)

complex_gen_quad = utils._EngineState._get_symbol('f02jqf')
complex_gen_quad.restype = None
complex_gen_quad.argtypes = (
    utils._BYREF_INT, # Input, scal.
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, sense.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[2*n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[2*n].
    utils._EngineComplex128ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, bevl[*].
    utils._EngineFloat64ArrayType.c_type, # Output, bevr[*].
    utils._BYREF_INT, # Output, iwarn.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)

real_gen_partialsvd_av = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[*].
    utils._EngineFloat64ArrayType.c_type, # Output, ax[*].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_partialsvd = utils._EngineState._get_symbol('f02wgf')
real_gen_partialsvd.restype = None
real_gen_partialsvd.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, ncv.
    real_gen_partialsvd_av,
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, sigma[ncv].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, ncv].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, ncv].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, resid[ncv].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_triang_svd = utils._EngineState._get_symbol('f02wuf')
real_triang_svd.restype = None
real_triang_svd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input, ncolb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_LOGICAL, # Input, wantq.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Output, sv[n].
    utils._BYREF_LOGICAL, # Input, wantp.
    utils._EngineFloat64ArrayType.c_type, # Output, work[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_triang_svd = utils._EngineState._get_symbol('f02xuf')
complex_triang_svd.restype = None
complex_triang_svd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input, ncolb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_LOGICAL, # Input, wantq.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Output, sv[n].
    utils._BYREF_LOGICAL, # Input, wantp.
    utils._EngineFloat64ArrayType.c_type, # Output, rwork[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, cwork[max(1, n-1)].
    utils._BYREF_INT, # Input/Output, ifail.
)
