# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `inteq` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

fredholm2_split_k1 = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, s.
)
fredholm2_split_k2 = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, s.
)
fredholm2_split_g = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
)
fredholm2_split = utils._EngineState._get_symbol('d05aaf')
fredholm2_split.restype = None
fredholm2_split.argtypes = (
    utils._BYREF_FLOAT64, # Input, lambda.
    utils._BYREF_FLOAT64, # Input, a.
    utils._BYREF_FLOAT64, # Input, b.
    fredholm2_split_k1,
    fredholm2_split_k2,
    fredholm2_split_g,
    utils._EngineFloat64ArrayType.c_type, # Output, f[n].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ind.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w1[ldw1, ldw2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, w2[ldw2, 4].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wd[ldw2].
    utils._BYREF_INT, # Input, ldw1.
    utils._BYREF_INT, # Input, ldw2.
    utils._BYREF_INT, # Input/Output, ifail.
)

fredholm2_smooth_k = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, s.
)
fredholm2_smooth_g = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
)
fredholm2_smooth = utils._EngineState._get_symbol('d05abf')
fredholm2_smooth.restype = None
fredholm2_smooth.argtypes = (
    fredholm2_smooth_k,
    fredholm2_smooth_g,
    utils._BYREF_FLOAT64, # Input, lambda.
    utils._BYREF_FLOAT64, # Input, a.
    utils._BYREF_FLOAT64, # Input, b.
    utils._BYREF_LOGICAL, # Input, odorev.
    utils._BYREF_LOGICAL, # Input, ev.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Workspace, cm[ldcm, ldcm].
    utils._EngineFloat64ArrayType.c_type, # Workspace, f1[ldcm, 1].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[2, nt2p1].
    utils._BYREF_INT, # Input, ldcm.
    utils._BYREF_INT, # Input, nt2p1.
    utils._EngineFloat64ArrayType.c_type, # Output, f[n].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

volterra2_ck = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
volterra2_cg = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, s.
    utils._BYREF_FLOAT64, # Input, y.
)
volterra2_cf = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
volterra2 = utils._EngineState._get_symbol('d05baf')
volterra2.restype = None
volterra2.argtypes = (
    volterra2_ck,
    volterra2_cg,
    volterra2_cf,
    utils._BYREF_STRING, # Input, method(len=1).
    utils._BYREF_INT, # Input, iorder.
    utils._BYREF_FLOAT64, # Input, alim.
    utils._BYREF_FLOAT64, # Input, tlim.
    utils._EngineFloat64ArrayType.c_type, # Output, yn[nmesh].
    utils._EngineFloat64ArrayType.c_type, # Output, errest[nmesh].
    utils._BYREF_INT, # Input, nmesh.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_FLOAT64, # Input, thresh.
    utils._EngineFloat64ArrayType.c_type, # Output, work[lwk].
    utils._BYREF_INT, # Input, lwk.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of method.
)

abel2_weak_ck = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
abel2_weak_cf = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
abel2_weak_cg = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, s.
    utils._BYREF_FLOAT64, # Input, y.
)
abel2_weak = utils._EngineState._get_symbol('d05bdf')
abel2_weak.restype = None
abel2_weak.argtypes = (
    abel2_weak_ck,
    abel2_weak_cf,
    abel2_weak_cg,
    utils._BYREF_STRING, # Input, initwt(len=1).
    utils._BYREF_INT, # Input, iorder.
    utils._BYREF_FLOAT64, # Input, tlim.
    utils._BYREF_FLOAT64, # Input, tolnl.
    utils._BYREF_INT, # Input, nmesh.
    utils._EngineFloat64ArrayType.c_type, # Output, yn[nmesh].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, work[lwk].
    utils._BYREF_INT, # Input, lwk.
    utils._EngineIntArrayType.c_type, # Workspace, nct[nmesh/32+1].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of initwt.
)

abel1_weak_ck = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
abel1_weak_cf = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
abel1_weak_cg = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, s.
    utils._BYREF_FLOAT64, # Input, y.
)
abel1_weak = utils._EngineState._get_symbol('d05bef')
abel1_weak.restype = None
abel1_weak.argtypes = (
    abel1_weak_ck,
    abel1_weak_cf,
    abel1_weak_cg,
    utils._BYREF_STRING, # Input, initwt(len=1).
    utils._BYREF_INT, # Input, iorder.
    utils._BYREF_FLOAT64, # Input, tlim.
    utils._BYREF_FLOAT64, # Input, tolnl.
    utils._BYREF_INT, # Input, nmesh.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, yn[nmesh].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, work[lwk].
    utils._BYREF_INT, # Input, lwk.
    utils._EngineIntArrayType.c_type, # Workspace, nct[nmesh/32+1].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of initwt.
)

volterra_weights = utils._EngineState._get_symbol('d05bwf')
volterra_weights.restype = None
volterra_weights.argtypes = (
    utils._BYREF_STRING, # Input, method(len=1).
    utils._BYREF_INT, # Input, iorder.
    utils._EngineFloat64ArrayType.c_type, # Output, omega[nomg].
    utils._BYREF_INT, # Input, nomg.
    utils._BYREF_INT, # Output, lensw.
    utils._EngineFloat64ArrayType.c_type, # Output, sw[ldsw, nwt].
    utils._BYREF_INT, # Input, ldsw.
    utils._BYREF_INT, # Input, nwt.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of method.
)

abel_weak_weights = utils._EngineState._get_symbol('d05byf')
abel_weak_weights.restype = None
abel_weak_weights.argtypes = (
    utils._BYREF_INT, # Input, iorder.
    utils._BYREF_INT, # Input, iq.
    utils._BYREF_INT, # Input, lenfw.
    utils._EngineFloat64ArrayType.c_type, # Output, wt[lenfw].
    utils._EngineFloat64ArrayType.c_type, # Output, sw[ldsw, 2*iorder-1].
    utils._BYREF_INT, # Input, ldsw.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[lwk].
    utils._BYREF_INT, # Input, lwk.
    utils._BYREF_INT, # Input/Output, ifail.
)
