# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `lapacklin` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

dgesv = utils._EngineState._get_symbol('dgesv')
dgesv.restype = None
dgesv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07aaf = utils._EngineState._get_symbol('f07aaf')
f07aaf.restype = dgesv.restype
f07aaf.argtypes = dgesv.argtypes

dgesvx = utils._EngineState._get_symbol('dgesvx')
dgesvx.restype = None
dgesvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, work[max(1, 4*n)].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07abf = utils._EngineState._get_symbol('f07abf')
f07abf.restype = dgesvx.restype
f07abf.argtypes = dgesvx.argtypes

dsgesv = utils._EngineState._get_symbol('dsgesv')
dsgesv.restype = None
dsgesv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n*nrhs].
    utils._EngineFloat32ArrayType.c_type, # Workspace, swork[n*(n+nrhs)].
    utils._BYREF_INT, # Output, iter.
    utils._BYREF_INT, # Output, info.
)
f07acf = utils._EngineState._get_symbol('f07acf')
f07acf.restype = dsgesv.restype
f07acf.argtypes = dsgesv.argtypes

dgetrf = utils._EngineState._get_symbol('dgetrf')
dgetrf.restype = None
dgetrf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[min(m, n)].
    utils._BYREF_INT, # Output, info.
)
f07adf = utils._EngineState._get_symbol('f07adf')
f07adf.restype = dgetrf.restype
f07adf.argtypes = dgetrf.argtypes

dgetrs = utils._EngineState._get_symbol('dgetrs')
dgetrs.restype = None
dgetrs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07aef = utils._EngineState._get_symbol('f07aef')
f07aef.restype = dgetrs.restype
f07aef.argtypes = dgetrs.argtypes

dgeequ = utils._EngineState._get_symbol('dgeequ')
dgeequ.restype = None
dgeequ.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, r[m].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._BYREF_FLOAT64, # Output, rowcnd.
    utils._BYREF_FLOAT64, # Output, colcnd.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
)
f07aff = utils._EngineState._get_symbol('f07aff')
f07aff.restype = dgeequ.restype
f07aff.argtypes = dgeequ.argtypes

dgecon = utils._EngineState._get_symbol('dgecon')
dgecon.restype = None
dgecon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[4*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)
f07agf = utils._EngineState._get_symbol('f07agf')
f07agf.restype = dgecon.restype
f07agf.argtypes = dgecon.argtypes

dgerfs = utils._EngineState._get_symbol('dgerfs')
dgerfs.restype = None
dgerfs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07ahf = utils._EngineState._get_symbol('f07ahf')
f07ahf.restype = dgerfs.restype
f07ahf.argtypes = dgerfs.argtypes

dgetri = utils._EngineState._get_symbol('dgetri')
dgetri.restype = None
dgetri.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f07ajf = utils._EngineState._get_symbol('f07ajf')
f07ajf.restype = dgetri.restype
f07ajf.argtypes = dgetri.argtypes

zgesv = utils._EngineState._get_symbol('zgesv')
zgesv.restype = None
zgesv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07anf = utils._EngineState._get_symbol('f07anf')
f07anf.restype = zgesv.restype
f07anf.argtypes = zgesv.argtypes

zgesvx = utils._EngineState._get_symbol('zgesvx')
zgesvx.restype = None
zgesvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Output, rwork[max(1, 2*n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07apf = utils._EngineState._get_symbol('f07apf')
f07apf.restype = zgesvx.restype
f07apf.argtypes = zgesvx.argtypes

zcgesv = utils._EngineState._get_symbol('zcgesv')
zcgesv.restype = None
zcgesv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n*nrhs].
    utils._EngineComplex64ArrayType.c_type, # Workspace, swork[n*(n+nrhs)].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, iter.
    utils._BYREF_INT, # Output, info.
)
f07aqf = utils._EngineState._get_symbol('f07aqf')
f07aqf.restype = zcgesv.restype
f07aqf.argtypes = zcgesv.argtypes

zgetrf = utils._EngineState._get_symbol('zgetrf')
zgetrf.restype = None
zgetrf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[min(m, n)].
    utils._BYREF_INT, # Output, info.
)
f07arf = utils._EngineState._get_symbol('f07arf')
f07arf.restype = zgetrf.restype
f07arf.argtypes = zgetrf.argtypes

zgetrs = utils._EngineState._get_symbol('zgetrs')
zgetrs.restype = None
zgetrs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07asf = utils._EngineState._get_symbol('f07asf')
f07asf.restype = zgetrs.restype
f07asf.argtypes = zgetrs.argtypes

zgeequ = utils._EngineState._get_symbol('zgeequ')
zgeequ.restype = None
zgeequ.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, r[m].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._BYREF_FLOAT64, # Output, rowcnd.
    utils._BYREF_FLOAT64, # Output, colcnd.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
)
f07atf = utils._EngineState._get_symbol('f07atf')
f07atf.restype = zgeequ.restype
f07atf.argtypes = zgeequ.argtypes

zgecon = utils._EngineState._get_symbol('zgecon')
zgecon.restype = None
zgecon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)
f07auf = utils._EngineState._get_symbol('f07auf')
f07auf.restype = zgecon.restype
f07auf.argtypes = zgecon.argtypes

zgerfs = utils._EngineState._get_symbol('zgerfs')
zgerfs.restype = None
zgerfs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07avf = utils._EngineState._get_symbol('f07avf')
f07avf.restype = zgerfs.restype
f07avf.argtypes = zgerfs.argtypes

zgetri = utils._EngineState._get_symbol('zgetri')
zgetri.restype = None
zgetri.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f07awf = utils._EngineState._get_symbol('f07awf')
f07awf.restype = zgetri.restype
f07awf.argtypes = zgetri.argtypes

dgbsv = utils._EngineState._get_symbol('dgbsv')
dgbsv.restype = None
dgbsv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07baf = utils._EngineState._get_symbol('f07baf')
f07baf.restype = dgbsv.restype
f07baf.argtypes = dgbsv.argtypes

dgbsvx = utils._EngineState._get_symbol('dgbsvx')
dgbsvx.restype = None
dgbsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, work[max(1, 3*n)].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07bbf = utils._EngineState._get_symbol('f07bbf')
f07bbf.restype = dgbsvx.restype
f07bbf.argtypes = dgbsvx.argtypes

dgbtrf = utils._EngineState._get_symbol('dgbtrf')
dgbtrf.restype = None
dgbtrf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Output, ipiv[min(m, n)].
    utils._BYREF_INT, # Output, info.
)
f07bdf = utils._EngineState._get_symbol('f07bdf')
f07bdf.restype = dgbtrf.restype
f07bdf.argtypes = dgbtrf.argtypes

dgbtrs = utils._EngineState._get_symbol('dgbtrs')
dgbtrs.restype = None
dgbtrs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07bef = utils._EngineState._get_symbol('f07bef')
f07bef.restype = dgbtrs.restype
f07bef.argtypes = dgbtrs.argtypes

dgbequ = utils._EngineState._get_symbol('dgbequ')
dgbequ.restype = None
dgbequ.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, r[m].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._BYREF_FLOAT64, # Output, rowcnd.
    utils._BYREF_FLOAT64, # Output, colcnd.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
)
f07bff = utils._EngineState._get_symbol('f07bff')
f07bff.restype = dgbequ.restype
f07bff.argtypes = dgbequ.argtypes

dgbcon = utils._EngineState._get_symbol('dgbcon')
dgbcon.restype = None
dgbcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)
f07bgf = utils._EngineState._get_symbol('f07bgf')
f07bgf.restype = dgbcon.restype
f07bgf.argtypes = dgbcon.argtypes

dgbrfs = utils._EngineState._get_symbol('dgbrfs')
dgbrfs.restype = None
dgbrfs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07bhf = utils._EngineState._get_symbol('f07bhf')
f07bhf.restype = dgbrfs.restype
f07bhf.argtypes = dgbrfs.argtypes

zgbsv = utils._EngineState._get_symbol('zgbsv')
zgbsv.restype = None
zgbsv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07bnf = utils._EngineState._get_symbol('f07bnf')
f07bnf.restype = zgbsv.restype
f07bnf.argtypes = zgbsv.argtypes

zgbsvx = utils._EngineState._get_symbol('zgbsvx')
zgbsvx.restype = None
zgbsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Output, rwork[max(1, n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07bpf = utils._EngineState._get_symbol('f07bpf')
f07bpf.restype = zgbsvx.restype
f07bpf.argtypes = zgbsvx.argtypes

zgbtrf = utils._EngineState._get_symbol('zgbtrf')
zgbtrf.restype = None
zgbtrf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Output, ipiv[min(m, n)].
    utils._BYREF_INT, # Output, info.
)
f07brf = utils._EngineState._get_symbol('f07brf')
f07brf.restype = zgbtrf.restype
f07brf.argtypes = zgbtrf.argtypes

zgbtrs = utils._EngineState._get_symbol('zgbtrs')
zgbtrs.restype = None
zgbtrs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07bsf = utils._EngineState._get_symbol('f07bsf')
f07bsf.restype = zgbtrs.restype
f07bsf.argtypes = zgbtrs.argtypes

zgbequ = utils._EngineState._get_symbol('zgbequ')
zgbequ.restype = None
zgbequ.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, r[m].
    utils._EngineFloat64ArrayType.c_type, # Output, c[n].
    utils._BYREF_FLOAT64, # Output, rowcnd.
    utils._BYREF_FLOAT64, # Output, colcnd.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
)
f07btf = utils._EngineState._get_symbol('f07btf')
f07btf.restype = zgbequ.restype
f07btf.argtypes = zgbequ.argtypes

zgbcon = utils._EngineState._get_symbol('zgbcon')
zgbcon.restype = None
zgbcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)
f07buf = utils._EngineState._get_symbol('f07buf')
f07buf.restype = zgbcon.restype
f07buf.argtypes = zgbcon.argtypes

zgbrfs = utils._EngineState._get_symbol('zgbrfs')
zgbrfs.restype = None
zgbrfs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07bvf = utils._EngineState._get_symbol('f07bvf')
f07bvf.restype = zgbrfs.restype
f07bvf.argtypes = zgbrfs.argtypes

dgtsv = utils._EngineState._get_symbol('dgtsv')
dgtsv.restype = None
dgtsv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, du[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07caf = utils._EngineState._get_symbol('f07caf')
f07caf.restype = dgtsv.restype
f07caf.argtypes = dgtsv.argtypes

dgtsvx = utils._EngineState._get_symbol('dgtsvx')
dgtsvx.restype = None
dgtsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, dlf[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, df[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, duf[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, du2[*].
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07cbf = utils._EngineState._get_symbol('f07cbf')
f07cbf.restype = dgtsvx.restype
f07cbf.argtypes = dgtsvx.argtypes

dgttrf = utils._EngineState._get_symbol('dgttrf')
dgttrf.restype = None
dgttrf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, du[*].
    utils._EngineFloat64ArrayType.c_type, # Output, du2[n-2].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._BYREF_INT, # Output, info.
)
f07cdf = utils._EngineState._get_symbol('f07cdf')
f07cdf.restype = dgttrf.restype
f07cdf.argtypes = dgttrf.argtypes

dgttrs = utils._EngineState._get_symbol('dgttrs')
dgttrs.restype = None
dgttrs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du2[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07cef = utils._EngineState._get_symbol('f07cef')
f07cef.restype = dgttrs.restype
f07cef.argtypes = dgttrs.argtypes

dgtcon = utils._EngineState._get_symbol('dgtcon')
dgtcon.restype = None
dgtcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du2[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)
f07cgf = utils._EngineState._get_symbol('f07cgf')
f07cgf.restype = dgtcon.restype
f07cgf.argtypes = dgtcon.argtypes

dgtrfs = utils._EngineState._get_symbol('dgtrfs')
dgtrfs.restype = None
dgtrfs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, dl[*].
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du[*].
    utils._EngineFloat64ArrayType.c_type, # Input, dlf[*].
    utils._EngineFloat64ArrayType.c_type, # Input, df[*].
    utils._EngineFloat64ArrayType.c_type, # Input, duf[*].
    utils._EngineFloat64ArrayType.c_type, # Input, du2[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07chf = utils._EngineState._get_symbol('f07chf')
f07chf.restype = dgtrfs.restype
f07chf.argtypes = dgtrfs.argtypes

zgtsv = utils._EngineState._get_symbol('zgtsv')
zgtsv.restype = None
zgtsv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, du[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07cnf = utils._EngineState._get_symbol('f07cnf')
f07cnf.restype = zgtsv.restype
f07cnf.argtypes = zgtsv.argtypes

zgtsvx = utils._EngineState._get_symbol('zgtsvx')
zgtsvx.restype = None
zgtsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, dlf[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, df[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, duf[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, du2[*].
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07cpf = utils._EngineState._get_symbol('f07cpf')
f07cpf.restype = zgtsvx.restype
f07cpf.argtypes = zgtsvx.argtypes

zgttrf = utils._EngineState._get_symbol('zgttrf')
zgttrf.restype = None
zgttrf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, du[*].
    utils._EngineComplex128ArrayType.c_type, # Output, du2[n-2].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._BYREF_INT, # Output, info.
)
f07crf = utils._EngineState._get_symbol('f07crf')
f07crf.restype = zgttrf.restype
f07crf.argtypes = zgttrf.argtypes

zgttrs = utils._EngineState._get_symbol('zgttrs')
zgttrs.restype = None
zgttrs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du2[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07csf = utils._EngineState._get_symbol('f07csf')
f07csf.restype = zgttrs.restype
f07csf.argtypes = zgttrs.argtypes

zgtcon = utils._EngineState._get_symbol('zgtcon')
zgtcon.restype = None
zgtcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du2[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
)
f07cuf = utils._EngineState._get_symbol('f07cuf')
f07cuf.restype = zgtcon.restype
f07cuf.argtypes = zgtcon.argtypes

zgtrfs = utils._EngineState._get_symbol('zgtrfs')
zgtrfs.restype = None
zgtrfs.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, dl[*].
    utils._EngineComplex128ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du[*].
    utils._EngineComplex128ArrayType.c_type, # Input, dlf[*].
    utils._EngineComplex128ArrayType.c_type, # Input, df[*].
    utils._EngineComplex128ArrayType.c_type, # Input, duf[*].
    utils._EngineComplex128ArrayType.c_type, # Input, du2[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f07cvf = utils._EngineState._get_symbol('f07cvf')
f07cvf.restype = zgtrfs.restype
f07cvf.argtypes = zgtrfs.argtypes

dposv = utils._EngineState._get_symbol('dposv')
dposv.restype = None
dposv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07faf = utils._EngineState._get_symbol('f07faf')
f07faf.restype = dposv.restype
f07faf.argtypes = dposv.argtypes

dposvx = utils._EngineState._get_symbol('dposvx')
dposvx.restype = None
dposvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07fbf = utils._EngineState._get_symbol('f07fbf')
f07fbf.restype = dposvx.restype
f07fbf.argtypes = dposvx.argtypes

dsposv = utils._EngineState._get_symbol('dsposv')
dsposv.restype = None
dsposv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n, nrhs].
    utils._EngineFloat32ArrayType.c_type, # Workspace, swork[n*(n+nrhs)].
    utils._BYREF_INT, # Output, iter.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fcf = utils._EngineState._get_symbol('f07fcf')
f07fcf.restype = dsposv.restype
f07fcf.argtypes = dsposv.argtypes

dpotrf = utils._EngineState._get_symbol('dpotrf')
dpotrf.restype = None
dpotrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fdf = utils._EngineState._get_symbol('f07fdf')
f07fdf.restype = dpotrf.restype
f07fdf.argtypes = dpotrf.argtypes

dpotrs = utils._EngineState._get_symbol('dpotrs')
dpotrs.restype = None
dpotrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fef = utils._EngineState._get_symbol('f07fef')
f07fef.restype = dpotrs.restype
f07fef.argtypes = dpotrs.argtypes

dpoequ = utils._EngineState._get_symbol('dpoequ')
dpoequ.restype = None
dpoequ.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._BYREF_FLOAT64, # Output, scond.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
)
f07fff = utils._EngineState._get_symbol('f07fff')
f07fff.restype = dpoequ.restype
f07fff.argtypes = dpoequ.argtypes

dpocon = utils._EngineState._get_symbol('dpocon')
dpocon.restype = None
dpocon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fgf = utils._EngineState._get_symbol('f07fgf')
f07fgf.restype = dpocon.restype
f07fgf.argtypes = dpocon.argtypes

dporfs = utils._EngineState._get_symbol('dporfs')
dporfs.restype = None
dporfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fhf = utils._EngineState._get_symbol('f07fhf')
f07fhf.restype = dporfs.restype
f07fhf.argtypes = dporfs.argtypes

dpotri = utils._EngineState._get_symbol('dpotri')
dpotri.restype = None
dpotri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fjf = utils._EngineState._get_symbol('f07fjf')
f07fjf.restype = dpotri.restype
f07fjf.argtypes = dpotri.argtypes

zposv = utils._EngineState._get_symbol('zposv')
zposv.restype = None
zposv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fnf = utils._EngineState._get_symbol('f07fnf')
f07fnf.restype = zposv.restype
f07fnf.argtypes = zposv.argtypes

zposvx = utils._EngineState._get_symbol('zposvx')
zposvx.restype = None
zposvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07fpf = utils._EngineState._get_symbol('f07fpf')
f07fpf.restype = zposvx.restype
f07fpf.argtypes = zposvx.argtypes

zcposv = utils._EngineState._get_symbol('zcposv')
zcposv.restype = None
zcposv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n, nrhs].
    utils._EngineComplex64ArrayType.c_type, # Workspace, swork[n*(n+nrhs)].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, iter.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fqf = utils._EngineState._get_symbol('f07fqf')
f07fqf.restype = zcposv.restype
f07fqf.argtypes = zcposv.argtypes

zpotrf = utils._EngineState._get_symbol('zpotrf')
zpotrf.restype = None
zpotrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07frf = utils._EngineState._get_symbol('f07frf')
f07frf.restype = zpotrf.restype
f07frf.argtypes = zpotrf.argtypes

zpotrs = utils._EngineState._get_symbol('zpotrs')
zpotrs.restype = None
zpotrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fsf = utils._EngineState._get_symbol('f07fsf')
f07fsf.restype = zpotrs.restype
f07fsf.argtypes = zpotrs.argtypes

zpoequ = utils._EngineState._get_symbol('zpoequ')
zpoequ.restype = None
zpoequ.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._BYREF_FLOAT64, # Output, scond.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
)
f07ftf = utils._EngineState._get_symbol('f07ftf')
f07ftf.restype = zpoequ.restype
f07ftf.argtypes = zpoequ.argtypes

zpocon = utils._EngineState._get_symbol('zpocon')
zpocon.restype = None
zpocon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fuf = utils._EngineState._get_symbol('f07fuf')
f07fuf.restype = zpocon.restype
f07fuf.argtypes = zpocon.argtypes

zporfs = utils._EngineState._get_symbol('zporfs')
zporfs.restype = None
zporfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fvf = utils._EngineState._get_symbol('f07fvf')
f07fvf.restype = zporfs.restype
f07fvf.argtypes = zporfs.argtypes

zpotri = utils._EngineState._get_symbol('zpotri')
zpotri.restype = None
zpotri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07fwf = utils._EngineState._get_symbol('f07fwf')
f07fwf.restype = zpotri.restype
f07fwf.argtypes = zpotri.argtypes

dppsv = utils._EngineState._get_symbol('dppsv')
dppsv.restype = None
dppsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gaf = utils._EngineState._get_symbol('f07gaf')
f07gaf.restype = dppsv.restype
f07gaf.argtypes = dppsv.argtypes

dppsvx = utils._EngineState._get_symbol('dppsvx')
dppsvx.restype = None
dppsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, afp[*].
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07gbf = utils._EngineState._get_symbol('f07gbf')
f07gbf.restype = dppsvx.restype
f07gbf.argtypes = dppsvx.argtypes

dpptrf = utils._EngineState._get_symbol('dpptrf')
dpptrf.restype = None
dpptrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gdf = utils._EngineState._get_symbol('f07gdf')
f07gdf.restype = dpptrf.restype
f07gdf.argtypes = dpptrf.argtypes

dpptrs = utils._EngineState._get_symbol('dpptrs')
dpptrs.restype = None
dpptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gef = utils._EngineState._get_symbol('f07gef')
f07gef.restype = dpptrs.restype
f07gef.argtypes = dpptrs.argtypes

dppequ = utils._EngineState._get_symbol('dppequ')
dppequ.restype = None
dppequ.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._BYREF_FLOAT64, # Output, scond.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gff = utils._EngineState._get_symbol('f07gff')
f07gff.restype = dppequ.restype
f07gff.argtypes = dppequ.argtypes

dppcon = utils._EngineState._get_symbol('dppcon')
dppcon.restype = None
dppcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07ggf = utils._EngineState._get_symbol('f07ggf')
f07ggf.restype = dppcon.restype
f07ggf.argtypes = dppcon.argtypes

dpprfs = utils._EngineState._get_symbol('dpprfs')
dpprfs.restype = None
dpprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, afp[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07ghf = utils._EngineState._get_symbol('f07ghf')
f07ghf.restype = dpprfs.restype
f07ghf.argtypes = dpprfs.argtypes

dpptri = utils._EngineState._get_symbol('dpptri')
dpptri.restype = None
dpptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gjf = utils._EngineState._get_symbol('f07gjf')
f07gjf.restype = dpptri.restype
f07gjf.argtypes = dpptri.argtypes

zppsv = utils._EngineState._get_symbol('zppsv')
zppsv.restype = None
zppsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gnf = utils._EngineState._get_symbol('f07gnf')
f07gnf.restype = zppsv.restype
f07gnf.argtypes = zppsv.argtypes

zppsvx = utils._EngineState._get_symbol('zppsvx')
zppsvx.restype = None
zppsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, afp[*].
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07gpf = utils._EngineState._get_symbol('f07gpf')
f07gpf.restype = zppsvx.restype
f07gpf.argtypes = zppsvx.argtypes

zpptrf = utils._EngineState._get_symbol('zpptrf')
zpptrf.restype = None
zpptrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07grf = utils._EngineState._get_symbol('f07grf')
f07grf.restype = zpptrf.restype
f07grf.argtypes = zpptrf.argtypes

zpptrs = utils._EngineState._get_symbol('zpptrs')
zpptrs.restype = None
zpptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gsf = utils._EngineState._get_symbol('f07gsf')
f07gsf.restype = zpptrs.restype
f07gsf.argtypes = zpptrs.argtypes

zppequ = utils._EngineState._get_symbol('zppequ')
zppequ.restype = None
zppequ.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._BYREF_FLOAT64, # Output, scond.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gtf = utils._EngineState._get_symbol('f07gtf')
f07gtf.restype = zppequ.restype
f07gtf.argtypes = zppequ.argtypes

zppcon = utils._EngineState._get_symbol('zppcon')
zppcon.restype = None
zppcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07guf = utils._EngineState._get_symbol('f07guf')
f07guf.restype = zppcon.restype
f07guf.argtypes = zppcon.argtypes

zpprfs = utils._EngineState._get_symbol('zpprfs')
zpprfs.restype = None
zpprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, afp[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gvf = utils._EngineState._get_symbol('f07gvf')
f07gvf.restype = zpprfs.restype
f07gvf.argtypes = zpprfs.argtypes

zpptri = utils._EngineState._get_symbol('zpptri')
zpptri.restype = None
zpptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07gwf = utils._EngineState._get_symbol('f07gwf')
f07gwf.restype = zpptri.restype
f07gwf.argtypes = zpptri.argtypes

dpbsv = utils._EngineState._get_symbol('dpbsv')
dpbsv.restype = None
dpbsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07haf = utils._EngineState._get_symbol('f07haf')
f07haf.restype = dpbsv.restype
f07haf.argtypes = dpbsv.argtypes

dpbsvx = utils._EngineState._get_symbol('dpbsvx')
dpbsvx.restype = None
dpbsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07hbf = utils._EngineState._get_symbol('f07hbf')
f07hbf.restype = dpbsvx.restype
f07hbf.argtypes = dpbsvx.argtypes

dpbtrf = utils._EngineState._get_symbol('dpbtrf')
dpbtrf.restype = None
dpbtrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hdf = utils._EngineState._get_symbol('f07hdf')
f07hdf.restype = dpbtrf.restype
f07hdf.argtypes = dpbtrf.argtypes

dpbtrs = utils._EngineState._get_symbol('dpbtrs')
dpbtrs.restype = None
dpbtrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hef = utils._EngineState._get_symbol('f07hef')
f07hef.restype = dpbtrs.restype
f07hef.argtypes = dpbtrs.argtypes

dpbequ = utils._EngineState._get_symbol('dpbequ')
dpbequ.restype = None
dpbequ.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._BYREF_FLOAT64, # Output, scond.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hff = utils._EngineState._get_symbol('f07hff')
f07hff.restype = dpbequ.restype
f07hff.argtypes = dpbequ.argtypes

dpbcon = utils._EngineState._get_symbol('dpbcon')
dpbcon.restype = None
dpbcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hgf = utils._EngineState._get_symbol('f07hgf')
f07hgf.restype = dpbcon.restype
f07hgf.argtypes = dpbcon.argtypes

dpbrfs = utils._EngineState._get_symbol('dpbrfs')
dpbrfs.restype = None
dpbrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hhf = utils._EngineState._get_symbol('f07hhf')
f07hhf.restype = dpbrfs.restype
f07hhf.argtypes = dpbrfs.argtypes

zpbsv = utils._EngineState._get_symbol('zpbsv')
zpbsv.restype = None
zpbsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hnf = utils._EngineState._get_symbol('f07hnf')
f07hnf.restype = zpbsv.restype
f07hnf.argtypes = zpbsv.argtypes

zpbsvx = utils._EngineState._get_symbol('zpbsvx')
zpbsvx.restype = None
zpbsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._BYREF_STRING, # Input/Output, equed(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equed.
)
f07hpf = utils._EngineState._get_symbol('f07hpf')
f07hpf.restype = zpbsvx.restype
f07hpf.argtypes = zpbsvx.argtypes

zpbtrf = utils._EngineState._get_symbol('zpbtrf')
zpbtrf.restype = None
zpbtrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hrf = utils._EngineState._get_symbol('f07hrf')
f07hrf.restype = zpbtrf.restype
f07hrf.argtypes = zpbtrf.argtypes

zpbtrs = utils._EngineState._get_symbol('zpbtrs')
zpbtrs.restype = None
zpbtrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hsf = utils._EngineState._get_symbol('f07hsf')
f07hsf.restype = zpbtrs.restype
f07hsf.argtypes = zpbtrs.argtypes

zpbequ = utils._EngineState._get_symbol('zpbequ')
zpbequ.restype = None
zpbequ.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._BYREF_FLOAT64, # Output, scond.
    utils._BYREF_FLOAT64, # Output, amax.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07htf = utils._EngineState._get_symbol('f07htf')
f07htf.restype = zpbequ.restype
f07htf.argtypes = zpbequ.argtypes

zpbcon = utils._EngineState._get_symbol('zpbcon')
zpbcon.restype = None
zpbcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07huf = utils._EngineState._get_symbol('f07huf')
f07huf.restype = zpbcon.restype
f07huf.argtypes = zpbcon.argtypes

zpbrfs = utils._EngineState._get_symbol('zpbrfs')
zpbrfs.restype = None
zpbrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input, afb[ldafb, *].
    utils._BYREF_INT, # Input, ldafb.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07hvf = utils._EngineState._get_symbol('f07hvf')
f07hvf.restype = zpbrfs.restype
f07hvf.argtypes = zpbrfs.argtypes

dptsv = utils._EngineState._get_symbol('dptsv')
dptsv.restype = None
dptsv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07jaf = utils._EngineState._get_symbol('f07jaf')
f07jaf.restype = dptsv.restype
f07jaf.argtypes = dptsv.argtypes

dptsvx = utils._EngineState._get_symbol('dptsvx')
dptsvx.restype = None
dptsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, df[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ef[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
)
f07jbf = utils._EngineState._get_symbol('f07jbf')
f07jbf.restype = dptsvx.restype
f07jbf.argtypes = dptsvx.argtypes

dpttrf = utils._EngineState._get_symbol('dpttrf')
dpttrf.restype = None
dpttrf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_INT, # Output, info.
)
f07jdf = utils._EngineState._get_symbol('f07jdf')
f07jdf.restype = dpttrf.restype
f07jdf.argtypes = dpttrf.argtypes

dpttrs = utils._EngineState._get_symbol('dpttrs')
dpttrs.restype = None
dpttrs.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07jef = utils._EngineState._get_symbol('f07jef')
f07jef.restype = dpttrs.restype
f07jef.argtypes = dpttrs.argtypes

dptcon = utils._EngineState._get_symbol('dptcon')
dptcon.restype = None
dptcon.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
)
f07jgf = utils._EngineState._get_symbol('f07jgf')
f07jgf.restype = dptcon.restype
f07jgf.argtypes = dptcon.argtypes

dptrfs = utils._EngineState._get_symbol('dptrfs')
dptrfs.restype = None
dptrfs.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input, df[*].
    utils._EngineFloat64ArrayType.c_type, # Input, ef[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
)
f07jhf = utils._EngineState._get_symbol('f07jhf')
f07jhf.restype = dptrfs.restype
f07jhf.argtypes = dptrfs.argtypes

zptsv = utils._EngineState._get_symbol('zptsv')
zptsv.restype = None
zptsv.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
)
f07jnf = utils._EngineState._get_symbol('f07jnf')
f07jnf.restype = zptsv.restype
f07jnf.argtypes = zptsv.argtypes

zptsvx = utils._EngineState._get_symbol('zptsvx')
zptsvx.restype = None
zptsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, df[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ef[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
)
f07jpf = utils._EngineState._get_symbol('f07jpf')
f07jpf.restype = zptsvx.restype
f07jpf.argtypes = zptsvx.argtypes

zpttrf = utils._EngineState._get_symbol('zpttrf')
zpttrf.restype = None
zpttrf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_INT, # Output, info.
)
f07jrf = utils._EngineState._get_symbol('f07jrf')
f07jrf.restype = zpttrf.restype
f07jrf.argtypes = zpttrf.argtypes

zpttrs = utils._EngineState._get_symbol('zpttrs')
zpttrs.restype = None
zpttrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07jsf = utils._EngineState._get_symbol('f07jsf')
f07jsf.restype = zpttrs.restype
f07jsf.argtypes = zpttrs.argtypes

zptcon = utils._EngineState._get_symbol('zptcon')
zptcon.restype = None
zptcon.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, e[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
)
f07juf = utils._EngineState._get_symbol('f07juf')
f07juf.restype = zptcon.restype
f07juf.argtypes = zptcon.argtypes

zptrfs = utils._EngineState._get_symbol('zptrfs')
zptrfs.restype = None
zptrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineComplex128ArrayType.c_type, # Input, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input, df[*].
    utils._EngineComplex128ArrayType.c_type, # Input, ef[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07jvf = utils._EngineState._get_symbol('f07jvf')
f07jvf.restype = zptrfs.restype
f07jvf.argtypes = zptrfs.argtypes

dpstrf = utils._EngineState._get_symbol('dpstrf')
dpstrf.restype = None
dpstrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, piv[n].
    utils._BYREF_INT, # Output, rank.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07kdf = utils._EngineState._get_symbol('f07kdf')
f07kdf.restype = dpstrf.restype
f07kdf.argtypes = dpstrf.argtypes

zpstrf = utils._EngineState._get_symbol('zpstrf')
zpstrf.restype = None
zpstrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, piv[n].
    utils._BYREF_INT, # Output, rank.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07krf = utils._EngineState._get_symbol('f07krf')
f07krf.restype = zpstrf.restype
f07krf.argtypes = zpstrf.argtypes

dsysv = utils._EngineState._get_symbol('dsysv')
dsysv.restype = None
dsysv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07maf = utils._EngineState._get_symbol('f07maf')
f07maf.restype = dsysv.restype
f07maf.argtypes = dsysv.argtypes

dsysvx = utils._EngineState._get_symbol('dsysvx')
dsysvx.restype = None
dsysvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mbf = utils._EngineState._get_symbol('f07mbf')
f07mbf.restype = dsysvx.restype
f07mbf.argtypes = dsysvx.argtypes

dsytrf = utils._EngineState._get_symbol('dsytrf')
dsytrf.restype = None
dsytrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mdf = utils._EngineState._get_symbol('f07mdf')
f07mdf.restype = dsytrf.restype
f07mdf.argtypes = dsytrf.argtypes

dsytrs = utils._EngineState._get_symbol('dsytrs')
dsytrs.restype = None
dsytrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mef = utils._EngineState._get_symbol('f07mef')
f07mef.restype = dsytrs.restype
f07mef.argtypes = dsytrs.argtypes

dsycon = utils._EngineState._get_symbol('dsycon')
dsycon.restype = None
dsycon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mgf = utils._EngineState._get_symbol('f07mgf')
f07mgf.restype = dsycon.restype
f07mgf.argtypes = dsycon.argtypes

dsyrfs = utils._EngineState._get_symbol('dsyrfs')
dsyrfs.restype = None
dsyrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mhf = utils._EngineState._get_symbol('f07mhf')
f07mhf.restype = dsyrfs.restype
f07mhf.argtypes = dsyrfs.argtypes

dsytri = utils._EngineState._get_symbol('dsytri')
dsytri.restype = None
dsytri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mjf = utils._EngineState._get_symbol('f07mjf')
f07mjf.restype = dsytri.restype
f07mjf.argtypes = dsytri.argtypes

zhesv = utils._EngineState._get_symbol('zhesv')
zhesv.restype = None
zhesv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mnf = utils._EngineState._get_symbol('f07mnf')
f07mnf.restype = zhesv.restype
f07mnf.argtypes = zhesv.argtypes

zhesvx = utils._EngineState._get_symbol('zhesvx')
zhesvx.restype = None
zhesvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mpf = utils._EngineState._get_symbol('f07mpf')
f07mpf.restype = zhesvx.restype
f07mpf.argtypes = zhesvx.argtypes

zhetrf = utils._EngineState._get_symbol('zhetrf')
zhetrf.restype = None
zhetrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mrf = utils._EngineState._get_symbol('f07mrf')
f07mrf.restype = zhetrf.restype
f07mrf.argtypes = zhetrf.argtypes

zhetrs = utils._EngineState._get_symbol('zhetrs')
zhetrs.restype = None
zhetrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07msf = utils._EngineState._get_symbol('f07msf')
f07msf.restype = zhetrs.restype
f07msf.argtypes = zhetrs.argtypes

zhecon = utils._EngineState._get_symbol('zhecon')
zhecon.restype = None
zhecon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07muf = utils._EngineState._get_symbol('f07muf')
f07muf.restype = zhecon.restype
f07muf.argtypes = zhecon.argtypes

zherfs = utils._EngineState._get_symbol('zherfs')
zherfs.restype = None
zherfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mvf = utils._EngineState._get_symbol('f07mvf')
f07mvf.restype = zherfs.restype
f07mvf.argtypes = zherfs.argtypes

zhetri = utils._EngineState._get_symbol('zhetri')
zhetri.restype = None
zhetri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07mwf = utils._EngineState._get_symbol('f07mwf')
f07mwf.restype = zhetri.restype
f07mwf.argtypes = zhetri.argtypes

zsysv = utils._EngineState._get_symbol('zsysv')
zsysv.restype = None
zsysv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07nnf = utils._EngineState._get_symbol('f07nnf')
f07nnf.restype = zsysv.restype
f07nnf.argtypes = zsysv.argtypes

zsysvx = utils._EngineState._get_symbol('zsysvx')
zsysvx.restype = None
zsysvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07npf = utils._EngineState._get_symbol('f07npf')
f07npf.restype = zsysvx.restype
f07npf.argtypes = zsysvx.argtypes

zsytrf = utils._EngineState._get_symbol('zsytrf')
zsytrf.restype = None
zsytrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Output, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07nrf = utils._EngineState._get_symbol('f07nrf')
f07nrf.restype = zsytrf.restype
f07nrf.argtypes = zsytrf.argtypes

zsytrs = utils._EngineState._get_symbol('zsytrs')
zsytrs.restype = None
zsytrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07nsf = utils._EngineState._get_symbol('f07nsf')
f07nsf.restype = zsytrs.restype
f07nsf.argtypes = zsytrs.argtypes

zsycon = utils._EngineState._get_symbol('zsycon')
zsycon.restype = None
zsycon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07nuf = utils._EngineState._get_symbol('f07nuf')
f07nuf.restype = zsycon.restype
f07nuf.argtypes = zsycon.argtypes

zsyrfs = utils._EngineState._get_symbol('zsyrfs')
zsyrfs.restype = None
zsyrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, af[ldaf, *].
    utils._BYREF_INT, # Input, ldaf.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07nvf = utils._EngineState._get_symbol('f07nvf')
f07nvf.restype = zsyrfs.restype
f07nvf.argtypes = zsyrfs.argtypes

zsytri = utils._EngineState._get_symbol('zsytri')
zsytri.restype = None
zsytri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07nwf = utils._EngineState._get_symbol('f07nwf')
f07nwf.restype = zsytri.restype
f07nwf.argtypes = zsytri.argtypes

dspsv = utils._EngineState._get_symbol('dspsv')
dspsv.restype = None
dspsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07paf = utils._EngineState._get_symbol('f07paf')
f07paf.restype = dspsv.restype
f07paf.argtypes = dspsv.argtypes

dspsvx = utils._EngineState._get_symbol('dspsvx')
dspsvx.restype = None
dspsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, afp[*].
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[n].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pbf = utils._EngineState._get_symbol('f07pbf')
f07pbf.restype = dspsvx.restype
f07pbf.argtypes = dspsvx.argtypes

dsptrf = utils._EngineState._get_symbol('dsptrf')
dsptrf.restype = None
dsptrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pdf = utils._EngineState._get_symbol('f07pdf')
f07pdf.restype = dsptrf.restype
f07pdf.argtypes = dsptrf.argtypes

dsptrs = utils._EngineState._get_symbol('dsptrs')
dsptrs.restype = None
dsptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pef = utils._EngineState._get_symbol('f07pef')
f07pef.restype = dsptrs.restype
f07pef.argtypes = dsptrs.argtypes

dspcon = utils._EngineState._get_symbol('dspcon')
dspcon.restype = None
dspcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pgf = utils._EngineState._get_symbol('f07pgf')
f07pgf.restype = dspcon.restype
f07pgf.argtypes = dspcon.argtypes

dsprfs = utils._EngineState._get_symbol('dsprfs')
dsprfs.restype = None
dsprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, afp[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07phf = utils._EngineState._get_symbol('f07phf')
f07phf.restype = dsprfs.restype
f07phf.argtypes = dsprfs.argtypes

dsptri = utils._EngineState._get_symbol('dsptri')
dsptri.restype = None
dsptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pjf = utils._EngineState._get_symbol('f07pjf')
f07pjf.restype = dsptri.restype
f07pjf.argtypes = dsptri.argtypes

zhpsv = utils._EngineState._get_symbol('zhpsv')
zhpsv.restype = None
zhpsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pnf = utils._EngineState._get_symbol('f07pnf')
f07pnf.restype = zhpsv.restype
f07pnf.argtypes = zhpsv.argtypes

zhpsvx = utils._EngineState._get_symbol('zhpsvx')
zhpsvx.restype = None
zhpsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, afp[*].
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07ppf = utils._EngineState._get_symbol('f07ppf')
f07ppf.restype = zhpsvx.restype
f07ppf.argtypes = zhpsvx.argtypes

zhptrf = utils._EngineState._get_symbol('zhptrf')
zhptrf.restype = None
zhptrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07prf = utils._EngineState._get_symbol('f07prf')
f07prf.restype = zhptrf.restype
f07prf.argtypes = zhptrf.argtypes

zhptrs = utils._EngineState._get_symbol('zhptrs')
zhptrs.restype = None
zhptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07psf = utils._EngineState._get_symbol('f07psf')
f07psf.restype = zhptrs.restype
f07psf.argtypes = zhptrs.argtypes

zhpcon = utils._EngineState._get_symbol('zhpcon')
zhpcon.restype = None
zhpcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07puf = utils._EngineState._get_symbol('f07puf')
f07puf.restype = zhpcon.restype
f07puf.argtypes = zhpcon.argtypes

zhprfs = utils._EngineState._get_symbol('zhprfs')
zhprfs.restype = None
zhprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, afp[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pvf = utils._EngineState._get_symbol('f07pvf')
f07pvf.restype = zhprfs.restype
f07pvf.argtypes = zhprfs.argtypes

zhptri = utils._EngineState._get_symbol('zhptri')
zhptri.restype = None
zhptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07pwf = utils._EngineState._get_symbol('f07pwf')
f07pwf.restype = zhptri.restype
f07pwf.argtypes = zhptri.argtypes

zspsv = utils._EngineState._get_symbol('zspsv')
zspsv.restype = None
zspsv.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07qnf = utils._EngineState._get_symbol('f07qnf')
f07qnf.restype = zspsv.restype
f07qnf.argtypes = zspsv.argtypes

zspsvx = utils._EngineState._get_symbol('zspsvx')
zspsvx.restype = None
zspsvx.argtypes = (
    utils._BYREF_STRING, # Input, fact(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, afp[*].
    utils._EngineIntArrayType.c_type, # Input/Output, ipiv[n].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fact.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07qpf = utils._EngineState._get_symbol('f07qpf')
f07qpf.restype = zspsvx.restype
f07qpf.argtypes = zspsvx.argtypes

zsptrf = utils._EngineState._get_symbol('zsptrf')
zsptrf.restype = None
zsptrf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07qrf = utils._EngineState._get_symbol('f07qrf')
f07qrf.restype = zsptrf.restype
f07qrf.argtypes = zsptrf.argtypes

zsptrs = utils._EngineState._get_symbol('zsptrs')
zsptrs.restype = None
zsptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07qsf = utils._EngineState._get_symbol('f07qsf')
f07qsf.restype = zsptrs.restype
f07qsf.argtypes = zsptrs.argtypes

zspcon = utils._EngineState._get_symbol('zspcon')
zspcon.restype = None
zspcon.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._BYREF_FLOAT64, # Input, anorm.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07quf = utils._EngineState._get_symbol('f07quf')
f07quf.restype = zspcon.restype
f07quf.argtypes = zspcon.argtypes

zsprfs = utils._EngineState._get_symbol('zsprfs')
zsprfs.restype = None
zsprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, afp[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07qvf = utils._EngineState._get_symbol('f07qvf')
f07qvf.restype = zsprfs.restype
f07qvf.argtypes = zsprfs.argtypes

zsptri = utils._EngineState._get_symbol('zsptri')
zsptri.restype = None
zsptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineIntArrayType.c_type, # Input, ipiv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07qwf = utils._EngineState._get_symbol('f07qwf')
f07qwf.restype = zsptri.restype
f07qwf.argtypes = zsptri.argtypes

dtrtrs = utils._EngineState._get_symbol('dtrtrs')
dtrtrs.restype = None
dtrtrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07tef = utils._EngineState._get_symbol('f07tef')
f07tef.restype = dtrtrs.restype
f07tef.argtypes = dtrtrs.argtypes

dtrcon = utils._EngineState._get_symbol('dtrcon')
dtrcon.restype = None
dtrcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07tgf = utils._EngineState._get_symbol('f07tgf')
f07tgf.restype = dtrcon.restype
f07tgf.argtypes = dtrcon.argtypes

dtrrfs = utils._EngineState._get_symbol('dtrrfs')
dtrrfs.restype = None
dtrrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07thf = utils._EngineState._get_symbol('f07thf')
f07thf.restype = dtrrfs.restype
f07thf.argtypes = dtrrfs.argtypes

dtrtri = utils._EngineState._get_symbol('dtrtri')
dtrtri.restype = None
dtrtri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07tjf = utils._EngineState._get_symbol('f07tjf')
f07tjf.restype = dtrtri.restype
f07tjf.argtypes = dtrtri.argtypes

ztrtrs = utils._EngineState._get_symbol('ztrtrs')
ztrtrs.restype = None
ztrtrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07tsf = utils._EngineState._get_symbol('f07tsf')
f07tsf.restype = ztrtrs.restype
f07tsf.argtypes = ztrtrs.argtypes

ztrcon = utils._EngineState._get_symbol('ztrcon')
ztrcon.restype = None
ztrcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07tuf = utils._EngineState._get_symbol('f07tuf')
f07tuf.restype = ztrcon.restype
f07tuf.argtypes = ztrcon.argtypes

ztrrfs = utils._EngineState._get_symbol('ztrrfs')
ztrrfs.restype = None
ztrrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07tvf = utils._EngineState._get_symbol('f07tvf')
f07tvf.restype = ztrrfs.restype
f07tvf.argtypes = ztrrfs.argtypes

ztrtri = utils._EngineState._get_symbol('ztrtri')
ztrtri.restype = None
ztrtri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07twf = utils._EngineState._get_symbol('f07twf')
f07twf.restype = ztrtri.restype
f07twf.argtypes = ztrtri.argtypes

dtptrs = utils._EngineState._get_symbol('dtptrs')
dtptrs.restype = None
dtptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07uef = utils._EngineState._get_symbol('f07uef')
f07uef.restype = dtptrs.restype
f07uef.argtypes = dtptrs.argtypes

dtpcon = utils._EngineState._get_symbol('dtpcon')
dtpcon.restype = None
dtpcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07ugf = utils._EngineState._get_symbol('f07ugf')
f07ugf.restype = dtpcon.restype
f07ugf.argtypes = dtpcon.argtypes

dtprfs = utils._EngineState._get_symbol('dtprfs')
dtprfs.restype = None
dtprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07uhf = utils._EngineState._get_symbol('f07uhf')
f07uhf.restype = dtprfs.restype
f07uhf.argtypes = dtprfs.argtypes

dtptri = utils._EngineState._get_symbol('dtptri')
dtptri.restype = None
dtptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07ujf = utils._EngineState._get_symbol('f07ujf')
f07ujf.restype = dtptri.restype
f07ujf.argtypes = dtptri.argtypes

ztptrs = utils._EngineState._get_symbol('ztptrs')
ztptrs.restype = None
ztptrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07usf = utils._EngineState._get_symbol('f07usf')
f07usf.restype = ztptrs.restype
f07usf.argtypes = ztptrs.argtypes

ztpcon = utils._EngineState._get_symbol('ztpcon')
ztpcon.restype = None
ztpcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07uuf = utils._EngineState._get_symbol('f07uuf')
f07uuf.restype = ztpcon.restype
f07uuf.argtypes = ztpcon.argtypes

ztprfs = utils._EngineState._get_symbol('ztprfs')
ztprfs.restype = None
ztprfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07uvf = utils._EngineState._get_symbol('f07uvf')
f07uvf.restype = ztprfs.restype
f07uvf.argtypes = ztprfs.argtypes

ztptri = utils._EngineState._get_symbol('ztptri')
ztptri.restype = None
ztptri.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07uwf = utils._EngineState._get_symbol('f07uwf')
f07uwf.restype = ztptri.restype
f07uwf.argtypes = ztptri.argtypes

dtbtrs = utils._EngineState._get_symbol('dtbtrs')
dtbtrs.restype = None
dtbtrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07vef = utils._EngineState._get_symbol('f07vef')
f07vef.restype = dtbtrs.restype
f07vef.argtypes = dtbtrs.argtypes

dtbcon = utils._EngineState._get_symbol('dtbcon')
dtbcon.restype = None
dtbcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07vgf = utils._EngineState._get_symbol('f07vgf')
f07vgf.restype = dtbcon.restype
f07vgf.argtypes = dtbcon.argtypes

dtbrfs = utils._EngineState._get_symbol('dtbrfs')
dtbrfs.restype = None
dtbrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07vhf = utils._EngineState._get_symbol('f07vhf')
f07vhf.restype = dtbrfs.restype
f07vhf.argtypes = dtbrfs.argtypes

ztbtrs = utils._EngineState._get_symbol('ztbtrs')
ztbtrs.restype = None
ztbtrs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07vsf = utils._EngineState._get_symbol('f07vsf')
f07vsf.restype = ztbtrs.restype
f07vsf.argtypes = ztbtrs.argtypes

ztbcon = utils._EngineState._get_symbol('ztbcon')
ztbcon.restype = None
ztbcon.argtypes = (
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._BYREF_FLOAT64, # Output, rcond.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07vuf = utils._EngineState._get_symbol('f07vuf')
f07vuf.restype = ztbcon.restype
f07vuf.argtypes = ztbcon.argtypes

ztbrfs = utils._EngineState._get_symbol('ztbrfs')
ztbrfs.restype = None
ztbrfs.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, ferr[nrhs].
    utils._EngineFloat64ArrayType.c_type, # Output, berr[nrhs].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07vvf = utils._EngineState._get_symbol('f07vvf')
f07vvf.restype = ztbrfs.restype
f07vvf.argtypes = ztbrfs.argtypes

dpftrf = utils._EngineState._get_symbol('dpftrf')
dpftrf.restype = None
dpftrf.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07wdf = utils._EngineState._get_symbol('f07wdf')
f07wdf.restype = dpftrf.restype
f07wdf.argtypes = dpftrf.argtypes

dpftrs = utils._EngineState._get_symbol('dpftrs')
dpftrs.restype = None
dpftrs.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input, ar[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07wef = utils._EngineState._get_symbol('f07wef')
f07wef.restype = dpftrs.restype
f07wef.argtypes = dpftrs.argtypes

dpftri = utils._EngineState._get_symbol('dpftri')
dpftri.restype = None
dpftri.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07wjf = utils._EngineState._get_symbol('f07wjf')
f07wjf.restype = dpftri.restype
f07wjf.argtypes = dpftri.argtypes

dtftri = utils._EngineState._get_symbol('dtftri')
dtftri.restype = None
dtftri.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07wkf = utils._EngineState._get_symbol('f07wkf')
f07wkf.restype = dtftri.restype
f07wkf.argtypes = dtftri.argtypes

zpftrf = utils._EngineState._get_symbol('zpftrf')
zpftrf.restype = None
zpftrf.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07wrf = utils._EngineState._get_symbol('f07wrf')
f07wrf.restype = zpftrf.restype
f07wrf.argtypes = zpftrf.argtypes

zpftrs = utils._EngineState._get_symbol('zpftrs')
zpftrs.restype = None
zpftrs.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input, ar[n*(n+1)/2].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07wsf = utils._EngineState._get_symbol('f07wsf')
f07wsf.restype = zpftrs.restype
f07wsf.argtypes = zpftrs.argtypes

zpftri = utils._EngineState._get_symbol('zpftri')
zpftri.restype = None
zpftri.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f07wwf = utils._EngineState._get_symbol('f07wwf')
f07wwf.restype = zpftri.restype
f07wwf.argtypes = zpftri.argtypes

ztftri = utils._EngineState._get_symbol('ztftri')
ztftri.restype = None
ztftri.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)
f07wxf = utils._EngineState._get_symbol('f07wxf')
f07wxf.restype = ztftri.restype
f07wxf.argtypes = ztftri.argtypes
