# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `mesh` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

dim2_gen_inc = utils._EngineState._get_symbol('d06aaf')
dim2_gen_inc.restype = None
dim2_gen_inc.argtypes = (
    utils._BYREF_INT, # Input, nvb.
    utils._BYREF_INT, # Input, nvmax.
    utils._BYREF_INT, # Input, nedge.
    utils._EngineIntArrayType.c_type, # Input, edge[3, nedge].
    utils._BYREF_INT, # Output, nv.
    utils._BYREF_INT, # Output, nelt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, coor[2, nvmax].
    utils._EngineIntArrayType.c_type, # Output, conn[3, 2*(nvmax-1)].
    utils._EngineFloat64ArrayType.c_type, # Input, bspace[nvb].
    utils._BYREF_LOGICAL, # Input, smooth.
    utils._BYREF_FLOAT64, # Input, coef.
    utils._BYREF_FLOAT64, # Input, power.
    utils._BYREF_INT, # Input, itrace.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_gen_delaunay = utils._EngineState._get_symbol('d06abf')
dim2_gen_delaunay.restype = None
dim2_gen_delaunay.argtypes = (
    utils._BYREF_INT, # Input, nvb.
    utils._BYREF_INT, # Input, nvint.
    utils._BYREF_INT, # Input, nvmax.
    utils._BYREF_INT, # Input, nedge.
    utils._EngineIntArrayType.c_type, # Input, edge[3, nedge].
    utils._BYREF_INT, # Output, nv.
    utils._BYREF_INT, # Output, nelt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, coor[2, nvmax].
    utils._EngineIntArrayType.c_type, # Output, conn[3, 2*nvmax+5].
    utils._EngineFloat64ArrayType.c_type, # Input, weight[*].
    utils._BYREF_INT, # Input, npropa.
    utils._BYREF_INT, # Input, itrace.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_gen_front = utils._EngineState._get_symbol('d06acf')
dim2_gen_front.restype = None
dim2_gen_front.argtypes = (
    utils._BYREF_INT, # Input, nvb.
    utils._BYREF_INT, # Input, nvint.
    utils._BYREF_INT, # Input, nvmax.
    utils._BYREF_INT, # Input, nedge.
    utils._EngineIntArrayType.c_type, # Input, edge[3, nedge].
    utils._BYREF_INT, # Output, nv.
    utils._BYREF_INT, # Output, nelt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, coor[2, nvmax].
    utils._EngineIntArrayType.c_type, # Output, conn[3, 2*nvmax+5].
    utils._EngineFloat64ArrayType.c_type, # Input, weight[*].
    utils._BYREF_INT, # Input, itrace.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_gen_boundary_dummy_fbnd = utils._EngineState._get_symbol('d06bad')
dim2_gen_boundary_dummy_fbnd.restype = utils._EngineFloat64ScalarType.c_type
dim2_gen_boundary_dummy_fbnd.argtypes = (
    utils._BYREF_INT, # Input, i.
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, y.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
)

dim2_gen_boundary_fbnd = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_INT, # Input, i.
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, y.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
)
dim2_gen_boundary = utils._EngineState._get_symbol('d06baf')
dim2_gen_boundary.restype = None
dim2_gen_boundary.argtypes = (
    utils._BYREF_INT, # Input, nlines.
    utils._EngineFloat64ArrayType.c_type, # Input, coorch[2, nlines].
    utils._EngineIntArrayType.c_type, # Input, lined[4, nlines].
    dim2_gen_boundary_fbnd,
    utils._EngineFloat64ArrayType.c_type, # Input, crus[2, sdcrus].
    utils._BYREF_INT, # Input, sdcrus.
    utils._EngineFloat64ArrayType.c_type, # Input, rate[nlines].
    utils._BYREF_INT, # Input, ncomp.
    utils._EngineIntArrayType.c_type, # Input, nlcomp[ncomp].
    utils._EngineIntArrayType.c_type, # Input, lcomp[nlines].
    utils._BYREF_INT, # Input, nvmax.
    utils._BYREF_INT, # Input, nedmx.
    utils._BYREF_INT, # Output, nvb.
    utils._EngineFloat64ArrayType.c_type, # Output, coor[2, nvmax].
    utils._BYREF_INT, # Output, nedge.
    utils._EngineIntArrayType.c_type, # Output, edge[3, nedmx].
    utils._BYREF_INT, # Input, itrace.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_smooth_bary = utils._EngineState._get_symbol('d06caf')
dim2_smooth_bary.restype = None
dim2_smooth_bary.argtypes = (
    utils._BYREF_INT, # Input, nv.
    utils._BYREF_INT, # Input, nelt.
    utils._BYREF_INT, # Input, nedge.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, coor[2, nv].
    utils._EngineIntArrayType.c_type, # Input, edge[3, nedge].
    utils._EngineIntArrayType.c_type, # Input, conn[3, nelt].
    utils._BYREF_INT, # Input, nvfix.
    utils._EngineIntArrayType.c_type, # Input, numfix[*].
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input, nqint.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_sparsity = utils._EngineState._get_symbol('d06cbf')
dim2_sparsity.restype = None
dim2_sparsity.argtypes = (
    utils._BYREF_INT, # Input, nv.
    utils._BYREF_INT, # Input, nelt.
    utils._BYREF_INT, # Input, nnzmax.
    utils._EngineIntArrayType.c_type, # Input, conn[3, nelt].
    utils._BYREF_INT, # Output, nnz.
    utils._EngineIntArrayType.c_type, # Output, irow[nnzmax].
    utils._EngineIntArrayType.c_type, # Output, icol[nnzmax].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_renumber = utils._EngineState._get_symbol('d06ccf')
dim2_renumber.restype = None
dim2_renumber.argtypes = (
    utils._BYREF_INT, # Input, nv.
    utils._BYREF_INT, # Input, nelt.
    utils._BYREF_INT, # Input, nedge.
    utils._BYREF_INT, # Input, nnzmax.
    utils._BYREF_INT, # Output, nnz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, coor[2, nv].
    utils._EngineIntArrayType.c_type, # Input/Output, edge[3, nedge].
    utils._EngineIntArrayType.c_type, # Input/Output, conn[3, nelt].
    utils._EngineIntArrayType.c_type, # Output, irow[nnzmax].
    utils._EngineIntArrayType.c_type, # Output, icol[nnzmax].
    utils._BYREF_INT, # Input, itrace.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_transform_affine = utils._EngineState._get_symbol('d06daf')
dim2_transform_affine.restype = None
dim2_transform_affine.argtypes = (
    utils._BYREF_INT, # Input, nv.
    utils._BYREF_INT, # Input, nedge.
    utils._BYREF_INT, # Input, nelt.
    utils._BYREF_INT, # Input, ntrans.
    utils._EngineIntArrayType.c_type, # Input, itype[ntrans].
    utils._EngineFloat64ArrayType.c_type, # Input, trans[6, ntrans].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, coori[2, nv].
    utils._EngineIntArrayType.c_type, # Input/Output, edgei[3, nedge].
    utils._EngineIntArrayType.c_type, # Input/Output, conni[3, nelt].
    utils._EngineFloat64ArrayType.c_type, # Output, cooro[2, nv].
    utils._EngineIntArrayType.c_type, # Output, edgeo[3, nedge].
    utils._EngineIntArrayType.c_type, # Output, conno[3, nelt].
    utils._BYREF_INT, # Input, itrace.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_join = utils._EngineState._get_symbol('d06dbf')
dim2_join.restype = None
dim2_join.argtypes = (
    utils._BYREF_FLOAT64, # Input, eps.
    utils._BYREF_INT, # Input, nv1.
    utils._BYREF_INT, # Input, nelt1.
    utils._BYREF_INT, # Input, nedge1.
    utils._EngineFloat64ArrayType.c_type, # Input, coor1[2, nv1].
    utils._EngineIntArrayType.c_type, # Input, edge1[3, nedge1].
    utils._EngineIntArrayType.c_type, # Input, conn1[3, nelt1].
    utils._EngineIntArrayType.c_type, # Input, reft1[nelt1].
    utils._BYREF_INT, # Input, nv2.
    utils._BYREF_INT, # Input, nelt2.
    utils._BYREF_INT, # Input, nedge2.
    utils._EngineFloat64ArrayType.c_type, # Input, coor2[2, nv2].
    utils._EngineIntArrayType.c_type, # Input, edge2[3, nedge2].
    utils._EngineIntArrayType.c_type, # Input, conn2[3, nelt2].
    utils._EngineIntArrayType.c_type, # Input, reft2[nelt2].
    utils._BYREF_INT, # Output, nv3.
    utils._BYREF_INT, # Output, nelt3.
    utils._BYREF_INT, # Output, nedge3.
    utils._EngineFloat64ArrayType.c_type, # Output, coor3[2, *].
    utils._EngineIntArrayType.c_type, # Output, edge3[3, *].
    utils._EngineIntArrayType.c_type, # Output, conn3[3, *].
    utils._EngineIntArrayType.c_type, # Output, reft3[*].
    utils._BYREF_INT, # Input, itrace.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[liwork].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Input/Output, ifail.
)
