# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `nonpar` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

test_sign = utils._EngineState._get_symbol('g08aaf')
test_sign.restype = None
test_sign.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Output, isgn.
    utils._BYREF_INT, # Output, n1.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

test_median = utils._EngineState._get_symbol('g08acf')
test_median.restype = None
test_median.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, n1.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w[n].
    utils._BYREF_INT, # Output, i1.
    utils._BYREF_INT, # Output, i2.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

test_friedman = utils._EngineState._get_symbol('g08aef')
test_friedman.restype = None
test_friedman.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, n].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w1[k].
    utils._EngineFloat64ArrayType.c_type, # Workspace, w2[k].
    utils._BYREF_FLOAT64, # Output, fr.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

test_kruskal = utils._EngineState._get_symbol('g08aff')
test_kruskal.restype = None
test_kruskal.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, x[lx].
    utils._BYREF_INT, # Input, lx.
    utils._EngineIntArrayType.c_type, # Input, l[k].
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w[lx].
    utils._BYREF_FLOAT64, # Output, h.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

test_wilcoxon = utils._EngineState._get_symbol('g08agf')
test_wilcoxon.restype = None
test_wilcoxon.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_FLOAT64, # Input, xme.
    utils._BYREF_STRING, # Input, tail(len=1).
    utils._BYREF_STRING, # Input, zer(len=1).
    utils._BYREF_FLOAT64, # Output, w.
    utils._BYREF_FLOAT64, # Output, wnor.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Output, n1.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[3*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of zer.
)

test_mwu = utils._EngineState._get_symbol('g08ahf')
test_mwu.restype = None
test_mwu.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n1].
    utils._BYREF_INT, # Input, n2.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n2].
    utils._BYREF_STRING, # Input, tail(len=1).
    utils._BYREF_FLOAT64, # Output, u.
    utils._BYREF_FLOAT64, # Output, unor.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_LOGICAL, # Output, ties.
    utils._EngineFloat64ArrayType.c_type, # Output, ranks[n1+n2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[n1+n2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tail.
)

prob_mwu_noties = utils._EngineState._get_symbol('g08ajf')
prob_mwu_noties.restype = None
prob_mwu_noties.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_STRING, # Input, tail(len=1).
    utils._BYREF_FLOAT64, # Input, u.
    utils._BYREF_FLOAT64, # Output, p.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[lwrk].
    utils._BYREF_INT, # Input, lwrk.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tail.
)

prob_mwu_ties = utils._EngineState._get_symbol('g08akf')
prob_mwu_ties.restype = None
prob_mwu_ties.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_STRING, # Input, tail(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, ranks[n1+n2].
    utils._BYREF_FLOAT64, # Input, u.
    utils._BYREF_FLOAT64, # Output, p.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[lwrk].
    utils._BYREF_INT, # Input, lwrk.
    utils._EngineIntArrayType.c_type, # Workspace, iwrk[2*(n1+n2+1)].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tail.
)

test_cochranq = utils._EngineState._get_symbol('g08alf')
test_cochranq.restype = None
test_cochranq.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, k].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, q.
    utils._BYREF_FLOAT64, # Output, prob.
    utils._BYREF_INT, # Input/Output, ifail.
)

test_mooddavid = utils._EngineState._get_symbol('g08baf')
test_mooddavid.restype = None
test_mooddavid.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, n1.
    utils._EngineFloat64ArrayType.c_type, # Output, r[n].
    utils._BYREF_INT, # Input, itest.
    utils._BYREF_FLOAT64, # Output, w.
    utils._BYREF_FLOAT64, # Output, v.
    utils._BYREF_FLOAT64, # Output, pw.
    utils._BYREF_FLOAT64, # Output, pv.
    utils._BYREF_INT, # Input/Output, ifail.
)

test_ks_1sample = utils._EngineState._get_symbol('g08cbf')
test_ks_1sample.restype = None
test_ks_1sample.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_STRING, # Input, dist(len=*).
    utils._EngineFloat64ArrayType.c_type, # Input/Output, par[2].
    utils._BYREF_STRING, # Input, estima(len=1).
    utils._BYREF_INT, # Input, ntype.
    utils._BYREF_FLOAT64, # Output, d.
    utils._BYREF_FLOAT64, # Output, z.
    utils._BYREF_FLOAT64, # Output, p.
    utils._EngineFloat64ArrayType.c_type, # Output, sx[n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of dist.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of estima.
)

test_ks_1sample_user_cdf = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
)
test_ks_1sample_user = utils._EngineState._get_symbol('g08ccf')
test_ks_1sample_user.restype = None
test_ks_1sample_user.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    test_ks_1sample_user_cdf,
    utils._BYREF_INT, # Input, ntype.
    utils._BYREF_FLOAT64, # Output, d.
    utils._BYREF_FLOAT64, # Output, z.
    utils._BYREF_FLOAT64, # Output, p.
    utils._EngineFloat64ArrayType.c_type, # Output, sx[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

test_ks_2sample = utils._EngineState._get_symbol('g08cdf')
test_ks_2sample.restype = None
test_ks_2sample.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n1].
    utils._BYREF_INT, # Input, n2.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n2].
    utils._BYREF_INT, # Input, ntype.
    utils._BYREF_FLOAT64, # Output, d.
    utils._BYREF_FLOAT64, # Output, z.
    utils._BYREF_FLOAT64, # Output, p.
    utils._EngineFloat64ArrayType.c_type, # Output, sx[n1].
    utils._EngineFloat64ArrayType.c_type, # Output, sy[n2].
    utils._BYREF_INT, # Input/Output, ifail.
)

test_chisq = utils._EngineState._get_symbol('g08cgf')
test_chisq.restype = None
test_chisq.argtypes = (
    utils._BYREF_INT, # Input, nclass.
    utils._EngineIntArrayType.c_type, # Input, ifreq[nclass].
    utils._EngineFloat64ArrayType.c_type, # Input, cb[nclass-1].
    utils._BYREF_STRING, # Input, dist(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, par[2].
    utils._BYREF_INT, # Input, npest.
    utils._EngineFloat64ArrayType.c_type, # Input, prob[nclass].
    utils._BYREF_FLOAT64, # Output, chisq.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Output, ndf.
    utils._EngineFloat64ArrayType.c_type, # Output, eval[nclass].
    utils._EngineFloat64ArrayType.c_type, # Output, chisqi[nclass].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of dist.
)

gofstat_anddar = utils._EngineState._get_symbol('g08chf')
gofstat_anddar.restype = utils._EngineFloat64ScalarType.c_type
gofstat_anddar.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_LOGICAL, # Input, issort.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

gofstat_anddar_unif = utils._EngineState._get_symbol('g08cjf')
gofstat_anddar_unif.restype = None
gofstat_anddar_unif.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_LOGICAL, # Input, issort.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[n].
    utils._BYREF_FLOAT64, # Output, a2.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

gofstat_anddar_normal = utils._EngineState._get_symbol('g08ckf')
gofstat_anddar_normal.restype = None
gofstat_anddar_normal.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_LOGICAL, # Input, issort.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_FLOAT64, # Output, ybar.
    utils._BYREF_FLOAT64, # Output, yvar.
    utils._BYREF_FLOAT64, # Output, a2.
    utils._BYREF_FLOAT64, # Output, aa2.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

gofstat_anddar_exp = utils._EngineState._get_symbol('g08clf')
gofstat_anddar_exp.restype = None
gofstat_anddar_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_LOGICAL, # Input, issort.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_FLOAT64, # Output, ybar.
    utils._BYREF_FLOAT64, # Output, a2.
    utils._BYREF_FLOAT64, # Output, aa2.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

concordance_kendall = utils._EngineState._get_symbol('g08daf')
concordance_kendall.restype = None
concordance_kendall.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, n].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rnk[ldx, n].
    utils._BYREF_FLOAT64, # Output, w.
    utils._BYREF_FLOAT64, # Output, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

randtest_runs = utils._EngineState._get_symbol('g08eaf')
randtest_runs.restype = None
randtest_runs.argtypes = (
    utils._BYREF_STRING, # Input, cl(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, maxr.
    utils._BYREF_INT, # Input/Output, nruns.
    utils._EngineIntArrayType.c_type, # Input/Output, ncount[maxr].
    utils._EngineFloat64ArrayType.c_type, # Output, ex[maxr].
    utils._EngineFloat64ArrayType.c_type, # Output, cov[ldcov, maxr].
    utils._BYREF_INT, # Input, ldcov.
    utils._BYREF_FLOAT64, # Output, chi.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_FLOAT64, # Output, prob.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[lwrk].
    utils._BYREF_INT, # Input, lwrk.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cl.
)

randtest_pairs = utils._EngineState._get_symbol('g08ebf')
randtest_pairs.restype = None
randtest_pairs.argtypes = (
    utils._BYREF_STRING, # Input, cl(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, msize.
    utils._BYREF_INT, # Input, lag.
    utils._EngineIntArrayType.c_type, # Input/Output, ncount[ldc, msize].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_FLOAT64, # Output, ex.
    utils._BYREF_FLOAT64, # Output, chi.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_FLOAT64, # Output, prob.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, wrk[2*lag].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cl.
)

randtest_triplets = utils._EngineState._get_symbol('g08ecf')
randtest_triplets.restype = None
randtest_triplets.argtypes = (
    utils._BYREF_STRING, # Input, cl(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, msize.
    utils._EngineIntArrayType.c_type, # Input/Output, ncount[ldc, ldc, msize].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_FLOAT64, # Output, ex.
    utils._BYREF_FLOAT64, # Output, chi.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_FLOAT64, # Output, prob.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cl.
)

randtest_gaps = utils._EngineState._get_symbol('g08edf')
randtest_gaps.restype = None
randtest_gaps.argtypes = (
    utils._BYREF_STRING, # Input, cl(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, maxg.
    utils._BYREF_FLOAT64, # Input, rlo.
    utils._BYREF_FLOAT64, # Input, rup.
    utils._BYREF_FLOAT64, # Input, totlen.
    utils._BYREF_INT, # Input/Output, ngaps.
    utils._EngineIntArrayType.c_type, # Input/Output, ncount[maxg].
    utils._EngineFloat64ArrayType.c_type, # Output, ex[maxg].
    utils._BYREF_FLOAT64, # Output, chi.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_FLOAT64, # Output, prob.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cl.
)

rank_regsn = utils._EngineState._get_symbol('g08raf')
rank_regsn.restype = None
rank_regsn.argtypes = (
    utils._BYREF_INT, # Input, ns.
    utils._EngineIntArrayType.c_type, # Input/Output, nv[ns].
    utils._BYREF_INT, # Input, nsum.
    utils._EngineFloat64ArrayType.c_type, # Input, y[nsum].
    utils._BYREF_INT, # Input, ip.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, ip].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_INT, # Input, idist.
    utils._BYREF_INT, # Input, nmax.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Output, prvr[ldprvr, ip].
    utils._BYREF_INT, # Input, ldprvr.
    utils._EngineIntArrayType.c_type, # Output, irank[nmax].
    utils._EngineFloat64ArrayType.c_type, # Output, zin[nmax].
    utils._EngineFloat64ArrayType.c_type, # Output, eta[nmax].
    utils._EngineFloat64ArrayType.c_type, # Output, vapvec[nmax*(nmax+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, parest[4*ip+1].
    utils._EngineFloat64ArrayType.c_type, # Output, work[0].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Output, iwa[0].
    utils._BYREF_INT, # Input/Output, ifail.
)

rank_regsn_censored = utils._EngineState._get_symbol('g08rbf')
rank_regsn_censored.restype = None
rank_regsn_censored.argtypes = (
    utils._BYREF_INT, # Input, ns.
    utils._EngineIntArrayType.c_type, # Input, nv[ns].
    utils._BYREF_INT, # Input, nsum.
    utils._EngineFloat64ArrayType.c_type, # Input, y[nsum].
    utils._BYREF_INT, # Input, ip.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, ip].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, icen[nsum].
    utils._BYREF_FLOAT64, # Input, gamma.
    utils._BYREF_INT, # Input, nmax.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Output, prvr[ldprvr, ip].
    utils._BYREF_INT, # Input, ldprvr.
    utils._EngineIntArrayType.c_type, # Output, irank[nmax].
    utils._EngineFloat64ArrayType.c_type, # Output, zin[nmax].
    utils._EngineFloat64ArrayType.c_type, # Output, eta[nmax].
    utils._EngineFloat64ArrayType.c_type, # Output, vapvec[nmax*(nmax+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, parest[4*ip+1].
    utils._EngineFloat64ArrayType.c_type, # Output, work[0].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Output, iwa[0].
    utils._BYREF_INT, # Input/Output, ifail.
)
