# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `pde` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

dim2_laplace = utils._EngineState._get_symbol('d03eaf')
dim2_laplace.restype = None
dim2_laplace.argtypes = (
    utils._BYREF_LOGICAL, # Input, stage1.
    utils._BYREF_LOGICAL, # Input, ext.
    utils._BYREF_LOGICAL, # Input, dorm.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_FLOAT64, # Input, q.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n1p1].
    utils._EngineFloat64ArrayType.c_type, # Input, y[n1p1].
    utils._BYREF_INT, # Input, n1p1.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, phi[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, phid[n].
    utils._BYREF_FLOAT64, # Input/Output, alpha.
    utils._EngineFloat64ArrayType.c_type, # Workspace, c[ldc, n+4].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_INT, # Input, np4.
    utils._EngineIntArrayType.c_type, # Workspace, icint[n+1].
    utils._BYREF_INT, # Input, np1.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_ellip_fd = utils._EngineState._get_symbol('d03ebf')
dim2_ellip_fd.restype = None
dim2_ellip_fd.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, b[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, c[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, d[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, e[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, q[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, t[lda, n2].
    utils._BYREF_FLOAT64, # Input, aparam.
    utils._BYREF_INT, # Input, itmax.
    utils._BYREF_INT, # Input/Output, itcoun.
    utils._BYREF_INT, # Output, itused.
    utils._BYREF_INT, # Input, ndir.
    utils._BYREF_INT, # Input, ixn.
    utils._BYREF_INT, # Input, iyn.
    utils._BYREF_FLOAT64, # Input, conres.
    utils._BYREF_FLOAT64, # Input, conchn.
    utils._EngineFloat64ArrayType.c_type, # Output, resids[itmax].
    utils._EngineFloat64ArrayType.c_type, # Output, chngs[itmax].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp1[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp2[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp3[lda, n2].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim3_ellip_fd = utils._EngineState._get_symbol('d03ecf')
dim3_ellip_fd.restype = None
dim3_ellip_fd.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_INT, # Input, n3.
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input, sda.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, b[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, c[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, d[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, e[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, f[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, g[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, q[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, t[lda, sda, n3].
    utils._BYREF_FLOAT64, # Input, aparam.
    utils._BYREF_INT, # Input, itmax.
    utils._BYREF_INT, # Input/Output, itcoun.
    utils._BYREF_INT, # Output, itused.
    utils._BYREF_INT, # Input, ndir.
    utils._BYREF_INT, # Input, ixn.
    utils._BYREF_INT, # Input, iyn.
    utils._BYREF_INT, # Input, izn.
    utils._BYREF_FLOAT64, # Input, conres.
    utils._BYREF_FLOAT64, # Input, conchn.
    utils._EngineFloat64ArrayType.c_type, # Output, resids[itmax].
    utils._EngineFloat64ArrayType.c_type, # Output, chngs[itmax].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp1[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp2[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp3[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp4[lda, sda, n3].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_ellip_mgrid = utils._EngineState._get_symbol('d03edf')
dim2_ellip_mgrid.restype = None
dim2_ellip_mgrid.argtypes = (
    utils._BYREF_INT, # Input, ngx.
    utils._BYREF_INT, # Input, ngy.
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, 7].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rhs[lda].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ub[ngx*ngy].
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_FLOAT64, # Input, acc.
    utils._EngineFloat64ArrayType.c_type, # Output, us[lda].
    utils._EngineFloat64ArrayType.c_type, # Output, u[lda].
    utils._BYREF_INT, # Input, iout.
    utils._BYREF_INT, # Output, numit.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_ellip_discret_pdef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, y.
    utils._BYREF_FLOAT64, # Output, alpha.
    utils._BYREF_FLOAT64, # Output, beta.
    utils._BYREF_FLOAT64, # Output, gamma.
    utils._BYREF_FLOAT64, # Output, delta.
    utils._BYREF_FLOAT64, # Output, epslon.
    utils._BYREF_FLOAT64, # Output, phi.
    utils._BYREF_FLOAT64, # Output, psi.
)
dim2_ellip_discret_bndy = utils._EngineState._sys_functype(
    None,
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, y.
    utils._BYREF_FLOAT64, # Output, a.
    utils._BYREF_FLOAT64, # Output, b.
    utils._BYREF_FLOAT64, # Output, c.
    utils._BYREF_INT, # Input, ibnd.
)
dim2_ellip_discret = utils._EngineState._get_symbol('d03eef')
dim2_ellip_discret.restype = None
dim2_ellip_discret.argtypes = (
    utils._BYREF_FLOAT64, # Input, xmin.
    utils._BYREF_FLOAT64, # Input, xmax.
    utils._BYREF_FLOAT64, # Input, ymin.
    utils._BYREF_FLOAT64, # Input, ymax.
    dim2_ellip_discret_pdef,
    dim2_ellip_discret_bndy,
    utils._BYREF_INT, # Input, ngx.
    utils._BYREF_INT, # Input, ngy.
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, a[lda, 7].
    utils._EngineFloat64ArrayType.c_type, # Output, rhs[lda].
    utils._BYREF_STRING, # Input, scheme(len=1).
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of scheme.
)

dim3_ellip_helmholtz = utils._EngineState._get_symbol('d03faf')
dim3_ellip_helmholtz.restype = None
dim3_ellip_helmholtz.argtypes = (
    utils._BYREF_FLOAT64, # Input, xs.
    utils._BYREF_FLOAT64, # Input, xf.
    utils._BYREF_INT, # Input, l.
    utils._BYREF_INT, # Input, lbdcnd.
    utils._EngineFloat64ArrayType.c_type, # Input, bdxs[ldf2, n+1].
    utils._EngineFloat64ArrayType.c_type, # Input, bdxf[ldf2, n+1].
    utils._BYREF_FLOAT64, # Input, ys.
    utils._BYREF_FLOAT64, # Input, yf.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, mbdcnd.
    utils._EngineFloat64ArrayType.c_type, # Input, bdys[ldf, n+1].
    utils._EngineFloat64ArrayType.c_type, # Input, bdyf[ldf, n+1].
    utils._BYREF_FLOAT64, # Input, zs.
    utils._BYREF_FLOAT64, # Input, zf.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nbdcnd.
    utils._EngineFloat64ArrayType.c_type, # Input, bdzs[ldf, m+1].
    utils._EngineFloat64ArrayType.c_type, # Input, bdzf[ldf, m+1].
    utils._BYREF_FLOAT64, # Input, lambda.
    utils._BYREF_INT, # Input, ldf.
    utils._BYREF_INT, # Input, ldf2.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, f[ldf, ldf2, n+1].
    utils._BYREF_FLOAT64, # Output, pertrb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[lwrk].
    utils._BYREF_INT, # Input, lwrk.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_triangulate_isin = utils._EngineState._sys_functype(
    utils._EngineIntScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, y.
)
dim2_triangulate = utils._EngineState._get_symbol('d03maf')
dim2_triangulate.restype = None
dim2_triangulate.argtypes = (
    utils._BYREF_FLOAT64, # Input, h.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nb.
    utils._BYREF_INT, # Output, npts.
    utils._EngineFloat64ArrayType.c_type, # Output, places[2, sdindx].
    utils._EngineIntArrayType.c_type, # Output, indx[4, sdindx].
    utils._BYREF_INT, # Input, sdindx.
    dim2_triangulate_isin,
    utils._EngineFloat64ArrayType.c_type, # Workspace, dist[4, sddist].
    utils._BYREF_INT, # Input, sddist.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_blackscholes_fd = utils._EngineState._get_symbol('d03ncf')
dim1_blackscholes_fd.restype = None
dim1_blackscholes_fd.argtypes = (
    utils._BYREF_INT, # Input, kopt.
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_STRING, # Input, mesh(len=1).
    utils._BYREF_INT, # Input, ns.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[ns].
    utils._BYREF_INT, # Input, nt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, t[nt].
    utils._EngineLogicalArrayType.c_type, # Input, tdpar[3].
    utils._EngineFloat64ArrayType.c_type, # Input, r[*].
    utils._EngineFloat64ArrayType.c_type, # Input, q[*].
    utils._EngineFloat64ArrayType.c_type, # Input, sigma[*].
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._BYREF_INT, # Input, ntkeep.
    utils._EngineFloat64ArrayType.c_type, # Output, f[ldf, ntkeep].
    utils._EngineFloat64ArrayType.c_type, # Output, theta[ldf, ntkeep].
    utils._EngineFloat64ArrayType.c_type, # Output, delta[ldf, ntkeep].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[ldf, ntkeep].
    utils._EngineFloat64ArrayType.c_type, # Output, lambda[ldf, ntkeep].
    utils._EngineFloat64ArrayType.c_type, # Output, rho[ldf, ntkeep].
    utils._BYREF_INT, # Input, ldf.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[4*ns].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[ns].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of mesh.
)

dim1_blackscholes_closed = utils._EngineState._get_symbol('d03ndf')
dim1_blackscholes_closed.restype = None
dim1_blackscholes_closed.argtypes = (
    utils._BYREF_INT, # Input, kopt.
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_FLOAT64, # Input, s.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, tmat.
    utils._EngineLogicalArrayType.c_type, # Input, tdpar[3].
    utils._EngineFloat64ArrayType.c_type, # Input, r[*].
    utils._EngineFloat64ArrayType.c_type, # Input, q[*].
    utils._EngineFloat64ArrayType.c_type, # Input, sigma[*].
    utils._BYREF_FLOAT64, # Output, f.
    utils._BYREF_FLOAT64, # Output, theta.
    utils._BYREF_FLOAT64, # Output, delta.
    utils._BYREF_FLOAT64, # Output, gamma.
    utils._BYREF_FLOAT64, # Output, lambda.
    utils._BYREF_FLOAT64, # Output, rho.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_blackscholes_means = utils._EngineState._get_symbol('d03nef')
dim1_blackscholes_means.restype = None
dim1_blackscholes_means.argtypes = (
    utils._BYREF_FLOAT64, # Input, t0.
    utils._BYREF_FLOAT64, # Input, tmat.
    utils._BYREF_INT, # Input, ntd.
    utils._EngineFloat64ArrayType.c_type, # Input, td[ntd].
    utils._EngineFloat64ArrayType.c_type, # Input, phid[ntd].
    utils._EngineFloat64ArrayType.c_type, # Output, phiav[3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_fd_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_fd_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_fd = utils._EngineState._get_symbol('d03pca')
dim1_parab_fd.restype = None
dim1_parab_fd.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_fd_pdedef,
    dim1_parab_fd_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[npde, npts].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_FLOAT64, # Input, acc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineCharArrayType.c_type, # Input/Output, cwsav(len=80)[10].
    utils._EngineLogicalArrayType.c_type, # Input/Output, lwsav[100].
    utils._EngineIntArrayType.c_type, # Input/Output, iwsav[505].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwsav[1100].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cwsav.
)

dim1_parab_fd_old_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_fd_old_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_fd_old = utils._EngineState._get_symbol('d03pcf')
dim1_parab_fd_old.restype = None
dim1_parab_fd_old.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_fd_old_pdedef,
    dim1_parab_fd_old_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[npde, npts].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_FLOAT64, # Input, acc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_remesh_fd_dummy_odedef_old = utils._EngineState._get_symbol('d03pck')
dim1_parab_remesh_fd_dummy_odedef_old.restype = None
dim1_parab_remesh_fd_dummy_odedef_old.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
)

dim1_parab_remesh_fd_dummy_monitf_old = utils._EngineState._get_symbol('d03pcl')
dim1_parab_remesh_fd_dummy_monitf_old.restype = None
dim1_parab_remesh_fd_dummy_monitf_old.argtypes = (
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Input, r[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Output, fmon[npts].
)

dim1_parab_coll_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[nptl].
    utils._BYREF_INT, # Input, nptl.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde, nptl].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_coll_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_coll_uinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_coll = utils._EngineState._get_symbol('d03pda')
dim1_parab_coll.restype = None
dim1_parab_coll.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_coll_pdedef,
    dim1_parab_coll_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[npde, npts].
    utils._BYREF_INT, # Input, nbkpts.
    utils._EngineFloat64ArrayType.c_type, # Input, xbkpts[nbkpts].
    utils._BYREF_INT, # Input, npoly.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Output, x[npts].
    dim1_parab_coll_uinit,
    utils._BYREF_FLOAT64, # Input, acc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineCharArrayType.c_type, # Input/Output, cwsav(len=80)[10].
    utils._EngineLogicalArrayType.c_type, # Input/Output, lwsav[100].
    utils._EngineIntArrayType.c_type, # Input/Output, iwsav[505].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwsav[1100].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cwsav.
)

dim1_parab_coll_old_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[nptl].
    utils._BYREF_INT, # Input, nptl.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde, nptl].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_coll_old_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_coll_old_uinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
)
dim1_parab_coll_old = utils._EngineState._get_symbol('d03pdf')
dim1_parab_coll_old.restype = None
dim1_parab_coll_old.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_coll_old_pdedef,
    dim1_parab_coll_old_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[npde, npts].
    utils._BYREF_INT, # Input, nbkpts.
    utils._EngineFloat64ArrayType.c_type, # Input, xbkpts[nbkpts].
    utils._BYREF_INT, # Input, npoly.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Output, x[npts].
    dim1_parab_coll_old_uinit,
    utils._BYREF_FLOAT64, # Input, acc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_keller_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, res[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_keller_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, ibnd.
    utils._BYREF_INT, # Input, nobc.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, res[nobc].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_keller = utils._EngineState._get_symbol('d03pef')
dim1_parab_keller.restype = None
dim1_parab_keller.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_keller_pdedef,
    dim1_parab_keller_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[npde, npts].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_INT, # Input, nleft.
    utils._BYREF_FLOAT64, # Input, acc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_dae_keller_remesh_fd_dummy_odedef = utils._EngineState._get_symbol('d03pek')
dim1_parab_dae_keller_remesh_fd_dummy_odedef.restype = None
dim1_parab_dae_keller_remesh_fd_dummy_odedef.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, r[nv].
    utils._BYREF_INT, # Input/Output, ires.
)

dim1_parab_dae_keller_remesh_fd_dummy_monitf = utils._EngineState._get_symbol('d03pel')
dim1_parab_dae_keller_remesh_fd_dummy_monitf.restype = None
dim1_parab_dae_keller_remesh_fd_dummy_monitf.argtypes = (
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Output, fmon[npts].
)

dim1_parab_convdiff_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, c[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, d[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, s[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_numflx = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, flux[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, 3].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, g[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff = utils._EngineState._get_symbol('d03pff')
dim1_parab_convdiff.restype = None
dim1_parab_convdiff.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_convdiff_pdedef,
    dim1_parab_convdiff_numflx,
    dim1_parab_convdiff_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[npde, npts].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, acc[2].
    utils._BYREF_FLOAT64, # Input, tsmax.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_convdiff_sample_pdedef = utils._EngineState._get_symbol('d03pfp')
dim1_parab_convdiff_sample_pdedef.restype = None
dim1_parab_convdiff_sample_pdedef.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, c[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, d[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, s[npde].
    utils._BYREF_INT, # Input/Output, ires.
)

dim1_parab_dae_fd_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_fd_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_fd_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_fd = utils._EngineState._get_symbol('d03pha')
dim1_parab_dae_fd.restype = None
dim1_parab_dae_fd.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_dae_fd_pdedef,
    dim1_parab_dae_fd_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_dae_fd_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineCharArrayType.c_type, # Input/Output, cwsav(len=80)[10].
    utils._EngineLogicalArrayType.c_type, # Input/Output, lwsav[100].
    utils._EngineIntArrayType.c_type, # Input/Output, iwsav[505].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwsav[1100].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cwsav.
)

dim1_parab_dae_fd_old_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_fd_old_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_fd_old_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_fd_old = utils._EngineState._get_symbol('d03phf')
dim1_parab_dae_fd_old.restype = None
dim1_parab_dae_fd_old.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_dae_fd_old_pdedef,
    dim1_parab_dae_fd_old_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_dae_fd_old_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_dae_coll_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[nptl].
    utils._BYREF_INT, # Input, nptl.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde, nptl].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde, nptl].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_coll_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_coll_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_coll_uvinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Output, v[nv].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_dae_coll = utils._EngineState._get_symbol('d03pja')
dim1_parab_dae_coll.restype = None
dim1_parab_dae_coll.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_dae_coll_pdedef,
    dim1_parab_dae_coll_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, nbkpts.
    utils._EngineFloat64ArrayType.c_type, # Input, xbkpts[nbkpts].
    utils._BYREF_INT, # Input, npoly.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Output, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_dae_coll_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    dim1_parab_dae_coll_uvinit,
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineCharArrayType.c_type, # Input/Output, cwsav(len=80)[10].
    utils._EngineLogicalArrayType.c_type, # Input/Output, lwsav[100].
    utils._EngineIntArrayType.c_type, # Input/Output, iwsav[505].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwsav[1100].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cwsav.
)

dim1_parab_dae_coll_old_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[nptl].
    utils._BYREF_INT, # Input, nptl.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde, nptl].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde, nptl].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde, nptl].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_coll_old_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_coll_old_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_coll_old_uvinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Output, v[nv].
)
dim1_parab_dae_coll_old = utils._EngineState._get_symbol('d03pjf')
dim1_parab_dae_coll_old.restype = None
dim1_parab_dae_coll_old.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_dae_coll_old_pdedef,
    dim1_parab_dae_coll_old_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, nbkpts.
    utils._EngineFloat64ArrayType.c_type, # Input, xbkpts[nbkpts].
    utils._BYREF_INT, # Input, npoly.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Output, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_dae_coll_old_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    dim1_parab_dae_coll_old_uvinit,
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_dae_keller_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, res[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_keller_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, ibnd.
    utils._BYREF_INT, # Input, nobc.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, res[nobc].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_keller_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, r[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_dae_keller = utils._EngineState._get_symbol('d03pkf')
dim1_parab_dae_keller.restype = None
dim1_parab_dae_keller.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_dae_keller_pdedef,
    dim1_parab_dae_keller_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_INT, # Input, nleft.
    utils._BYREF_INT, # Input, nv.
    dim1_parab_dae_keller_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_convdiff_dae_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, c[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, d[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, s[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_dae_numflx = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, flux[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_dae_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, g[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_dae_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, r[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_dae = utils._EngineState._get_symbol('d03plf')
dim1_parab_convdiff_dae.restype = None
dim1_parab_convdiff_dae.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_convdiff_dae_pdedef,
    dim1_parab_convdiff_dae_numflx,
    dim1_parab_convdiff_dae_bndary,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_convdiff_dae_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_convdiff_dae_sample_pdedef = utils._EngineState._get_symbol('d03plp')
dim1_parab_convdiff_dae_sample_pdedef.restype = None
dim1_parab_convdiff_dae_sample_pdedef.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, c[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, d[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, s[npde].
    utils._BYREF_INT, # Input/Output, ires.
)

dim1_parab_remesh_fd_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_remesh_fd_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_remesh_fd_uvinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Output, v[nv].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_remesh_fd_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_remesh_fd_monitf = utils._EngineState._sys_functype(
    None,
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Input, r[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Output, fmon[npts].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
dim1_parab_remesh_fd = utils._EngineState._get_symbol('d03ppa')
dim1_parab_remesh_fd.restype = None
dim1_parab_remesh_fd.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_remesh_fd_pdedef,
    dim1_parab_remesh_fd_bndary,
    dim1_parab_remesh_fd_uvinit,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_remesh_fd_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._BYREF_LOGICAL, # Input, remesh.
    utils._BYREF_INT, # Input, nxfix.
    utils._EngineFloat64ArrayType.c_type, # Input, xfix[nxfix].
    utils._BYREF_INT, # Input, nrmesh.
    utils._BYREF_FLOAT64, # Input, dxmesh.
    utils._BYREF_FLOAT64, # Input, trmesh.
    utils._BYREF_INT, # Input, ipminf.
    utils._BYREF_FLOAT64, # Input, xratio.
    utils._BYREF_FLOAT64, # Input, con.
    dim1_parab_remesh_fd_monitf,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._EngineCharArrayType.c_type, # Input/Output, cwsav(len=80)[10].
    utils._EngineLogicalArrayType.c_type, # Input/Output, lwsav[100].
    utils._EngineIntArrayType.c_type, # Input/Output, iwsav[505].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwsav[1100].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cwsav.
)

dim1_parab_remesh_fd_old_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, q[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, r[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_remesh_fd_old_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, beta[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, gamma[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_remesh_fd_old_uvinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Output, v[nv].
)
dim1_parab_remesh_fd_old_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, rcp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucptx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, f[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_remesh_fd_old_monitf = utils._EngineState._sys_functype(
    None,
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Input, r[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Output, fmon[npts].
)
dim1_parab_remesh_fd_old = utils._EngineState._get_symbol('d03ppf')
dim1_parab_remesh_fd_old.restype = None
dim1_parab_remesh_fd_old.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_remesh_fd_old_pdedef,
    dim1_parab_remesh_fd_old_bndary,
    dim1_parab_remesh_fd_old_uvinit,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_remesh_fd_old_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._BYREF_LOGICAL, # Input, remesh.
    utils._BYREF_INT, # Input, nxfix.
    utils._EngineFloat64ArrayType.c_type, # Input, xfix[nxfix].
    utils._BYREF_INT, # Input, nrmesh.
    utils._BYREF_FLOAT64, # Input, dxmesh.
    utils._BYREF_FLOAT64, # Input, trmesh.
    utils._BYREF_INT, # Input, ipminf.
    utils._BYREF_FLOAT64, # Input, xratio.
    utils._BYREF_FLOAT64, # Input, con.
    dim1_parab_remesh_fd_old_monitf,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_remesh_keller_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, res[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_remesh_keller_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, ibnd.
    utils._BYREF_INT, # Input, nobc.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, res[nobc].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_remesh_keller_uvinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Output, v[nv].
)
dim1_parab_remesh_keller_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, r[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_remesh_keller_monitf = utils._EngineState._sys_functype(
    None,
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Output, fmon[npts].
)
dim1_parab_remesh_keller = utils._EngineState._get_symbol('d03prf')
dim1_parab_remesh_keller.restype = None
dim1_parab_remesh_keller.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_remesh_keller_pdedef,
    dim1_parab_remesh_keller_bndary,
    dim1_parab_remesh_keller_uvinit,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[npts].
    utils._BYREF_INT, # Input, nleft.
    utils._BYREF_INT, # Input, nv.
    dim1_parab_remesh_keller_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._BYREF_LOGICAL, # Input, remesh.
    utils._BYREF_INT, # Input, nxfix.
    utils._EngineFloat64ArrayType.c_type, # Input, xfix[nxfix].
    utils._BYREF_INT, # Input, nrmesh.
    utils._BYREF_FLOAT64, # Input, dxmesh.
    utils._BYREF_FLOAT64, # Input, trmesh.
    utils._BYREF_INT, # Input, ipminf.
    utils._BYREF_FLOAT64, # Input, xratio.
    utils._BYREF_FLOAT64, # Input, con.
    dim1_parab_remesh_keller_monitf,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_convdiff_remesh_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npde].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._EngineFloat64ArrayType.c_type, # Output, p[npde, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, c[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, d[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, s[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_remesh_numflx = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, x.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[npde].
    utils._EngineFloat64ArrayType.c_type, # Output, flux[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_remesh_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, ibnd.
    utils._EngineFloat64ArrayType.c_type, # Output, g[npde].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_remesh_uvinit = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npde, npts].
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Output, v[nv].
)
dim1_parab_convdiff_remesh_odedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, nv.
    utils._EngineFloat64ArrayType.c_type, # Input, v[nv].
    utils._EngineFloat64ArrayType.c_type, # Input, vdot[nv].
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucp[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpx[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Input, ucpt[npde, nxi].
    utils._EngineFloat64ArrayType.c_type, # Output, r[nv].
    utils._BYREF_INT, # Input/Output, ires.
)
dim1_parab_convdiff_remesh_monitf = utils._EngineState._sys_functype(
    None,
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._EngineFloat64ArrayType.c_type, # Output, fmon[npts].
)
dim1_parab_convdiff_remesh = utils._EngineState._get_symbol('d03psf')
dim1_parab_convdiff_remesh.restype = None
dim1_parab_convdiff_remesh.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    dim1_parab_convdiff_remesh_pdedef,
    dim1_parab_convdiff_remesh_numflx,
    dim1_parab_convdiff_remesh_bndary,
    dim1_parab_convdiff_remesh_uvinit,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[neqn].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[npts].
    utils._BYREF_INT, # Input, nv.
    dim1_parab_convdiff_remesh_odedef,
    utils._BYREF_INT, # Input, nxi.
    utils._EngineFloat64ArrayType.c_type, # Input, xi[nxi].
    utils._BYREF_INT, # Input, neqn.
    utils._EngineFloat64ArrayType.c_type, # Input, rtol[*].
    utils._EngineFloat64ArrayType.c_type, # Input, atol[*].
    utils._BYREF_INT, # Input, itol.
    utils._BYREF_STRING, # Input, norm(len=1).
    utils._BYREF_STRING, # Input, laopt(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, algopt[30].
    utils._BYREF_LOGICAL, # Input, remesh.
    utils._BYREF_INT, # Input, nxfix.
    utils._EngineFloat64ArrayType.c_type, # Input, xfix[nxfix].
    utils._BYREF_INT, # Input, nrmesh.
    utils._BYREF_FLOAT64, # Input, dxmesh.
    utils._BYREF_FLOAT64, # Input, trmesh.
    utils._BYREF_INT, # Input, ipminf.
    utils._BYREF_FLOAT64, # Input, xratio.
    utils._BYREF_FLOAT64, # Input, con.
    dim1_parab_convdiff_remesh_monitf,
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._EngineIntArrayType.c_type, # Input/Output, isave[lisave].
    utils._BYREF_INT, # Input, lisave.
    utils._BYREF_INT, # Input, itask.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of norm.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of laopt.
)

dim1_parab_euler_roe = utils._EngineState._get_symbol('d03puf')
dim1_parab_euler_roe.restype = None
dim1_parab_euler_roe.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[3].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[3].
    utils._BYREF_FLOAT64, # Input, gamma.
    utils._EngineFloat64ArrayType.c_type, # Output, flux[3].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_euler_osher = utils._EngineState._get_symbol('d03pvf')
dim1_parab_euler_osher.restype = None
dim1_parab_euler_osher.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[3].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[3].
    utils._BYREF_FLOAT64, # Input, gamma.
    utils._BYREF_STRING, # Input, path(len=1).
    utils._EngineFloat64ArrayType.c_type, # Output, flux[3].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of path.
)

dim1_parab_euler_hll = utils._EngineState._get_symbol('d03pwf')
dim1_parab_euler_hll.restype = None
dim1_parab_euler_hll.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[3].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[3].
    utils._BYREF_FLOAT64, # Input, gamma.
    utils._EngineFloat64ArrayType.c_type, # Output, flux[3].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_euler_exact = utils._EngineState._get_symbol('d03pxf')
dim1_parab_euler_exact.restype = None
dim1_parab_euler_exact.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, uleft[3].
    utils._EngineFloat64ArrayType.c_type, # Input, uright[3].
    utils._BYREF_FLOAT64, # Input, gamma.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, niter.
    utils._EngineFloat64ArrayType.c_type, # Output, flux[3].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_coll_interp = utils._EngineState._get_symbol('d03pyf')
dim1_parab_coll_interp.restype = None
dim1_parab_coll_interp.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._BYREF_INT, # Input, nbkpts.
    utils._EngineFloat64ArrayType.c_type, # Input, xbkpts[nbkpts].
    utils._BYREF_INT, # Input, npoly.
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, xp[intpts].
    utils._BYREF_INT, # Input, intpts.
    utils._BYREF_INT, # Input, itype.
    utils._EngineFloat64ArrayType.c_type, # Output, up[npde, intpts, itype].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rsave[lrsave].
    utils._BYREF_INT, # Input, lrsave.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim1_parab_fd_interp = utils._EngineState._get_symbol('d03pzf')
dim1_parab_fd_interp.restype = None
dim1_parab_fd_interp.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, u[npde, npts].
    utils._BYREF_INT, # Input, npts.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, xp[intpts].
    utils._BYREF_INT, # Input, intpts.
    utils._BYREF_INT, # Input, itype.
    utils._EngineFloat64ArrayType.c_type, # Output, up[npde, intpts, itype].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_gen_order2_rectangle_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, y[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uy[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uxx[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uxy[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uyy[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, res[npts, npde].
)
dim2_gen_order2_rectangle_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, y[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uy[npts, npde].
    utils._BYREF_INT, # Input, nbpts.
    utils._EngineIntArrayType.c_type, # Input, lbnd[nbpts].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, res[npts, npde].
)
dim2_gen_order2_rectangle_pdeiv = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, y[npts].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npts, npde].
)
dim2_gen_order2_rectangle_monitr = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, dt.
    utils._BYREF_FLOAT64, # Input, dtnew.
    utils._BYREF_LOGICAL, # Input, tlast.
    utils._BYREF_INT, # Input, nlev.
    utils._EngineIntArrayType.c_type, # Input, ngpts[nlev].
    utils._EngineFloat64ArrayType.c_type, # Input, xpts[*].
    utils._EngineFloat64ArrayType.c_type, # Input, ypts[*].
    utils._EngineIntArrayType.c_type, # Input, lsol[nlev].
    utils._EngineFloat64ArrayType.c_type, # Input, sol[*].
    utils._BYREF_INT, # Input/Output, ierr.
)
dim2_gen_order2_rectangle = utils._EngineState._get_symbol('d03raf')
dim2_gen_order2_rectangle.restype = None
dim2_gen_order2_rectangle.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, dt[3].
    utils._BYREF_FLOAT64, # Input, xmin.
    utils._BYREF_FLOAT64, # Input, xmax.
    utils._BYREF_FLOAT64, # Input, ymin.
    utils._BYREF_FLOAT64, # Input, ymax.
    utils._BYREF_INT, # Input, nx.
    utils._BYREF_INT, # Input, ny.
    utils._BYREF_FLOAT64, # Input, tols.
    utils._BYREF_FLOAT64, # Input, tolt.
    dim2_gen_order2_rectangle_pdedef,
    dim2_gen_order2_rectangle_bndary,
    dim2_gen_order2_rectangle_pdeiv,
    dim2_gen_order2_rectangle_monitr,
    utils._EngineIntArrayType.c_type, # Input, opti[4].
    utils._EngineFloat64ArrayType.c_type, # Input, optr[3, npde].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwk[lenrwk].
    utils._BYREF_INT, # Input, lenrwk.
    utils._EngineIntArrayType.c_type, # Input/Output, iwk[leniwk].
    utils._BYREF_INT, # Input, leniwk.
    utils._EngineLogicalArrayType.c_type, # Workspace, lwk[lenlwk].
    utils._BYREF_INT, # Input, lenlwk.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_gen_order2_rectilinear_inidom = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, maxpts.
    utils._BYREF_FLOAT64, # Output, xmin.
    utils._BYREF_FLOAT64, # Output, xmax.
    utils._BYREF_FLOAT64, # Output, ymin.
    utils._BYREF_FLOAT64, # Output, ymax.
    utils._BYREF_INT, # Output, nx.
    utils._BYREF_INT, # Output, ny.
    utils._BYREF_INT, # Output, npts.
    utils._BYREF_INT, # Output, nrows.
    utils._BYREF_INT, # Output, nbnds.
    utils._BYREF_INT, # Output, nbpts.
    utils._EngineIntArrayType.c_type, # Output, lrow[*].
    utils._EngineIntArrayType.c_type, # Output, irow[*].
    utils._EngineIntArrayType.c_type, # Output, icol[*].
    utils._EngineIntArrayType.c_type, # Output, llbnd[*].
    utils._EngineIntArrayType.c_type, # Output, ilbnd[*].
    utils._EngineIntArrayType.c_type, # Output, lbnd[*].
    utils._BYREF_INT, # Input/Output, ierr.
)
dim2_gen_order2_rectilinear_pdedef = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, y[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uy[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uxx[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uxy[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uyy[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Output, res[npts, npde].
)
dim2_gen_order2_rectilinear_bndary = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, y[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, u[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ut[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, ux[npts, npde].
    utils._EngineFloat64ArrayType.c_type, # Input, uy[npts, npde].
    utils._BYREF_INT, # Input, nbnds.
    utils._BYREF_INT, # Input, nbpts.
    utils._EngineIntArrayType.c_type, # Input, llbnd[nbnds].
    utils._EngineIntArrayType.c_type, # Input, ilbnd[nbnds].
    utils._EngineIntArrayType.c_type, # Input, lbnd[nbpts].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, res[npts, npde].
)
dim2_gen_order2_rectilinear_pdeiv = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npts.
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input, x[npts].
    utils._EngineFloat64ArrayType.c_type, # Input, y[npts].
    utils._EngineFloat64ArrayType.c_type, # Output, u[npts, npde].
)
dim2_gen_order2_rectilinear_monitr = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, dt.
    utils._BYREF_FLOAT64, # Input, dtnew.
    utils._BYREF_LOGICAL, # Input, tlast.
    utils._BYREF_INT, # Input, nlev.
    utils._BYREF_FLOAT64, # Input, xmin.
    utils._BYREF_FLOAT64, # Input, ymin.
    utils._BYREF_FLOAT64, # Input, dxb.
    utils._BYREF_FLOAT64, # Input, dyb.
    utils._EngineIntArrayType.c_type, # Input, lgrid[*].
    utils._EngineIntArrayType.c_type, # Input, istruc[*].
    utils._EngineIntArrayType.c_type, # Input, lsol[nlev].
    utils._EngineFloat64ArrayType.c_type, # Input, sol[*].
    utils._BYREF_INT, # Input/Output, ierr.
)
dim2_gen_order2_rectilinear = utils._EngineState._get_symbol('d03rbf')
dim2_gen_order2_rectilinear.restype = None
dim2_gen_order2_rectilinear.argtypes = (
    utils._BYREF_INT, # Input, npde.
    utils._BYREF_FLOAT64, # Input/Output, ts.
    utils._BYREF_FLOAT64, # Input, tout.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, dt[3].
    utils._BYREF_FLOAT64, # Input, tols.
    utils._BYREF_FLOAT64, # Input, tolt.
    dim2_gen_order2_rectilinear_inidom,
    dim2_gen_order2_rectilinear_pdedef,
    dim2_gen_order2_rectilinear_bndary,
    dim2_gen_order2_rectilinear_pdeiv,
    dim2_gen_order2_rectilinear_monitr,
    utils._EngineIntArrayType.c_type, # Input, opti[4].
    utils._EngineFloat64ArrayType.c_type, # Input, optr[3, npde].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwk[lenrwk].
    utils._BYREF_INT, # Input, lenrwk.
    utils._EngineIntArrayType.c_type, # Input/Output, iwk[leniwk].
    utils._BYREF_INT, # Input, leniwk.
    utils._EngineLogicalArrayType.c_type, # Workspace, lwk[lenlwk].
    utils._BYREF_INT, # Input, lenlwk.
    utils._BYREF_INT, # Input, itrace.
    utils._BYREF_INT, # Input/Output, ind.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_gen_order2_rectilinear_extractgrid = utils._EngineState._get_symbol('d03rzf')
dim2_gen_order2_rectilinear_extractgrid.restype = None
dim2_gen_order2_rectilinear_extractgrid.argtypes = (
    utils._BYREF_INT, # Input, level.
    utils._BYREF_INT, # Input, nlev.
    utils._BYREF_FLOAT64, # Input, xmin.
    utils._BYREF_FLOAT64, # Input, ymin.
    utils._BYREF_FLOAT64, # Input, dxb.
    utils._BYREF_FLOAT64, # Input, dyb.
    utils._EngineIntArrayType.c_type, # Input, lgrid[*].
    utils._EngineIntArrayType.c_type, # Input, istruc[*].
    utils._BYREF_INT, # Output, npts.
    utils._EngineFloat64ArrayType.c_type, # Output, x[lenxy].
    utils._EngineFloat64ArrayType.c_type, # Output, y[lenxy].
    utils._BYREF_INT, # Input, lenxy.
    utils._BYREF_INT, # Input/Output, ifail.
)

dim2_ellip_fd_iter = utils._EngineState._get_symbol('d03uaf')
dim2_ellip_fd_iter.restype = None
dim2_ellip_fd_iter.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, b[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, c[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, d[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Input, e[lda, n2].
    utils._BYREF_FLOAT64, # Input, aparam.
    utils._BYREF_INT, # Input, it.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp1[lda, n2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp2[lda, n2].
    utils._BYREF_INT, # Input/Output, ifail.
)

dim3_ellip_fd_iter = utils._EngineState._get_symbol('d03ubf')
dim3_ellip_fd_iter.restype = None
dim3_ellip_fd_iter.argtypes = (
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_INT, # Input, n3.
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input, sda.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, b[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, c[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, d[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, e[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, f[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Input, g[lda, sda, n3].
    utils._BYREF_FLOAT64, # Input, aparam.
    utils._BYREF_INT, # Input, it.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp1[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp2[lda, sda, n3].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrksp3[lda, sda, n3].
    utils._BYREF_INT, # Input/Output, ifail.
)
