# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `sparseig` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

real_init = utils._EngineState._get_symbol('f12aaf')
real_init.restype = None
real_init.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._EngineIntArrayType.c_type, # Output, icomm[max(1, licomm)].
    utils._BYREF_INT, # Input, licomm.
    utils._EngineFloat64ArrayType.c_type, # Output, comm[max(1, lcomm)].
    utils._BYREF_INT, # Input, lcomm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_iter = utils._EngineState._get_symbol('f12abf')
real_iter.restype = None
real_iter.argtypes = (
    utils._BYREF_INT, # Input/Output, irevcm.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, resid[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, mx[*].
    utils._BYREF_INT, # Output, nshift.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_proc = utils._EngineState._get_symbol('f12acf')
real_proc.restype = None
real_proc.argtypes = (
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, dr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, di[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_FLOAT64, # Input, sigmar.
    utils._BYREF_FLOAT64, # Input, sigmai.
    utils._EngineFloat64ArrayType.c_type, # Input, resid[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_option = utils._EngineState._get_symbol('f12adf')
real_option.restype = None
real_option.argtypes = (
    utils._BYREF_STRING, # Input, str(len=*).
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of str.
)

real_monit = utils._EngineState._get_symbol('f12aef')
real_monit.restype = None
real_monit.argtypes = (
    utils._BYREF_INT, # Output, niter.
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, ritzr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, ritzi[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rzest[*].
    utils._EngineIntArrayType.c_type, # Input, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input, comm[*].
)

real_band_init = utils._EngineState._get_symbol('f12aff')
real_band_init.restype = None
real_band_init.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._EngineIntArrayType.c_type, # Output, icomm[max(1, licomm)].
    utils._BYREF_INT, # Input, licomm.
    utils._EngineFloat64ArrayType.c_type, # Output, comm[max(1, lcomm)].
    utils._BYREF_INT, # Input, lcomm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_band_solve = utils._EngineState._get_symbol('f12agf')
real_band_solve.restype = None
real_band_solve.argtypes = (
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input, mb[ldmb, *].
    utils._BYREF_INT, # Input, ldmb.
    utils._BYREF_FLOAT64, # Input, sigmar.
    utils._BYREF_FLOAT64, # Input, sigmai.
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, dr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, di[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, resid[*].
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_init = utils._EngineState._get_symbol('f12anf')
complex_init.restype = None
complex_init.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._EngineIntArrayType.c_type, # Output, icomm[max(1, licomm)].
    utils._BYREF_INT, # Input, licomm.
    utils._EngineComplex128ArrayType.c_type, # Output, comm[max(1, lcomm)].
    utils._BYREF_INT, # Input, lcomm.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_iter = utils._EngineState._get_symbol('f12apf')
complex_iter.restype = None
complex_iter.argtypes = (
    utils._BYREF_INT, # Input/Output, irevcm.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, resid[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, mx[*].
    utils._BYREF_INT, # Output, nshift.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_proc = utils._EngineState._get_symbol('f12aqf')
complex_proc.restype = None
complex_proc.argtypes = (
    utils._BYREF_INT, # Output, nconv.
    utils._EngineComplex128ArrayType.c_type, # Output, d[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_COMPLEX128, # Input, sigma.
    utils._EngineComplex128ArrayType.c_type, # Input, resid[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_option = utils._EngineState._get_symbol('f12arf')
complex_option.restype = None
complex_option.argtypes = (
    utils._BYREF_STRING, # Input, str(len=*).
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of str.
)

complex_monit = utils._EngineState._get_symbol('f12asf')
complex_monit.restype = None
complex_monit.argtypes = (
    utils._BYREF_INT, # Output, niter.
    utils._BYREF_INT, # Output, nconv.
    utils._EngineComplex128ArrayType.c_type, # Output, ritz[*].
    utils._EngineComplex128ArrayType.c_type, # Output, rzest[*].
    utils._EngineIntArrayType.c_type, # Input, icomm[*].
    utils._EngineComplex128ArrayType.c_type, # Input, comm[*].
)

complex_band_init = utils._EngineState._get_symbol('f12atf')
complex_band_init.restype = None
complex_band_init.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._EngineIntArrayType.c_type, # Output, icomm[max(1, licomm)].
    utils._BYREF_INT, # Input, licomm.
    utils._EngineComplex128ArrayType.c_type, # Output, comm[max(1, lcomm)].
    utils._BYREF_INT, # Input, lcomm.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_band_solve = utils._EngineState._get_symbol('f12auf')
complex_band_solve.restype = None
complex_band_solve.argtypes = (
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input, mb[ldmb, *].
    utils._BYREF_INT, # Input, ldmb.
    utils._BYREF_COMPLEX128, # Input, sigma.
    utils._BYREF_INT, # Output, nconv.
    utils._EngineComplex128ArrayType.c_type, # Output, d[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, resid[*].
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, comm[60].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[140].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_init = utils._EngineState._get_symbol('f12faf')
real_symm_init.restype = None
real_symm_init.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._EngineIntArrayType.c_type, # Output, icomm[max(1, licomm)].
    utils._BYREF_INT, # Input, licomm.
    utils._EngineFloat64ArrayType.c_type, # Output, comm[max(1, lcomm)].
    utils._BYREF_INT, # Input, lcomm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_iter = utils._EngineState._get_symbol('f12fbf')
real_symm_iter.restype = None
real_symm_iter.argtypes = (
    utils._BYREF_INT, # Input/Output, irevcm.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, resid[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, mx[*].
    utils._BYREF_INT, # Output, nshift.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_proc = utils._EngineState._get_symbol('f12fcf')
real_symm_proc.restype = None
real_symm_proc.argtypes = (
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_FLOAT64, # Input, sigma.
    utils._EngineFloat64ArrayType.c_type, # Input, resid[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_option = utils._EngineState._get_symbol('f12fdf')
real_symm_option.restype = None
real_symm_option.argtypes = (
    utils._BYREF_STRING, # Input, str(len=*).
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of str.
)

real_symm_monit = utils._EngineState._get_symbol('f12fef')
real_symm_monit.restype = None
real_symm_monit.argtypes = (
    utils._BYREF_INT, # Output, niter.
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, ritz[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rzest[*].
    utils._EngineIntArrayType.c_type, # Input, icomm[*].
    utils._EngineFloat64ArrayType.c_type, # Input, comm[*].
)

real_symm_band_init = utils._EngineState._get_symbol('f12fff')
real_symm_band_init.restype = None
real_symm_band_init.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nev.
    utils._BYREF_INT, # Input, ncv.
    utils._EngineIntArrayType.c_type, # Output, icomm[max(1, licomm)].
    utils._BYREF_INT, # Input, licomm.
    utils._EngineFloat64ArrayType.c_type, # Output, comm[max(1, lcomm)].
    utils._BYREF_INT, # Input, lcomm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_band_solve = utils._EngineState._get_symbol('f12fgf')
real_symm_band_solve.restype = None
real_symm_band_solve.argtypes = (
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input, mb[ldmb, *].
    utils._BYREF_INT, # Input, ldmb.
    utils._BYREF_FLOAT64, # Input, sigma.
    utils._BYREF_INT, # Output, nconv.
    utils._EngineFloat64ArrayType.c_type, # Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, resid[*].
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[*].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[*].
    utils._BYREF_INT, # Input/Output, ifail.
)
