# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `surviv` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

kaplanmeier = utils._EngineState._get_symbol('g12aaf')
kaplanmeier.restype = None
kaplanmeier.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, t[n].
    utils._EngineIntArrayType.c_type, # Input, ic[n].
    utils._BYREF_STRING, # Input, freq(len=1).
    utils._EngineIntArrayType.c_type, # Input, ifreq[*].
    utils._BYREF_INT, # Output, nd.
    utils._EngineFloat64ArrayType.c_type, # Output, tp[n].
    utils._EngineFloat64ArrayType.c_type, # Output, p[n].
    utils._EngineFloat64ArrayType.c_type, # Output, psig[n].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of freq.
)

logrank = utils._EngineState._get_symbol('g12abf')
logrank.restype = None
logrank.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, t[n].
    utils._EngineIntArrayType.c_type, # Input, ic[n].
    utils._EngineIntArrayType.c_type, # Input, grp[n].
    utils._BYREF_INT, # Input, ngrp.
    utils._BYREF_STRING, # Input, freq(len=1).
    utils._EngineIntArrayType.c_type, # Input, ifreq[*].
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._BYREF_FLOAT64, # Output, ts.
    utils._BYREF_INT, # Output, df.
    utils._BYREF_FLOAT64, # Output, p.
    utils._EngineFloat64ArrayType.c_type, # Output, obsd[ngrp].
    utils._EngineFloat64ArrayType.c_type, # Output, expt[ngrp].
    utils._BYREF_INT, # Output, nd.
    utils._EngineIntArrayType.c_type, # Output, di[ldn].
    utils._EngineIntArrayType.c_type, # Output, ni[ldn].
    utils._BYREF_INT, # Input, ldn.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of freq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

coxmodel = utils._EngineState._get_symbol('g12baf')
coxmodel.restype = None
coxmodel.argtypes = (
    utils._BYREF_STRING, # Input, offset(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, ns.
    utils._EngineFloat64ArrayType.c_type, # Input, z[ldz, m].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Input, isz[m].
    utils._BYREF_INT, # Input, ip.
    utils._EngineFloat64ArrayType.c_type, # Input, t[n].
    utils._EngineIntArrayType.c_type, # Input, ic[n].
    utils._EngineFloat64ArrayType.c_type, # Input, omega[*].
    utils._EngineIntArrayType.c_type, # Input, isi[*].
    utils._BYREF_FLOAT64, # Output, dev.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, se[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, sc[ip].
    utils._EngineFloat64ArrayType.c_type, # Output, cov[ip*(ip+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, res[n].
    utils._BYREF_INT, # Output, nd.
    utils._EngineFloat64ArrayType.c_type, # Output, tp[ndmax].
    utils._EngineFloat64ArrayType.c_type, # Output, sur[ndmax, *].
    utils._BYREF_INT, # Input, ndmax.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_INT, # Input, iprint.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[ip*(ip+9)/2+n].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[2*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of offset.
)

coxmodel_risksets = utils._EngineState._get_symbol('g12zaf')
coxmodel_risksets.restype = None
coxmodel_risksets.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, ns.
    utils._EngineFloat64ArrayType.c_type, # Input, z[ldz, m].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Input, isz[m].
    utils._BYREF_INT, # Input, ip.
    utils._EngineFloat64ArrayType.c_type, # Input, t[n].
    utils._EngineIntArrayType.c_type, # Input, ic[n].
    utils._EngineIntArrayType.c_type, # Input, isi[*].
    utils._BYREF_INT, # Output, num.
    utils._EngineIntArrayType.c_type, # Output, ixs[mxn].
    utils._BYREF_INT, # Output, nxs.
    utils._EngineFloat64ArrayType.c_type, # Output, x[mxn, ip].
    utils._BYREF_INT, # Input, mxn.
    utils._EngineIntArrayType.c_type, # Output, id[mxn].
    utils._BYREF_INT, # Output, nd.
    utils._EngineFloat64ArrayType.c_type, # Output, tp[n].
    utils._EngineIntArrayType.c_type, # Output, irs[n].
    utils._BYREF_INT, # Input/Output, ifail.
)
