# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `univar` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

ci_binomial = utils._EngineState._get_symbol('g07aaf')
ci_binomial.restype = None
ci_binomial.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_FLOAT64, # Input, clevel.
    utils._BYREF_FLOAT64, # Output, pl.
    utils._BYREF_FLOAT64, # Output, pu.
    utils._BYREF_INT, # Input/Output, ifail.
)

ci_poisson = utils._EngineState._get_symbol('g07abf')
ci_poisson.restype = None
ci_poisson.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, xmean.
    utils._BYREF_FLOAT64, # Input, clevel.
    utils._BYREF_FLOAT64, # Output, tl.
    utils._BYREF_FLOAT64, # Output, tu.
    utils._BYREF_INT, # Input/Output, ifail.
)

estim_normal = utils._EngineState._get_symbol('g07bbf')
estim_normal.restype = None
estim_normal.argtypes = (
    utils._BYREF_STRING, # Input, method(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Input, xc[n].
    utils._EngineIntArrayType.c_type, # Input, ic[n].
    utils._BYREF_FLOAT64, # Input/Output, xmu.
    utils._BYREF_FLOAT64, # Input/Output, xsig.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_FLOAT64, # Output, sexmu.
    utils._BYREF_FLOAT64, # Output, sexsig.
    utils._BYREF_FLOAT64, # Output, corr.
    utils._BYREF_FLOAT64, # Output, dev.
    utils._EngineIntArrayType.c_type, # Output, nobs[4].
    utils._BYREF_INT, # Output, nit.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[2*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of method.
)

estim_weibull = utils._EngineState._get_symbol('g07bef')
estim_weibull.restype = None
estim_weibull.argtypes = (
    utils._BYREF_STRING, # Input, cens(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineIntArrayType.c_type, # Input, ic[*].
    utils._BYREF_FLOAT64, # Output, beta.
    utils._BYREF_FLOAT64, # Input/Output, gamma.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_FLOAT64, # Output, sebeta.
    utils._BYREF_FLOAT64, # Output, segam.
    utils._BYREF_FLOAT64, # Output, corr.
    utils._BYREF_FLOAT64, # Output, dev.
    utils._BYREF_INT, # Output, nit.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of cens.
)

estim_genpareto = utils._EngineState._get_symbol('g07bff')
estim_genpareto.restype = None
estim_genpareto.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_INT, # Input, optopt.
    utils._BYREF_FLOAT64, # Output, xi.
    utils._BYREF_FLOAT64, # Output, beta.
    utils._EngineFloat64ArrayType.c_type, # Output, asvc[4].
    utils._EngineFloat64ArrayType.c_type, # Output, obsvc[4].
    utils._BYREF_FLOAT64, # Output, ll.
    utils._BYREF_INT, # Input/Output, ifail.
)

ttest_2normal = utils._EngineState._get_symbol('g07caf')
ttest_2normal.restype = None
ttest_2normal.argtypes = (
    utils._BYREF_STRING, # Input, tail(len=1).
    utils._BYREF_STRING, # Input, equal(len=1).
    utils._BYREF_INT, # Input, nx.
    utils._BYREF_INT, # Input, ny.
    utils._BYREF_FLOAT64, # Input, xmean.
    utils._BYREF_FLOAT64, # Input, ymean.
    utils._BYREF_FLOAT64, # Input, xstd.
    utils._BYREF_FLOAT64, # Input, ystd.
    utils._BYREF_FLOAT64, # Input, clevel.
    utils._BYREF_FLOAT64, # Output, t.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_FLOAT64, # Output, prob.
    utils._BYREF_FLOAT64, # Output, dl.
    utils._BYREF_FLOAT64, # Output, du.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equal.
)

robust_1var_median = utils._EngineState._get_symbol('g07daf')
robust_1var_median.restype = None
robust_1var_median.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Output, y[n].
    utils._BYREF_FLOAT64, # Output, xme.
    utils._BYREF_FLOAT64, # Output, xmd.
    utils._BYREF_FLOAT64, # Output, xsd.
    utils._BYREF_INT, # Input/Output, ifail.
)

robust_1var_mestim = utils._EngineState._get_symbol('g07dbf')
robust_1var_mestim.restype = None
robust_1var_mestim.argtypes = (
    utils._BYREF_INT, # Input, isigma.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, ipsi.
    utils._BYREF_FLOAT64, # Input, c.
    utils._BYREF_FLOAT64, # Input, h1.
    utils._BYREF_FLOAT64, # Input, h2.
    utils._BYREF_FLOAT64, # Input, h3.
    utils._BYREF_FLOAT64, # Input, dchi.
    utils._BYREF_FLOAT64, # Input/Output, theta.
    utils._BYREF_FLOAT64, # Input/Output, sigma.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Output, rs[n].
    utils._BYREF_INT, # Output, nit.
    utils._EngineFloat64ArrayType.c_type, # Output, wrk[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

robust_1var_mestim_wgt_chi = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
robust_1var_mestim_wgt_psi = utils._EngineState._sys_functype(
    utils._EngineFloat64ScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, t.
)
robust_1var_mestim_wgt = utils._EngineState._get_symbol('g07dcf')
robust_1var_mestim_wgt.restype = None
robust_1var_mestim_wgt.argtypes = (
    robust_1var_mestim_wgt_chi,
    robust_1var_mestim_wgt_psi,
    utils._BYREF_INT, # Input, isigma.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_FLOAT64, # Input, beta.
    utils._BYREF_FLOAT64, # Input/Output, theta.
    utils._BYREF_FLOAT64, # Input/Output, sigma.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Output, rs[n].
    utils._BYREF_INT, # Output, nit.
    utils._EngineFloat64ArrayType.c_type, # Output, wrk[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

robust_1var_trimmed = utils._EngineState._get_symbol('g07ddf')
robust_1var_trimmed.restype = None
robust_1var_trimmed.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._BYREF_FLOAT64, # Output, tmean.
    utils._BYREF_FLOAT64, # Output, wmean.
    utils._BYREF_FLOAT64, # Output, tvar.
    utils._BYREF_FLOAT64, # Output, wvar.
    utils._BYREF_INT, # Output, k.
    utils._EngineFloat64ArrayType.c_type, # Output, sx[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

robust_1var_ci = utils._EngineState._get_symbol('g07eaf')
robust_1var_ci.restype = None
robust_1var_ci.argtypes = (
    utils._BYREF_STRING, # Input, method(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_FLOAT64, # Input, clevel.
    utils._BYREF_FLOAT64, # Output, theta.
    utils._BYREF_FLOAT64, # Output, thetal.
    utils._BYREF_FLOAT64, # Output, thetau.
    utils._BYREF_FLOAT64, # Output, estcl.
    utils._BYREF_FLOAT64, # Output, wlower.
    utils._BYREF_FLOAT64, # Output, wupper.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[4*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwrk[3*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of method.
)

robust_2var_ci = utils._EngineState._get_symbol('g07ebf')
robust_2var_ci.restype = None
robust_2var_ci.argtypes = (
    utils._BYREF_STRING, # Input, method(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, y[m].
    utils._BYREF_FLOAT64, # Input, clevel.
    utils._BYREF_FLOAT64, # Output, theta.
    utils._BYREF_FLOAT64, # Output, thetal.
    utils._BYREF_FLOAT64, # Output, thetau.
    utils._BYREF_FLOAT64, # Output, estcl.
    utils._BYREF_FLOAT64, # Output, ulower.
    utils._BYREF_FLOAT64, # Output, uupper.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wrk[3*(m+n)].
    utils._EngineIntArrayType.c_type, # Workspace, iwrk[3*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of method.
)

outlier_peirce_1var = utils._EngineState._get_symbol('g07gaf')
outlier_peirce_1var.restype = None
outlier_peirce_1var.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._EngineFloat64ArrayType.c_type, # Input, y[n].
    utils._BYREF_FLOAT64, # Input, mean.
    utils._BYREF_FLOAT64, # Input, var.
    utils._EngineIntArrayType.c_type, # Output, iout[n].
    utils._BYREF_INT, # Output, niout.
    utils._BYREF_INT, # Input, ldiff.
    utils._EngineFloat64ArrayType.c_type, # Output, diff[ldiff].
    utils._EngineFloat64ArrayType.c_type, # Output, llamb[ldiff].
    utils._BYREF_INT, # Input/Output, ifail.
)

outlier_peirce_2var = utils._EngineState._get_symbol('g07gbf')
outlier_peirce_2var.restype = utils._EngineLogicalScalarType.c_type
outlier_peirce_2var.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, e.
    utils._BYREF_FLOAT64, # Input, var1.
    utils._BYREF_FLOAT64, # Input, var2.
    utils._BYREF_FLOAT64, # Output, x.
    utils._BYREF_FLOAT64, # Output, lx.
    utils._BYREF_FLOAT64, # Output, ux.
    utils._BYREF_INT, # Input/Output, ifail.
)
