# -*- coding: utf-8 -*-
u"""
Examples for the ``eigen`` module.

``eigen`` - Eigenvalues and Eigenvectors

This module provides functions for various types of matrix eigenvalue
problem:

    standard eigenvalue problems (finding eigenvalues and eigenvectors
    of a square matrix A);

    singular value problems (finding singular values and singular
    vectors of a rectangular matrix A);

    generalized eigenvalue problems (finding eigenvalues and
    eigenvectors of a matrix pencil A-lambda B).

    quadratic eigenvalue problems (finding eigenvalues and eigenvectors
    of the quadratic lambda^2A+lambda B+C).

Functions are provided for both `real` and `complex` data.

The majority of functions for these problems can be found in submodule
``lapackeig`` which contains software derived from LAPACK (see Anderson
`et al.` (1999)).
However, you should read [the F02 Introduction] before turning to
submodule ``lapackeig``, especially if you are a new user. Submodule
``sparseig`` contains functions for large sparse eigenvalue problems,
although one such function is also available in this module.

Submodule ``eigen`` and submodule ``lapackeig`` contain **Black Box**
(or **Driver**) functions that enable many problems to be solved by a
call to a single function, and the decision trees in [Decision Trees]
direct you to the most appropriate functions in submodule ``eigen`` and
submodule ``lapackeig``.
The submodule ``eigen`` functions call functions in submodule
``lapacklin`` and submodule ``lapackeig`` wherever possible to perform
the computations, and there are pointers in [Decision Trees] to the
relevant decision trees in submodule ``lapackeig``.

For full information please refer to the NAG Library document

https://www.nag.com/numeric/nl/nagdoc_27/flhtml/f02/f02intro.html
"""

# NAG Copyright 2017-2020.

pass
