# -*- coding: utf-8 -*-
u"""
Examples for the ``fit`` module.

``fit`` - Curve and Surface Fitting

The main aim of this module is to assist you in finding a function which
approximates a set of data points.
Typically the data contain random errors, as of experimental
measurement, which need to be smoothed out.
To seek an approximation to the data, it is first necessary to specify
for the approximating function a mathematical form (a polynomial, for
example) which contains a number of unspecified coefficients: the
appropriate fitting function then derives for the coefficients the
values which provide the best fit of that particular form.
The module deals mainly with curve and surface fitting (i.e., fitting
with functions of one and of two variables) when a polynomial or a cubic
spline is used as the fitting function, since these cover the most
common needs.
However, fitting with other functions and/or more variables can be
undertaken by means of general linear or nonlinear functions (some of
which are contained in other modules) depending on whether the
coefficients in the function occur linearly or nonlinearly.
Cases where a graph rather than a set of data points is given can be
treated simply by first reading a suitable set of points from the graph.

The module also contains functions for evaluating, differentiating and
integrating polynomial and spline curves and surfaces, once the
numerical values of their coefficients have been determined.

There is also a function for computing a Padé approximant of a
mathematical function (see [Background to the Problems]).

For full information please refer to the NAG Library document

https://www.nag.com/numeric/nl/nagdoc_27/flhtml/e02/e02intro.html
"""

# NAG Copyright 2017-2020.

pass
