# -*- coding: utf-8 -*-
u"""
Examples for the ``lapackeig`` module.

``lapackeig`` - Least Squares and Eigenvalue Problems (LAPACK)

This module provides functions for the solution of linear least squares
problems, eigenvalue problems and singular value problems, as well as
associated computations.
It provides functions for:

    solution of linear least squares problems;

    solution of symmetric eigenvalue problems;

    solution of nonsymmetric eigenvalue problems;

    solution of singular value problems;

    solution of generalized linear least squares problems;

    solution of generalized symmetric-definite eigenvalue problems;

    solution of generalized nonsymmetric eigenvalue problems;

    solution of generalized singular value problems;

    matrix factorizations associated with the above problems;

    estimating condition numbers of eigenvalue and eigenvector problems;

    estimating the numerical rank of a matrix;

    solution of the Sylvester matrix equation.

Functions are provided for both `real` and `complex` data.

For a general introduction to the solution of linear least squares
problems, you should turn first to submodule ``linsys``.
The decision trees, at the end of submodule ``linsys``, direct you to
the most appropriate functions in submodule ``linsys`` or submodule
``lapackeig``. Submodule ``linsys`` and submodule ``lapackeig`` contain
`Black Box` (or `driver`) functions which enable standard linear least
squares problems to be solved by a call to a single function.

For a general introduction to eigenvalue and singular value problems,
you should turn first to submodule ``eigen``.
The decision trees, at the end of submodule ``eigen``, direct you to the
most appropriate functions in submodule ``eigen`` or submodule
``lapackeig``. Submodule ``eigen`` and submodule ``lapackeig`` contain
`Black Box` (or `driver`) functions which enable standard types of
problem to be solved by a call to a single function.
Often functions in submodule ``eigen`` call submodule ``lapackeig``
functions to perform the necessary computational tasks.

The functions in this module (submodule ``lapackeig``) handle only
`dense`, `band`, `tridiagonal` and `Hessenberg` matrices (not matrices
with more specialised structures, or general sparse matrices).
The tables in [Available Functions] and the decision trees in [Decision
Trees] direct you to the most appropriate functions in submodule
``lapackeig``.

The functions in this module have all been derived from the LAPACK
project (see Anderson `et al.` (1999)).
They have been designed to be efficient on a wide range of
high-performance computers, without compromising efficiency on
conventional serial machines.

For full information please refer to the NAG Library document

https://www.nag.com/numeric/nl/nagdoc_27/flhtml/f08/f08intro.html
"""

# NAG Copyright 2017-2020.

pass
