# -*- coding: utf-8 -*-
u"""
Examples for the ``sparseig`` module.

``sparseig`` - Large Scale Eigenproblems

This module provides functions for computing **some** eigenvalues and
eigenvectors of large-scale (sparse) standard and generalized eigenvalue
problems.
It provides functions for:

    solution of symmetric eigenvalue problems;

    solution of nonsymmetric eigenvalue problems;

    solution of generalized symmetric-definite eigenvalue problems;

    solution of generalized nonsymmetric eigenvalue problems;

    partial singular value decomposition.

Functions are provided for both `real` and `complex` data.

The functions in this module have all been derived from the ARPACK
software suite (see Lehoucq `et al.` (1998)), a collection of Fortran 77
functions designed to solve large scale eigenvalue problems.
The interfaces provided in this module have been chosen to combine ease
of use with the flexibility of the original ARPACK software.
The underlying iterative methods and algorithms remain essentially the
same as those in ARPACK and are described fully in Lehoucq `et al.`
(1998).

The algorithms used are based upon an algorithmic variant of the Arnoldi
process called the Implicitly Restarted Arnoldi Method.
For symmetric matrices, this reduces to a variant of the Lanczos process
called the Implicitly Restarted Lanczos Method.
These variants may be viewed as a synthesis of the Arnoldi/Lanczos
process with the Implicitly Shifted QR technique that is suitable for
large scale problems.
For many standard problems, a matrix factorization is not required.
Only the action of the matrix on a vector is needed.

For full information please refer to the NAG Library document

https://www.nag.com/numeric/nl/nagdoc_27/flhtml/f12/f12intro.html
"""

# NAG Copyright 2017-2020.

pass
