"""
Deprecated wrappers for the NAG C Library (Mark 26.0) g04 Chapter.

g04 - Analysis of Variance.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/G04/g04conts.html

NAG Copyright 2017.
"""
from ctypes import c_double
from ctypes import POINTER

from .util import get_library
from .util import Integer
from .util import NagError
from .util import Nag_Blocks
from .util import Nag_IntervalType
from .util import Nag_DummyType

_library_cl = get_library()


g04bbc_ctypes = _library_cl.g04bbc
g04bbc_ctypes.restype = None
g04bbc_ctypes.argtypes = [Integer, POINTER(c_double), Nag_Blocks, Integer, Integer, POINTER(Integer), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), POINTER(c_double), c_double, Integer, POINTER(NagError)]


def g04bbc(n, y, blocks, iblock, nt, it, gmean, bmean, tmean, table, c, tdc, irep, r, ef, tol, irdf, fail):
    """
    General block design or completely randomized design.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g04/g04bbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        y, it, gmean, bmean, tmean, table, c, irep, r, ef
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        y, gmean, bmean, tmean, table, c, r, ef
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        it, irep
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _y = nag_double_type_check_and_cast('g04bbc', y, 'y')
    _it = nag_integer_type_check_and_cast('g04bbc', it, 'it')
    _gmean = nag_double_type_check_and_cast('g04bbc', gmean, 'gmean')
    _bmean = nag_double_type_check_and_cast('g04bbc', bmean, 'bmean')
    _tmean = nag_double_type_check_and_cast('g04bbc', tmean, 'tmean')
    _table = nag_double_type_check_and_cast('g04bbc', table, 'table')
    _c = nag_double_type_check_and_cast('g04bbc', c, 'c')
    _irep = nag_integer_type_check_and_cast('g04bbc', irep, 'irep')
    _r = nag_double_type_check_and_cast('g04bbc', r, 'r')
    _ef = nag_double_type_check_and_cast('g04bbc', ef, 'ef')
    g04bbc_ctypes(n, _y, blocks, iblock, nt, _it, _gmean, _bmean, _tmean, _table, _c, tdc, _irep, _r, _ef, tol, irdf, fail)

g04bcc_ctypes = _library_cl.g04bcc
g04bcc_ctypes.restype = None
g04bcc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), c_double, Integer, POINTER(NagError)]


def g04bcc(nrep, nrow, ncol, y, nt, it, gmean, tmean, table, c, tdc, irep, rpmean, rmean, cmean, r, ef, tol, irdf, fail):
    """
    Analysis of variance, general row and column design, treatment means and
    standard errors.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g04/g04bcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        y, it, gmean, tmean, table, c, irep, rpmean, rmean, cmean, r, ef
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        y, gmean, tmean, table, c, rpmean, rmean, cmean, r, ef
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        it, irep
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _y = nag_double_type_check_and_cast('g04bcc', y, 'y')
    _it = nag_integer_type_check_and_cast('g04bcc', it, 'it')
    _gmean = nag_double_type_check_and_cast('g04bcc', gmean, 'gmean')
    _tmean = nag_double_type_check_and_cast('g04bcc', tmean, 'tmean')
    _table = nag_double_type_check_and_cast('g04bcc', table, 'table')
    _c = nag_double_type_check_and_cast('g04bcc', c, 'c')
    _irep = nag_integer_type_check_and_cast('g04bcc', irep, 'irep')
    _rpmean = nag_double_type_check_and_cast('g04bcc', rpmean, 'rpmean')
    _rmean = nag_double_type_check_and_cast('g04bcc', rmean, 'rmean')
    _cmean = nag_double_type_check_and_cast('g04bcc', cmean, 'cmean')
    _r = nag_double_type_check_and_cast('g04bcc', r, 'r')
    _ef = nag_double_type_check_and_cast('g04bcc', ef, 'ef')
    g04bcc_ctypes(nrep, nrow, ncol, _y, nt, _it, _gmean, _tmean, _table, _c, tdc, _irep, _rpmean, _rmean, _cmean, _r, _ef, tol, irdf, fail)

g04cac_ctypes = _library_cl.g04cac
g04cac_ctypes.restype = None
g04cac_ctypes.argtypes = [Integer, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, POINTER(Integer), POINTER(POINTER(c_double)), POINTER(POINTER(c_double)), POINTER(Integer), POINTER(POINTER(c_double)), POINTER(POINTER(Integer)), POINTER(POINTER(c_double)), POINTER(POINTER(c_double)), POINTER(c_double), POINTER(NagError)]


def g04cac(n, y, nfac, lfac, nblock, inter, irdf, mterm, table, tmean, maxt, e, imean, semean, bmean, r, fail):
    """
    Complete factorial design.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g04/g04cac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        y, lfac, mterm, table, tmean, maxt, e, imean, semean, bmean, r
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        y, table, tmean, e, semean, bmean, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        lfac, mterm, maxt, imean
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _y = nag_double_type_check_and_cast('g04cac', y, 'y')
    _lfac = nag_integer_type_check_and_cast('g04cac', lfac, 'lfac')
    _mterm = nag_integer_type_check_and_cast('g04cac', mterm, 'mterm')
    _table = nag_double_type_check_and_cast('g04cac', table, 'table')
    _tmean = nag_double_type_check_and_cast('g04cac', tmean, 'tmean')
    _maxt = nag_integer_type_check_and_cast('g04cac', maxt, 'maxt')
    _e = nag_double_type_check_and_cast('g04cac', e, 'e')
    _imean = nag_integer_type_check_and_cast('g04cac', imean, 'imean')
    _semean = nag_double_type_check_and_cast('g04cac', semean, 'semean')
    _bmean = nag_double_type_check_and_cast('g04cac', bmean, 'bmean')
    _r = nag_double_type_check_and_cast('g04cac', r, 'r')
    g04cac_ctypes(n, _y, nfac, _lfac, nblock, inter, irdf, _mterm, _table, _tmean, _maxt, _e, _imean, _semean, _bmean, _r, fail)

g04czc_ctypes = _library_cl.g04czc
g04czc_ctypes.restype = None
g04czc_ctypes.argtypes = [POINTER(POINTER(c_double)), POINTER(POINTER(c_double)), POINTER(POINTER(c_double)), POINTER(POINTER(Integer)), POINTER(POINTER(c_double)), POINTER(POINTER(c_double))]


def g04czc(table, tmean, e, imean, semean, bmean):
    """
    Memory freeing function for g04cac.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g04/g04czc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        table, tmean, e, imean, semean, bmean
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        table, tmean, e, semean, bmean
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        imean
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _table = nag_double_type_check_and_cast('g04czc', table, 'table')
    _tmean = nag_double_type_check_and_cast('g04czc', tmean, 'tmean')
    _e = nag_double_type_check_and_cast('g04czc', e, 'e')
    _imean = nag_integer_type_check_and_cast('g04czc', imean, 'imean')
    _semean = nag_double_type_check_and_cast('g04czc', semean, 'semean')
    _bmean = nag_double_type_check_and_cast('g04czc', bmean, 'bmean')
    g04czc_ctypes(_table, _tmean, _e, _imean, _semean, _bmean)

g04dbc_ctypes = _library_cl.g04dbc
g04dbc_ctypes.restype = None
g04dbc_ctypes.argtypes = [Nag_IntervalType, Integer, POINTER(c_double), c_double, POINTER(c_double), Integer, c_double, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def g04dbc(_type, nt, tmean, rdf, c, tdc, clevel, cil, ciu, isig, fail):
    """
    Computes confidence intervals for differences between means computed by
    g04bbc or g04bcc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g04/g04dbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        tmean, c, cil, ciu, isig
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        tmean, c, cil, ciu
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isig
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _tmean = nag_double_type_check_and_cast('g04dbc', tmean, 'tmean')
    _c = nag_double_type_check_and_cast('g04dbc', c, 'c')
    _cil = nag_double_type_check_and_cast('g04dbc', cil, 'cil')
    _ciu = nag_double_type_check_and_cast('g04dbc', ciu, 'ciu')
    _isig = nag_integer_type_check_and_cast('g04dbc', isig, 'isig')
    g04dbc_ctypes(_type, nt, _tmean, rdf, _c, tdc, clevel, _cil, _ciu, _isig, fail)

g04eac_ctypes = _library_cl.g04eac
g04eac_ctypes.restype = None
g04eac_ctypes.argtypes = [Nag_DummyType, Integer, Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), POINTER(NagError)]


def g04eac(_type, n, levels, factor, x, tdx, v, numreps, fail):
    """
    Computes orthogonal polynomials or dummy variables for
    factor/classification variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g04/g04eac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        factor, x, v, numreps
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, v, numreps
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        factor
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _factor = nag_integer_type_check_and_cast('g04eac', factor, 'factor')
    _x = nag_double_type_check_and_cast('g04eac', x, 'x')
    _v = nag_double_type_check_and_cast('g04eac', v, 'v')
    _numreps = nag_double_type_check_and_cast('g04eac', numreps, 'numreps')
    g04eac_ctypes(_type, n, levels, _factor, _x, tdx, _v, _numreps, fail)

nag_anova_random = g04bbc
nag_anova_row_col = g04bcc
nag_anova_factorial = g04cac
nag_anova_factorial_free = g04czc
nag_anova_confid_interval = g04dbc
nag_dummy_vars = g04eac
__all__ = ['g04bbc', 'g04bcc', 'g04cac', 'g04czc',
           'g04dbc', 'g04eac', 'nag_anova_confid_interval',
           'nag_anova_factorial',
           'nag_anova_factorial_free',
           'nag_anova_random', 'nag_anova_row_col', 'nag_dummy_vars']
