"""
Deprecated wrappers for the NAG C Library (Mark 26.0) g05 Chapter.

g05 - Random Number Generators.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/G05/g05conts.html

NAG Copyright 2017.
"""
from ctypes import POINTER
from ctypes import c_double
from ctypes import c_char_p
from ctypes import c_ulong
from .util import get_library
from .util import Nag_Boolean
from .util import Integer
from .util import NagError
from .util import Nag_DataByObsOrVar

from .util import Nag_DiscreteDistrib
from .util import Nag_BaseRNG
from .util import Nag_OrderType
from .util import Nag_SortOrder
from .util import Nag_ErrorDistn
from .util import Nag_ModeRNG
from .util import Nag_InitialValues
from .util import Nag_ExpSmoothType
from .util import Nag_SideType
from .util import Nag_InitializeA
from .util import Nag_BridgeOrder
from .util import Nag_QuasiRandom_Sequence
from .util import Nag_QuasiRandom_Scrambling
from .util import NAG_G05ZMC_COV1
from .util import Nag_EmbedPad
from .util import Nag_EmbedScale
from .util import Nag_Comm
from .util import Nag_Variogram
from .util import NAG_G05ZQC_COV2
from .util import Nag_Parity
from .util import Nag_NormType

_library_cl = get_library()
STRING = c_char_p
size_t = c_ulong

g05kfc_ctypes = _library_cl.g05kfc
g05kfc_ctypes.restype = None
g05kfc_ctypes.argtypes = [Nag_BaseRNG, Integer, POINTER(Integer), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05kfc(genid, subid, seed, lseed, state, lstate, fail):
    """
    Initializes a pseudorandom number generator to give a repeatable
    sequence.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05kfc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        seed, state, lstate
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        seed, state, lstate
    """
    from .util import nag_integer_type_check_and_cast
    _seed = nag_integer_type_check_and_cast('g05kfc', seed, 'seed')
    _state = nag_integer_type_check_and_cast('g05kfc', state, 'state')
    _lstate = nag_integer_type_check_and_cast('g05kfc', lstate, 'lstate')
    g05kfc_ctypes(genid, subid, _seed, lseed, _state, _lstate, fail)

g05kgc_ctypes = _library_cl.g05kgc
g05kgc_ctypes.restype = None
g05kgc_ctypes.argtypes = [Nag_BaseRNG, Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05kgc(genid, subid, state, lstate, fail):
    """
    Initializes a pseudorandom number generator to give a non-repeatable
    sequence.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05kgc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, lstate
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, lstate
    """
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05kgc', state, 'state')
    _lstate = nag_integer_type_check_and_cast('g05kgc', lstate, 'lstate')
    g05kgc_ctypes(genid, subid, _state, _lstate, fail)

g05khc_ctypes = _library_cl.g05khc
g05khc_ctypes.restype = None
g05khc_ctypes.argtypes = [Integer, Integer, POINTER(Integer), POINTER(NagError)]


def g05khc(n, k, state, fail):
    """
    Primes a pseudorandom number generator for generating multiple streams
    using leap-frog.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05khc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05khc', state, 'state')
    g05khc_ctypes(n, k, _state, fail)

g05kjc_ctypes = _library_cl.g05kjc
g05kjc_ctypes.restype = None
g05kjc_ctypes.argtypes = [Integer, POINTER(Integer), POINTER(NagError)]


def g05kjc(n, state, fail):
    """
    Primes a pseudorandom number generator for generating multiple streams
    using skip-ahead.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05kjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05kjc', state, 'state')
    g05kjc_ctypes(n, _state, fail)

g05kkc_ctypes = _library_cl.g05kkc
g05kkc_ctypes.restype = None
g05kkc_ctypes.argtypes = [Integer, POINTER(Integer), POINTER(NagError)]


def g05kkc(n, state, fail):
    """
    Primes a pseudorandom number generator for generating multiple streams
    using skip-ahead, skipping ahead a power of 2.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05kkc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05kkc', state, 'state')
    g05kkc_ctypes(n, _state, fail)

g05ncc_ctypes = _library_cl.g05ncc
g05ncc_ctypes.restype = None
g05ncc_ctypes.argtypes = [POINTER(Integer), Integer, POINTER(Integer), POINTER(NagError)]


def g05ncc(indx, n, state, fail):
    """
    Pseudorandom permutation of an integer vector.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ncc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        indx, state
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        indx, state
    """
    from .util import nag_integer_type_check_and_cast
    _indx = nag_integer_type_check_and_cast('g05ncc', indx, 'indx')
    _state = nag_integer_type_check_and_cast('g05ncc', state, 'state')
    g05ncc_ctypes(_indx, n, _state, fail)

g05ndc_ctypes = _library_cl.g05ndc
g05ndc_ctypes.restype = None
g05ndc_ctypes.argtypes = [POINTER(Integer), Integer, POINTER(Integer), Integer, POINTER(Integer), POINTER(NagError)]


def g05ndc(ipop, n, isampl, m, state, fail):
    """
    Pseudorandom sample from an integer vector.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ndc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ipop, isampl, state
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        ipop, isampl, state
    """
    from .util import nag_integer_type_check_and_cast
    _ipop = nag_integer_type_check_and_cast('g05ndc', ipop, 'ipop')
    _isampl = nag_integer_type_check_and_cast('g05ndc', isampl, 'isampl')
    _state = nag_integer_type_check_and_cast('g05ndc', state, 'state')
    g05ndc_ctypes(_ipop, n, _isampl, m, _state, fail)

g05nec_ctypes = _library_cl.g05nec
g05nec_ctypes.restype = None
g05nec_ctypes.argtypes = [Nag_SortOrder, POINTER(c_double), POINTER(Integer), Integer, POINTER(Integer), Integer, POINTER(Integer), POINTER(NagError)]


def g05nec(sortorder, wt, ipop, n, isampl, m, state, fail):
    """
    Pseudorandom sample, without replacement, unequal weights.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05nec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        wt, ipop, isampl, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        wt
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        ipop, isampl, state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _wt = nag_double_type_check_and_cast('g05nec', wt, 'wt')
    _ipop = nag_integer_type_check_and_cast('g05nec', ipop, 'ipop')
    _isampl = nag_integer_type_check_and_cast('g05nec', isampl, 'isampl')
    _state = nag_integer_type_check_and_cast('g05nec', state, 'state')
    g05nec_ctypes(sortorder, _wt, _ipop, n, _isampl, m, _state, fail)

g05pdc_ctypes = _library_cl.g05pdc
g05pdc_ctypes.restype = None
g05pdc_ctypes.argtypes = [Nag_ErrorDistn, Integer, Integer, Integer, POINTER(c_double), c_double, Integer, POINTER(c_double), POINTER(c_double), Nag_Boolean, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05pdc(dist, num, ip, iq, theta, gamma, df, ht, et, fcall, r, lr, state, fail):
    """
    Generates a realization of a time series from a GARCH process with
    asymmetry of the form (epsilon_(t-1)+gamma)**2.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        theta, ht, et, r, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        theta, ht, et, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _theta = nag_double_type_check_and_cast('g05pdc', theta, 'theta')
    _ht = nag_double_type_check_and_cast('g05pdc', ht, 'ht')
    _et = nag_double_type_check_and_cast('g05pdc', et, 'et')
    _r = nag_double_type_check_and_cast('g05pdc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pdc', state, 'state')
    g05pdc_ctypes(dist, num, ip, iq, _theta, gamma, df, _ht, _et, fcall, _r, lr, _state, fail)

g05pec_ctypes = _library_cl.g05pec
g05pec_ctypes.restype = None
g05pec_ctypes.argtypes = [Nag_ErrorDistn, Integer, Integer, Integer, POINTER(c_double), c_double, Integer, POINTER(c_double), POINTER(c_double), Nag_Boolean, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05pec(dist, num, ip, iq, theta, gamma, df, ht, et, fcall, r, lr, state, fail):
    """
    Generates a realization of a time series from a GARCH process with
    asymmetry of the form (abs(epsilon_(t-1))+gammaepsilon_(t-1))**2.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        theta, ht, et, r, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        theta, ht, et, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _theta = nag_double_type_check_and_cast('g05pec', theta, 'theta')
    _ht = nag_double_type_check_and_cast('g05pec', ht, 'ht')
    _et = nag_double_type_check_and_cast('g05pec', et, 'et')
    _r = nag_double_type_check_and_cast('g05pec', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pec', state, 'state')
    g05pec_ctypes(dist, num, ip, iq, _theta, gamma, df, _ht, _et, fcall, _r, lr, _state, fail)

g05pfc_ctypes = _library_cl.g05pfc
g05pfc_ctypes.restype = None
g05pfc_ctypes.argtypes = [Nag_ErrorDistn, Integer, Integer, Integer, POINTER(c_double), c_double, Integer, POINTER(c_double), POINTER(c_double), Nag_Boolean, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05pfc(dist, num, ip, iq, theta, gamma, df, ht, et, fcall, r, lr, state, fail):
    """
    Generates a realization of a time series from an asymmetric Glosten,
    Jagannathan and Runkle (GJR) GARCH process.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pfc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        theta, ht, et, r, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        theta, ht, et, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _theta = nag_double_type_check_and_cast('g05pfc', theta, 'theta')
    _ht = nag_double_type_check_and_cast('g05pfc', ht, 'ht')
    _et = nag_double_type_check_and_cast('g05pfc', et, 'et')
    _r = nag_double_type_check_and_cast('g05pfc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pfc', state, 'state')
    g05pfc_ctypes(dist, num, ip, iq, _theta, gamma, df, _ht, _et, fcall, _r, lr, _state, fail)

g05pgc_ctypes = _library_cl.g05pgc
g05pgc_ctypes.restype = None
g05pgc_ctypes.argtypes = [Nag_ErrorDistn, Integer, Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Nag_Boolean, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05pgc(dist, num, ip, iq, theta, df, ht, et, fcall, r, lr, state, fail):
    """
    Generates a realization of a time series from an exponential GARCH
    (EGARCH) process.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pgc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        theta, ht, et, r, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        theta, ht, et, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _theta = nag_double_type_check_and_cast('g05pgc', theta, 'theta')
    _ht = nag_double_type_check_and_cast('g05pgc', ht, 'ht')
    _et = nag_double_type_check_and_cast('g05pgc', et, 'et')
    _r = nag_double_type_check_and_cast('g05pgc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pgc', state, 'state')
    g05pgc_ctypes(dist, num, ip, iq, _theta, df, _ht, _et, fcall, _r, lr, _state, fail)

g05phc_ctypes = _library_cl.g05phc
g05phc_ctypes.restype = None
g05phc_ctypes.argtypes = [Nag_ModeRNG, Integer, c_double, Integer, POINTER(c_double), Integer, POINTER(c_double), c_double, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), POINTER(c_double), POINTER(NagError)]


def g05phc(mode, n, xmean, ip, phi, iq, theta, avar, r, lr, state, var, x, fail):
    """
    Generates a realization of a time series from an ARMA model.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05phc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        phi, theta, r, state, var, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        phi, theta, r, var, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _phi = nag_double_type_check_and_cast('g05phc', phi, 'phi')
    _theta = nag_double_type_check_and_cast('g05phc', theta, 'theta')
    _r = nag_double_type_check_and_cast('g05phc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05phc', state, 'state')
    _var = nag_double_type_check_and_cast('g05phc', var, 'var')
    _x = nag_double_type_check_and_cast('g05phc', x, 'x')
    g05phc_ctypes(mode, n, xmean, ip, _phi, iq, _theta, avar, _r, lr, _state, _var, _x, fail)

g05pjc_ctypes = _library_cl.g05pjc
g05pjc_ctypes.restype = None
g05pjc_ctypes.argtypes = [Nag_OrderType, Nag_ModeRNG, Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05pjc(order, mode, n, k, xmean, p, phi, q, theta, var, pdv, r, lr, state, x, pdx, fail):
    """
    Generates a realization of a multivariate time series from a VARMA
    model.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        xmean, phi, theta, var, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        xmean, phi, theta, var, r, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _xmean = nag_double_type_check_and_cast('g05pjc', xmean, 'xmean')
    _phi = nag_double_type_check_and_cast('g05pjc', phi, 'phi')
    _theta = nag_double_type_check_and_cast('g05pjc', theta, 'theta')
    _var = nag_double_type_check_and_cast('g05pjc', var, 'var')
    _r = nag_double_type_check_and_cast('g05pjc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pjc', state, 'state')
    _x = nag_double_type_check_and_cast('g05pjc', x, 'x')
    g05pjc_ctypes(order, mode, n, k, _xmean, p, _phi, q, _theta, _var, pdv, _r, lr, _state, _x, pdx, fail)

g05pmc_ctypes = _library_cl.g05pmc
g05pmc_ctypes.restype = None
g05pmc_ctypes.argtypes = [Nag_InitialValues, Integer, Nag_ExpSmoothType, Integer, POINTER(c_double), POINTER(c_double), c_double, POINTER(c_double), POINTER(Integer), POINTER(c_double), Integer, POINTER(c_double), POINTER(NagError)]


def g05pmc(mode, n, itype, p, param, init, var, r, state, e, en, x, fail):
    """
    Generates a realization of a time series from an exponential smoothing
    model.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pmc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        param, init, r, state, e, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        param, init, r, e, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _param = nag_double_type_check_and_cast('g05pmc', param, 'param')
    _init = nag_double_type_check_and_cast('g05pmc', init, 'init')
    _r = nag_double_type_check_and_cast('g05pmc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pmc', state, 'state')
    _e = nag_double_type_check_and_cast('g05pmc', e, 'e')
    _x = nag_double_type_check_and_cast('g05pmc', x, 'x')
    g05pmc_ctypes(mode, n, itype, p, _param, _init, var, _r, _state, _e, en, _x, fail)

g05pvc_ctypes = _library_cl.g05pvc
g05pvc_ctypes.restype = None
g05pvc_ctypes.argtypes = [Integer, Integer, Integer, Integer, Nag_DataByObsOrVar, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05pvc(k, fold, n, m, sordx, x, pdx, y, w, nt, state, fail):
    """
    Permutes a matrix, vector, vector triplet into a form suitable for
    K-fold cross validation.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pvc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, y, w, nt, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, y, w
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        nt, state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('g05pvc', x, 'x')
    _y = nag_double_type_check_and_cast('g05pvc', y, 'y')
    _w = nag_double_type_check_and_cast('g05pvc', w, 'w')
    _nt = nag_integer_type_check_and_cast('g05pvc', nt, 'nt')
    _state = nag_integer_type_check_and_cast('g05pvc', state, 'state')
    g05pvc_ctypes(k, fold, n, m, sordx, _x, pdx, _y, _w, _nt, _state, fail)

nag_rand_kfold_xyw = g05pvc

g05pwc_ctypes = _library_cl.g05pwc
g05pwc_ctypes.restype = None
g05pwc_ctypes.argtypes = [Integer, Integer, Integer, Nag_DataByObsOrVar, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(NagError)]


def g05pwc(nt, n, m, sordx, x, pdx, y, w, state, fail):
    """
    Permutes a matrix, vector, vector triplet into a form suitable for
    random sub-sampling validation.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pwc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        x, y, w, state
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x, y, w
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_double_type_check_and_cast('g05pwc', x, 'x')
    _y = nag_double_type_check_and_cast('g05pwc', y, 'y')
    _w = nag_double_type_check_and_cast('g05pwc', w, 'w')
    _state = nag_integer_type_check_and_cast('g05pwc', state, 'state')
    g05pwc_ctypes(nt, n, m, sordx, _x, pdx, _y, _w, _state, fail)

nag_rand_subsamp_xyw = g05pwc

g05pxc_ctypes = _library_cl.g05pxc
g05pxc_ctypes.restype = None
g05pxc_ctypes.argtypes = [Nag_SideType, Nag_InitializeA, Integer, Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05pxc(side, init, m, n, state, a, pda, fail):
    """
    Generates a random orthogonal matrix.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pxc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, a
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05pxc', state, 'state')
    _a = nag_double_type_check_and_cast('g05pxc', a, 'a')
    g05pxc_ctypes(side, init, m, n, _state, _a, pda, fail)

g05pyc_ctypes = _library_cl.g05pyc
g05pyc_ctypes.restype = None
g05pyc_ctypes.argtypes = [Integer, POINTER(c_double), c_double, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05pyc(n, d, eps, state, c, pdc, fail):
    """
    Generates a random correlation matrix.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pyc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        d, state, c
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        d, c
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _d = nag_double_type_check_and_cast('g05pyc', d, 'd')
    _state = nag_integer_type_check_and_cast('g05pyc', state, 'state')
    _c = nag_double_type_check_and_cast('g05pyc', c, 'c')
    g05pyc_ctypes(n, _d, eps, _state, _c, pdc, fail)

g05pzc_ctypes = _library_cl.g05pzc
g05pzc_ctypes.restype = None
g05pzc_ctypes.argtypes = [Nag_ModeRNG, Integer, Integer, POINTER(Integer), POINTER(Integer), POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), Integer, POINTER(NagError)]


def g05pzc(mode, nrow, ncol, totr, totc, r, lr, state, x, pdx, fail):
    """
    Generates a random two-way table.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05pzc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        totr, totc, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        totr, totc, state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _totr = nag_integer_type_check_and_cast('g05pzc', totr, 'totr')
    _totc = nag_integer_type_check_and_cast('g05pzc', totc, 'totc')
    _r = nag_double_type_check_and_cast('g05pzc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05pzc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05pzc', x, 'x')
    g05pzc_ctypes(mode, nrow, ncol, _totr, _totc, _r, lr, _state, _x, pdx, fail)

g05rcc_ctypes = _library_cl.g05rcc
g05rcc_ctypes.restype = None
g05rcc_ctypes.argtypes = [Nag_OrderType, Nag_ModeRNG, Integer, Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05rcc(order, mode, n, df, m, c, pdc, r, lr, state, x, pdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a Student's t-copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, r, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('g05rcc', c, 'c')
    _r = nag_double_type_check_and_cast('g05rcc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05rcc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rcc', x, 'x')
    g05rcc_ctypes(order, mode, n, df, m, _c, pdc, _r, lr, _state, _x, pdx, fail)

g05rdc_ctypes = _library_cl.g05rdc
g05rdc_ctypes.restype = None
g05rdc_ctypes.argtypes = [Nag_OrderType, Nag_ModeRNG, Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05rdc(order, mode, n, m, c, pdc, r, lr, state, x, pdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a Gaussian copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        c, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        c, r, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _c = nag_double_type_check_and_cast('g05rdc', c, 'c')
    _r = nag_double_type_check_and_cast('g05rdc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05rdc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rdc', x, 'x')
    g05rdc_ctypes(order, mode, n, m, _c, pdc, _r, lr, _state, _x, pdx, fail)

g05rec_ctypes = _library_cl.g05rec
g05rec_ctypes.restype = None
g05rec_ctypes.argtypes = [Nag_OrderType, POINTER(Integer), c_double, Integer, POINTER(c_double), Integer, Integer, POINTER(NagError)]


def g05rec(order, state, theta, n, x, pdx, sdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a bivariate Clayton/Cook
    --Johnson copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05rec', state, 'state')
    _x = nag_double_type_check_and_cast('g05rec', x, 'x')
    g05rec_ctypes(order, _state, theta, n, _x, pdx, sdx, fail)

g05rfc_ctypes = _library_cl.g05rfc
g05rfc_ctypes.restype = None
g05rfc_ctypes.argtypes = [Nag_OrderType, POINTER(Integer), c_double, Integer, POINTER(c_double), Integer, Integer, POINTER(NagError)]


def g05rfc(order, state, theta, n, x, pdx, sdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a bivariate Frank
    copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rfc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05rfc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rfc', x, 'x')
    g05rfc_ctypes(order, _state, theta, n, _x, pdx, sdx, fail)

g05rgc_ctypes = _library_cl.g05rgc
g05rgc_ctypes.restype = None
g05rgc_ctypes.argtypes = [Nag_OrderType, POINTER(Integer), c_double, Integer, POINTER(c_double), Integer, Integer, POINTER(NagError)]


def g05rgc(order, state, theta, n, x, pdx, sdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a bivariate Plackett
    copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rgc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05rgc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rgc', x, 'x')
    g05rgc_ctypes(order, _state, theta, n, _x, pdx, sdx, fail)

g05rhc_ctypes = _library_cl.g05rhc
g05rhc_ctypes.restype = None
g05rhc_ctypes.argtypes = [Nag_OrderType, POINTER(Integer), c_double, Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(NagError)]


def g05rhc(order, state, theta, n, m, x, pdx, sdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a multivariate
    Clayton/Cook--Johnson copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rhc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05rhc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rhc', x, 'x')
    g05rhc_ctypes(order, _state, theta, n, m, _x, pdx, sdx, fail)

g05rjc_ctypes = _library_cl.g05rjc
g05rjc_ctypes.restype = None
g05rjc_ctypes.argtypes = [Nag_OrderType, POINTER(Integer), c_double, Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(NagError)]


def g05rjc(order, state, theta, n, m, x, pdx, sdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a multivariate Frank
    copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05rjc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rjc', x, 'x')
    g05rjc_ctypes(order, _state, theta, n, m, _x, pdx, sdx, fail)

g05rkc_ctypes = _library_cl.g05rkc
g05rkc_ctypes.restype = None
g05rkc_ctypes.argtypes = [Nag_OrderType, POINTER(Integer), c_double, Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(NagError)]


def g05rkc(order, state, theta, n, m, x, pdx, sdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a Gumbel--Hougaard
    copula.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rkc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05rkc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rkc', x, 'x')
    g05rkc_ctypes(order, _state, theta, n, m, _x, pdx, sdx, fail)

g05ryc_ctypes = _library_cl.g05ryc
g05ryc_ctypes.restype = None
g05ryc_ctypes.argtypes = [Nag_OrderType, Nag_ModeRNG, Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05ryc(order, mode, n, df, m, xmu, c, pdc, r, lr, state, x, pdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a multivariate Student's
    t-distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ryc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        xmu, c, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        xmu, c, r, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _xmu = nag_double_type_check_and_cast('g05ryc', xmu, 'xmu')
    _c = nag_double_type_check_and_cast('g05ryc', c, 'c')
    _r = nag_double_type_check_and_cast('g05ryc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05ryc', state, 'state')
    _x = nag_double_type_check_and_cast('g05ryc', x, 'x')
    g05ryc_ctypes(order, mode, n, df, m, _xmu, _c, pdc, _r, lr, _state, _x, pdx, fail)

g05rzc_ctypes = _library_cl.g05rzc
g05rzc_ctypes.restype = None
g05rzc_ctypes.argtypes = [Nag_OrderType, Nag_ModeRNG, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05rzc(order, mode, n, m, xmu, c, pdc, r, lr, state, x, pdx, fail):
    """
    Generates a matrix of pseudorandom numbers from a multivariate Normal
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05rzc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        xmu, c, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        xmu, c, r, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _xmu = nag_double_type_check_and_cast('g05rzc', xmu, 'xmu')
    _c = nag_double_type_check_and_cast('g05rzc', c, 'c')
    _r = nag_double_type_check_and_cast('g05rzc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05rzc', state, 'state')
    _x = nag_double_type_check_and_cast('g05rzc', x, 'x')
    g05rzc_ctypes(order, mode, n, m, _xmu, _c, pdc, _r, lr, _state, _x, pdx, fail)

g05sac_ctypes = _library_cl.g05sac
g05sac_ctypes.restype = None
g05sac_ctypes.argtypes = [Integer, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sac(n, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a uniform distribution
    over (0,1].
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05sac', state, 'state')
    _x = nag_double_type_check_and_cast('g05sac', x, 'x')
    g05sac_ctypes(n, _state, _x, fail)

g05sbc_ctypes = _library_cl.g05sbc
g05sbc_ctypes.restype = None
g05sbc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sbc(n, a, b, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a beta distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05sbc', state, 'state')
    _x = nag_double_type_check_and_cast('g05sbc', x, 'x')
    g05sbc_ctypes(n, a, b, _state, _x, fail)

g05scc_ctypes = _library_cl.g05scc
g05scc_ctypes.restype = None
g05scc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05scc(n, xmed, semiqr, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a Cauchy distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05scc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05scc', state, 'state')
    _x = nag_double_type_check_and_cast('g05scc', x, 'x')
    g05scc_ctypes(n, xmed, semiqr, _state, _x, fail)

g05sdc_ctypes = _library_cl.g05sdc
g05sdc_ctypes.restype = None
g05sdc_ctypes.argtypes = [Integer, Integer, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sdc(n, df, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a chi**2 distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05sdc', state, 'state')
    _x = nag_double_type_check_and_cast('g05sdc', x, 'x')
    g05sdc_ctypes(n, df, _state, _x, fail)

g05sec_ctypes = _library_cl.g05sec
g05sec_ctypes.restype = None
g05sec_ctypes.argtypes = [Nag_OrderType, Integer, Integer, POINTER(c_double), POINTER(Integer), POINTER(c_double), Integer, POINTER(NagError)]


def g05sec(order, n, m, a, state, x, pdx, fail):
    """
    Generates a vector of pseudorandom numbers from a Dirichlet
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        a, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _a = nag_double_type_check_and_cast('g05sec', a, 'a')
    _state = nag_integer_type_check_and_cast('g05sec', state, 'state')
    _x = nag_double_type_check_and_cast('g05sec', x, 'x')
    g05sec_ctypes(order, n, m, _a, _state, _x, pdx, fail)

g05sfc_ctypes = _library_cl.g05sfc
g05sfc_ctypes.restype = None
g05sfc_ctypes.argtypes = [Integer, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sfc(n, a, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from an exponential
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sfc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05sfc', state, 'state')
    _x = nag_double_type_check_and_cast('g05sfc', x, 'x')
    g05sfc_ctypes(n, a, _state, _x, fail)

g05sgc_ctypes = _library_cl.g05sgc
g05sgc_ctypes.restype = None
g05sgc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sgc(n, nmix, a, wgt, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from an exponential mix
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sgc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        a, wgt, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        a, wgt, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _a = nag_double_type_check_and_cast('g05sgc', a, 'a')
    _wgt = nag_double_type_check_and_cast('g05sgc', wgt, 'wgt')
    _state = nag_integer_type_check_and_cast('g05sgc', state, 'state')
    _x = nag_double_type_check_and_cast('g05sgc', x, 'x')
    g05sgc_ctypes(n, nmix, _a, _wgt, _state, _x, fail)

g05shc_ctypes = _library_cl.g05shc
g05shc_ctypes.restype = None
g05shc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05shc(n, df1, df2, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from an F-distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05shc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05shc', state, 'state')
    _x = nag_double_type_check_and_cast('g05shc', x, 'x')
    g05shc_ctypes(n, df1, df2, _state, _x, fail)

g05sjc_ctypes = _library_cl.g05sjc
g05sjc_ctypes.restype = None
g05sjc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sjc(n, a, b, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a gamma distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05sjc', state, 'state')
    _x = nag_double_type_check_and_cast('g05sjc', x, 'x')
    g05sjc_ctypes(n, a, b, _state, _x, fail)

g05skc_ctypes = _library_cl.g05skc
g05skc_ctypes.restype = None
g05skc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05skc(n, xmu, var, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a Normal distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05skc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05skc', state, 'state')
    _x = nag_double_type_check_and_cast('g05skc', x, 'x')
    g05skc_ctypes(n, xmu, var, _state, _x, fail)

g05slc_ctypes = _library_cl.g05slc
g05slc_ctypes.restype = None
g05slc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05slc(n, a, b, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a logistic distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05slc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05slc', state, 'state')
    _x = nag_double_type_check_and_cast('g05slc', x, 'x')
    g05slc_ctypes(n, a, b, _state, _x, fail)

g05smc_ctypes = _library_cl.g05smc
g05smc_ctypes.restype = None
g05smc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05smc(n, xmu, var, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a log-normal
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05smc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05smc', state, 'state')
    _x = nag_double_type_check_and_cast('g05smc', x, 'x')
    g05smc_ctypes(n, xmu, var, _state, _x, fail)

g05snc_ctypes = _library_cl.g05snc
g05snc_ctypes.restype = None
g05snc_ctypes.argtypes = [Integer, Integer, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05snc(n, df, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a Student's
    t-distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05snc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05snc', state, 'state')
    _x = nag_double_type_check_and_cast('g05snc', x, 'x')
    g05snc_ctypes(n, df, _state, _x, fail)

g05spc_ctypes = _library_cl.g05spc
g05spc_ctypes.restype = None
g05spc_ctypes.argtypes = [Integer, c_double, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05spc(n, xmin, xmed, xmax, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a triangular
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05spc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05spc', state, 'state')
    _x = nag_double_type_check_and_cast('g05spc', x, 'x')
    g05spc_ctypes(n, xmin, xmed, xmax, _state, _x, fail)

g05sqc_ctypes = _library_cl.g05sqc
g05sqc_ctypes.restype = None
g05sqc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05sqc(n, a, b, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a uniform distribution
    over [a,b].
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05sqc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05sqc', state, 'state')
    _x = nag_double_type_check_and_cast('g05sqc', x, 'x')
    g05sqc_ctypes(n, a, b, _state, _x, fail)

g05src_ctypes = _library_cl.g05src
g05src_ctypes.restype = None
g05src_ctypes.argtypes = [Integer, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05src(n, vk, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a von Mises
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05src.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05src', state, 'state')
    _x = nag_double_type_check_and_cast('g05src', x, 'x')
    g05src_ctypes(n, vk, _state, _x, fail)

g05ssc_ctypes = _library_cl.g05ssc
g05ssc_ctypes.restype = None
g05ssc_ctypes.argtypes = [Integer, c_double, c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05ssc(n, a, b, state, x, fail):
    """
    Generates a vector of pseudorandom numbers from a Weibull distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ssc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05ssc', state, 'state')
    _x = nag_double_type_check_and_cast('g05ssc', x, 'x')
    g05ssc_ctypes(n, a, b, _state, _x, fail)

g05tac_ctypes = _library_cl.g05tac
g05tac_ctypes.restype = None
g05tac_ctypes.argtypes = [Nag_ModeRNG, Integer, Integer, c_double, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tac(mode, n, m, p, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a binomial
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _r = nag_double_type_check_and_cast('g05tac', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tac', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tac', x, 'x')
    g05tac_ctypes(mode, n, m, p, _r, lr, _state, _x, fail)

g05tbc_ctypes = _library_cl.g05tbc
g05tbc_ctypes.restype = None
g05tbc_ctypes.argtypes = [Integer, c_double, POINTER(Integer), POINTER(Nag_Boolean), POINTER(NagError)]


def g05tbc(n, p, state, x, fail):
    """
    Generates a vector of pseudorandom logical values.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    Nag_Boolean:
        x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_enum_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _x = nag_enum_type_check_and_cast('g05tbc', x, 'x', Nag_Boolean)
    _state = nag_integer_type_check_and_cast('g05tbc', state, 'state')
    g05tbc_ctypes(n, p, _state, _x, fail)

g05tcc_ctypes = _library_cl.g05tcc
g05tcc_ctypes.restype = None
g05tcc_ctypes.argtypes = [Nag_ModeRNG, Integer, c_double, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tcc(mode, n, p, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a geometric
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _r = nag_double_type_check_and_cast('g05tcc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tcc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tcc', x, 'x')
    g05tcc_ctypes(mode, n, p, _r, lr, _state, _x, fail)

g05tdc_ctypes = _library_cl.g05tdc
g05tdc_ctypes.restype = None
g05tdc_ctypes.argtypes = [Nag_ModeRNG, Integer, POINTER(c_double), Integer, Integer, Nag_DiscreteDistrib, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tdc(mode, n, p, np, ip1, itype, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a general discrete
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        p, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        p, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _p = nag_double_type_check_and_cast('g05tdc', p, 'p')
    _r = nag_double_type_check_and_cast('g05tdc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tdc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tdc', x, 'x')
    g05tdc_ctypes(mode, n, _p, np, ip1, itype, _r, lr, _state, _x, fail)

g05tec_ctypes = _library_cl.g05tec
g05tec_ctypes.restype = None
g05tec_ctypes.argtypes = [Nag_ModeRNG, Integer, Integer, Integer, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tec(mode, n, ns, np, m, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a hypergeometric
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _r = nag_double_type_check_and_cast('g05tec', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tec', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tec', x, 'x')
    g05tec_ctypes(mode, n, ns, np, m, _r, lr, _state, _x, fail)

g05tfc_ctypes = _library_cl.g05tfc
g05tfc_ctypes.restype = None
g05tfc_ctypes.argtypes = [Nag_ModeRNG, Integer, c_double, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tfc(mode, n, a, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a logarithmic
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tfc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _r = nag_double_type_check_and_cast('g05tfc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tfc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tfc', x, 'x')
    g05tfc_ctypes(mode, n, a, _r, lr, _state, _x, fail)

g05tgc_ctypes = _library_cl.g05tgc
g05tgc_ctypes.restype = None
g05tgc_ctypes.argtypes = [Nag_OrderType, Nag_ModeRNG, Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), Integer, POINTER(NagError)]


def g05tgc(order, mode, n, m, k, p, r, lr, state, x, pdx, fail):
    """
    Generates a vector of pseudorandom integers from a multinomial
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tgc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        p, r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        p, r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _p = nag_double_type_check_and_cast('g05tgc', p, 'p')
    _r = nag_double_type_check_and_cast('g05tgc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tgc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tgc', x, 'x')
    g05tgc_ctypes(order, mode, n, m, k, _p, _r, lr, _state, _x, pdx, fail)

g05thc_ctypes = _library_cl.g05thc
g05thc_ctypes.restype = None
g05thc_ctypes.argtypes = [Nag_ModeRNG, Integer, Integer, c_double, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05thc(mode, n, m, p, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a negative binomial
    distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05thc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _r = nag_double_type_check_and_cast('g05thc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05thc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05thc', x, 'x')
    g05thc_ctypes(mode, n, m, p, _r, lr, _state, _x, fail)

g05tjc_ctypes = _library_cl.g05tjc
g05tjc_ctypes.restype = None
g05tjc_ctypes.argtypes = [Nag_ModeRNG, Integer, c_double, POINTER(c_double), Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tjc(mode, n, _lambda, r, lr, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a Poisson distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        r, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _r = nag_double_type_check_and_cast('g05tjc', r, 'r')
    _state = nag_integer_type_check_and_cast('g05tjc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tjc', x, 'x')
    g05tjc_ctypes(mode, n, _lambda, _r, lr, _state, _x, fail)

g05tkc_ctypes = _library_cl.g05tkc
g05tkc_ctypes.restype = None
g05tkc_ctypes.argtypes = [Integer, POINTER(c_double), POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tkc(m, vlamda, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a Poisson distribution
    with varying mean.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tkc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        vlamda, state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        vlamda
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _vlamda = nag_double_type_check_and_cast('g05tkc', vlamda, 'vlamda')
    _state = nag_integer_type_check_and_cast('g05tkc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tkc', x, 'x')
    g05tkc_ctypes(m, _vlamda, _state, _x, fail)

g05tlc_ctypes = _library_cl.g05tlc
g05tlc_ctypes.restype = None
g05tlc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(Integer), POINTER(Integer), POINTER(NagError)]


def g05tlc(n, a, b, state, x, fail):
    """
    Generates a vector of pseudorandom integers from a uniform distribution.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05tlc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        state, x
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state, x
    """
    from .util import nag_integer_type_check_and_cast
    _state = nag_integer_type_check_and_cast('g05tlc', state, 'state')
    _x = nag_integer_type_check_and_cast('g05tlc', x, 'x')
    g05tlc_ctypes(n, a, b, _state, _x, fail)

g05xac_ctypes = _library_cl.g05xac
g05xac_ctypes.restype = None
g05xac_ctypes.argtypes = [c_double, c_double, POINTER(c_double), Integer, POINTER(c_double), POINTER(NagError)]


def g05xac(t0, tend, times, ntimes, rcomm, fail):
    """
    Initializes the Brownian bridge generator.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05xac.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        times, rcomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        times, rcomm
    """
    from .util import nag_double_type_check_and_cast
    _times = nag_double_type_check_and_cast('g05xac', times, 'times')
    _rcomm = nag_double_type_check_and_cast('g05xac', rcomm, 'rcomm')
    g05xac_ctypes(t0, tend, _times, ntimes, _rcomm, fail)

g05xbc_ctypes = _library_cl.g05xbc
g05xbc_ctypes.restype = None
g05xbc_ctypes.argtypes = [Nag_OrderType, Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(NagError)]


def g05xbc(order, npaths, d, start, a, term, z, pdz, c, pdc, b, pdb, rcomm, fail):
    """
    Generate paths for a free or non-free Wiener process using the Brownian
    bridge algorithm.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05xbc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        start, term, z, c, b, rcomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        start, term, z, c, b, rcomm
    """
    from .util import nag_double_type_check_and_cast
    _start = nag_double_type_check_and_cast('g05xbc', start, 'start')
    _term = nag_double_type_check_and_cast('g05xbc', term, 'term')
    _z = nag_double_type_check_and_cast('g05xbc', z, 'z')
    _c = nag_double_type_check_and_cast('g05xbc', c, 'c')
    _b = nag_double_type_check_and_cast('g05xbc', b, 'b')
    _rcomm = nag_double_type_check_and_cast('g05xbc', rcomm, 'rcomm')
    g05xbc_ctypes(order, npaths, d, _start, a, _term, _z, pdz, _c, pdc, _b, pdb, _rcomm, fail)

g05xcc_ctypes = _library_cl.g05xcc
g05xcc_ctypes.restype = None
g05xcc_ctypes.argtypes = [c_double, c_double, POINTER(c_double), Integer, POINTER(c_double), POINTER(NagError)]


def g05xcc(t0, tend, times, ntimes, rcomm, fail):
    """
    Initializes the generator which backs out the increments of sample paths
    generated by a Brownian bridge algorithm.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05xcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        times, rcomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        times, rcomm
    """
    from .util import nag_double_type_check_and_cast
    _times = nag_double_type_check_and_cast('g05xcc', times, 'times')
    _rcomm = nag_double_type_check_and_cast('g05xcc', rcomm, 'rcomm')
    g05xcc_ctypes(t0, tend, _times, ntimes, _rcomm, fail)

g05xdc_ctypes = _library_cl.g05xdc
g05xdc_ctypes.restype = None
g05xdc_ctypes.argtypes = [Nag_OrderType, Integer, Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(NagError)]


def g05xdc(order, npaths, d, a, diff, z, pdz, c, pdc, b, pdb, rcomm, fail):
    """
    Backs out the increments from sample paths generated by a Brownian
    bridge algorithm.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05xdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        diff, z, c, b, rcomm
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        diff, z, c, b, rcomm
    """
    from .util import nag_double_type_check_and_cast
    _diff = nag_double_type_check_and_cast('g05xdc', diff, 'diff')
    _z = nag_double_type_check_and_cast('g05xdc', z, 'z')
    _c = nag_double_type_check_and_cast('g05xdc', c, 'c')
    _b = nag_double_type_check_and_cast('g05xdc', b, 'b')
    _rcomm = nag_double_type_check_and_cast('g05xdc', rcomm, 'rcomm')
    g05xdc_ctypes(order, npaths, d, a, _diff, _z, pdz, _c, pdc, _b, pdb, _rcomm, fail)

g05xec_ctypes = _library_cl.g05xec
g05xec_ctypes.restype = None
g05xec_ctypes.argtypes = [Nag_BridgeOrder, c_double, c_double, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05xec(bgord, t0, tend, ntimes, intime, nmove, move, times, fail):
    """
    Creates a Brownian bridge construction order out of a set of input
    times.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05xec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        intime, move, times
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        intime, times
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        move
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _intime = nag_double_type_check_and_cast('g05xec', intime, 'intime')
    _move = nag_integer_type_check_and_cast('g05xec', move, 'move')
    _times = nag_double_type_check_and_cast('g05xec', times, 'times')
    g05xec_ctypes(bgord, t0, tend, ntimes, _intime, nmove, _move, _times, fail)

g05yjc_ctypes = _library_cl.g05yjc
g05yjc_ctypes.restype = None
g05yjc_ctypes.argtypes = [Nag_OrderType, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05yjc(order, xmean, std, n, quas, pdquas, iref, fail):
    """
    Generates a Normal quasi-random number sequence.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05yjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        xmean, std, quas, iref
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        xmean, std, quas
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        iref
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _xmean = nag_double_type_check_and_cast('g05yjc', xmean, 'xmean')
    _std = nag_double_type_check_and_cast('g05yjc', std, 'std')
    _quas = nag_double_type_check_and_cast('g05yjc', quas, 'quas')
    _iref = nag_integer_type_check_and_cast('g05yjc', iref, 'iref')
    g05yjc_ctypes(order, _xmean, _std, n, _quas, pdquas, _iref, fail)

g05ykc_ctypes = _library_cl.g05ykc
g05ykc_ctypes.restype = None
g05ykc_ctypes.argtypes = [Nag_OrderType, POINTER(c_double), POINTER(c_double), Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05ykc(order, xmean, std, n, quas, pdquas, iref, fail):
    """
    Generates a log-normal quasi-random number sequence.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ykc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        xmean, std, quas, iref
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        xmean, std, quas
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        iref
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _xmean = nag_double_type_check_and_cast('g05ykc', xmean, 'xmean')
    _std = nag_double_type_check_and_cast('g05ykc', std, 'std')
    _quas = nag_double_type_check_and_cast('g05ykc', quas, 'quas')
    _iref = nag_integer_type_check_and_cast('g05ykc', iref, 'iref')
    g05ykc_ctypes(order, _xmean, _std, n, _quas, pdquas, _iref, fail)

g05ylc_ctypes = _library_cl.g05ylc
g05ylc_ctypes.restype = None
g05ylc_ctypes.argtypes = [Nag_QuasiRandom_Sequence, Integer, POINTER(Integer), Integer, Integer, POINTER(NagError)]


def g05ylc(genid, idim, iref, liref, iskip, fail):
    """
    Initializes a quasi-random number generator.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ylc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        iref
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        iref
    """
    from .util import nag_integer_type_check_and_cast
    _iref = nag_integer_type_check_and_cast('g05ylc', iref, 'iref')
    g05ylc_ctypes(genid, idim, _iref, liref, iskip, fail)

g05ymc_ctypes = _library_cl.g05ymc
g05ymc_ctypes.restype = None
g05ymc_ctypes.argtypes = [Nag_OrderType, Integer, POINTER(c_double), Integer, POINTER(Integer), POINTER(NagError)]


def g05ymc(order, n, quas, pdquas, iref, fail):
    """
    Generates a uniform quasi-random number sequence.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ymc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        quas, iref
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        quas
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        iref
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _quas = nag_double_type_check_and_cast('g05ymc', quas, 'quas')
    _iref = nag_integer_type_check_and_cast('g05ymc', iref, 'iref')
    g05ymc_ctypes(order, n, _quas, pdquas, _iref, fail)

g05ync_ctypes = _library_cl.g05ync
g05ync_ctypes.restype = None
g05ync_ctypes.argtypes = [Nag_QuasiRandom_Sequence, Nag_QuasiRandom_Scrambling, Integer, POINTER(Integer), Integer, Integer, Integer, POINTER(Integer), POINTER(NagError)]


def g05ync(genid, stype, idim, iref, liref, iskip, nsdigi, state, fail):
    """
    Initializes a scrambled quasi-random number generator.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ync.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        iref, state
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        iref, state
    """
    from .util import nag_integer_type_check_and_cast
    _iref = nag_integer_type_check_and_cast('g05ync', iref, 'iref')
    _state = nag_integer_type_check_and_cast('g05ync', state, 'state')
    g05ync_ctypes(genid, stype, idim, _iref, liref, iskip, nsdigi, _state, fail)

g05zmc_ctypes = _library_cl.g05zmc
g05zmc_ctypes.restype = None
g05zmc_ctypes.argtypes = [Integer, c_double, c_double, Integer, c_double, NAG_G05ZMC_COV1, Nag_EmbedPad, Nag_EmbedScale, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(Integer), POINTER(c_double), POINTER(Integer), POINTER(c_double), POINTER(Nag_Comm), POINTER(NagError)]


def g05zmc(ns, xmin, xmax, maxm, var, cov1, pad, corr, lam, xx, m, approx, rho, icount, eig, comm, fail):
    """
    Setup for simulating one-dimensional random fields, user-defined
    variogram.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05zmc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        lam, xx, m, approx, rho, icount, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        lam, xx, rho, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        m, approx, icount
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _lam = nag_double_type_check_and_cast('g05zmc', lam, 'lam')
    _xx = nag_double_type_check_and_cast('g05zmc', xx, 'xx')
    _m = nag_integer_type_check_and_cast('g05zmc', m, 'm')
    _approx = nag_integer_type_check_and_cast('g05zmc', approx, 'approx')
    _rho = nag_double_type_check_and_cast('g05zmc', rho, 'rho')
    _icount = nag_integer_type_check_and_cast('g05zmc', icount, 'icount')
    _eig = nag_double_type_check_and_cast('g05zmc', eig, 'eig')
    g05zmc_ctypes(ns, xmin, xmax, maxm, var, cov1, pad, corr, _lam, _xx, _m, _approx, _rho, _icount, _eig, comm, fail)

g05znc_ctypes = _library_cl.g05znc
g05znc_ctypes.restype = None
g05znc_ctypes.argtypes = [Integer, c_double, c_double, Integer, c_double, Nag_Variogram, Integer, POINTER(c_double), Nag_EmbedPad, Nag_EmbedScale, POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(Integer), POINTER(c_double), POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05znc(ns, xmin, xmax, maxm, var, cov, np, params, pad, corr, lam, xx, m, approx, rho, icount, eig, fail):
    """
    Setup for simulating one-dimensional random fields.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05znc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        params, lam, xx, m, approx, rho, icount, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        params, lam, xx, rho, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        m, approx, icount
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _params = nag_double_type_check_and_cast('g05znc', params, 'params')
    _lam = nag_double_type_check_and_cast('g05znc', lam, 'lam')
    _xx = nag_double_type_check_and_cast('g05znc', xx, 'xx')
    _m = nag_integer_type_check_and_cast('g05znc', m, 'm')
    _approx = nag_integer_type_check_and_cast('g05znc', approx, 'approx')
    _rho = nag_double_type_check_and_cast('g05znc', rho, 'rho')
    _icount = nag_integer_type_check_and_cast('g05znc', icount, 'icount')
    _eig = nag_double_type_check_and_cast('g05znc', eig, 'eig')
    g05znc_ctypes(ns, xmin, xmax, maxm, var, cov, np, _params, pad, corr, _lam, _xx, _m, _approx, _rho, _icount, _eig, fail)

g05zpc_ctypes = _library_cl.g05zpc
g05zpc_ctypes.restype = None
g05zpc_ctypes.argtypes = [Integer, Integer, Integer, POINTER(c_double), c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05zpc(ns, s, m, lam, rho, state, z, fail):
    """
    Generates realizations of a one-dimensional random field.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05zpc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        lam, state, z
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        lam, z
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _lam = nag_double_type_check_and_cast('g05zpc', lam, 'lam')
    _state = nag_integer_type_check_and_cast('g05zpc', state, 'state')
    _z = nag_double_type_check_and_cast('g05zpc', z, 'z')
    g05zpc_ctypes(ns, s, m, _lam, rho, _state, _z, fail)

g05zqc_ctypes = _library_cl.g05zqc
g05zqc_ctypes.restype = None
g05zqc_ctypes.argtypes = [POINTER(Integer), c_double, c_double, c_double, c_double, POINTER(Integer), c_double, NAG_G05ZQC_COV2, Nag_Parity, Nag_EmbedPad, Nag_EmbedScale, POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(Integer), POINTER(c_double), POINTER(Integer), POINTER(c_double), POINTER(Nag_Comm), POINTER(NagError)]


def g05zqc(ns, xmin, xmax, ymin, ymax, maxm, var, cov2, parity, pad, corr, lam, xx, yy, m, approx, rho, icount, eig, comm, fail):
    """
    Setup for simulating two-dimensional random fields, user-defined
    variogram.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05zqc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ns, maxm, lam, xx, yy, m, approx, rho, icount, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        lam, xx, yy, rho, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        ns, maxm, m, approx, icount
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ns = nag_integer_type_check_and_cast('g05zqc', ns, 'ns')
    _maxm = nag_integer_type_check_and_cast('g05zqc', maxm, 'maxm')
    _lam = nag_double_type_check_and_cast('g05zqc', lam, 'lam')
    _xx = nag_double_type_check_and_cast('g05zqc', xx, 'xx')
    _yy = nag_double_type_check_and_cast('g05zqc', yy, 'yy')
    _m = nag_integer_type_check_and_cast('g05zqc', m, 'm')
    _approx = nag_integer_type_check_and_cast('g05zqc', approx, 'approx')
    _rho = nag_double_type_check_and_cast('g05zqc', rho, 'rho')
    _icount = nag_integer_type_check_and_cast('g05zqc', icount, 'icount')
    _eig = nag_double_type_check_and_cast('g05zqc', eig, 'eig')
    g05zqc_ctypes(_ns, xmin, xmax, ymin, ymax, _maxm, var, cov2, parity, pad, corr, _lam, _xx, _yy, _m, _approx, _rho, _icount, _eig, comm, fail)

g05zrc_ctypes = _library_cl.g05zrc
g05zrc_ctypes.restype = None
g05zrc_ctypes.argtypes = [POINTER(Integer), c_double, c_double, c_double, c_double, POINTER(Integer), c_double, Nag_Variogram, Nag_NormType, Integer, POINTER(c_double), Nag_EmbedPad, Nag_EmbedScale, POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(Integer), POINTER(Integer), POINTER(c_double), POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05zrc(ns, xmin, xmax, ymin, ymax, maxm, var, cov, norm, np, params, pad, corr, lam, xx, yy, m, approx, rho, icount, eig, fail):
    """
    Setup for simulating two-dimensional random fields, preset variogram.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05zrc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ns, maxm, params, lam, xx, yy, m, approx, rho, icount, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        params, lam, xx, yy, rho, eig
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        ns, maxm, m, approx, icount
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ns = nag_integer_type_check_and_cast('g05zrc', ns, 'ns')
    _maxm = nag_integer_type_check_and_cast('g05zrc', maxm, 'maxm')
    _params = nag_double_type_check_and_cast('g05zrc', params, 'params')
    _lam = nag_double_type_check_and_cast('g05zrc', lam, 'lam')
    _xx = nag_double_type_check_and_cast('g05zrc', xx, 'xx')
    _yy = nag_double_type_check_and_cast('g05zrc', yy, 'yy')
    _m = nag_integer_type_check_and_cast('g05zrc', m, 'm')
    _approx = nag_integer_type_check_and_cast('g05zrc', approx, 'approx')
    _rho = nag_double_type_check_and_cast('g05zrc', rho, 'rho')
    _icount = nag_integer_type_check_and_cast('g05zrc', icount, 'icount')
    _eig = nag_double_type_check_and_cast('g05zrc', eig, 'eig')
    g05zrc_ctypes(_ns, xmin, xmax, ymin, ymax, _maxm, var, cov, norm, np, _params, pad, corr, _lam, _xx, _yy, _m, _approx, _rho, _icount, _eig, fail)

g05zsc_ctypes = _library_cl.g05zsc
g05zsc_ctypes.restype = None
g05zsc_ctypes.argtypes = [POINTER(Integer), Integer, POINTER(Integer), POINTER(c_double), c_double, POINTER(Integer), POINTER(c_double), POINTER(NagError)]


def g05zsc(ns, s, m, lam, rho, state, z, fail):
    """
    Generates realizations of a two-dimensional random field.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05zsc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ns, m, lam, state, z
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        lam, z
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        ns, m, state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ns = nag_integer_type_check_and_cast('g05zsc', ns, 'ns')
    _m = nag_integer_type_check_and_cast('g05zsc', m, 'm')
    _lam = nag_double_type_check_and_cast('g05zsc', lam, 'lam')
    _state = nag_integer_type_check_and_cast('g05zsc', state, 'state')
    _z = nag_double_type_check_and_cast('g05zsc', z, 'z')
    g05zsc_ctypes(_ns, s, _m, _lam, rho, _state, _z, fail)

g05ztc_ctypes = _library_cl.g05ztc
g05ztc_ctypes.restype = None
g05ztc_ctypes.argtypes = [Integer, Integer, Integer, c_double, c_double, POINTER(c_double), c_double, POINTER(Integer), POINTER(c_double), POINTER(c_double), POINTER(NagError)]


def g05ztc(ns, s, m, xmax, h, lam, rho, state, z, xx, fail):
    """
    Generates realizations of fractional Brownian motion.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/g05/g05ztc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        lam, state, z, xx
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        lam, z, xx
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        state
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _lam = nag_double_type_check_and_cast('g05ztc', lam, 'lam')
    _state = nag_integer_type_check_and_cast('g05ztc', state, 'state')
    _z = nag_double_type_check_and_cast('g05ztc', z, 'z')
    _xx = nag_double_type_check_and_cast('g05ztc', xx, 'xx')
    g05ztc_ctypes(ns, s, m, xmax, h, _lam, rho, _state, _z, _xx, fail)

nag_rand_init_repeatable = g05kfc
nag_rand_init_nonrepeatable = g05kgc
nag_rand_leap_frog = g05khc
nag_rand_skip_ahead = g05kjc
nag_rand_skip_ahead_power2 = g05kkc
nag_rand_permute = g05ncc
nag_rand_sample = g05ndc
nag_rand_sample_unequal = g05nec
nag_rand_agarchI = g05pdc
nag_rand_agarchII = g05pec
nag_rand_garchGJR = g05pfc
nag_rand_egarch = g05pgc
nag_rand_arma = g05phc
nag_rand_varma = g05pjc
nag_rand_exp_smooth = g05pmc
nag_rand_orthog_matrix = g05pxc
nag_rand_corr_matrix = g05pyc
nag_rand_2_way_table = g05pzc
nag_rand_copula_students_t = g05rcc
nag_rand_copula_normal = g05rdc
nag_rand_bivariate_copula_clayton = g05rec
nag_rand_bivariate_copula_frank = g05rfc
nag_rand_bivariate_copula_plackett = g05rgc
nag_rand_copula_clayton = g05rhc
nag_rand_copula_frank = g05rjc
nag_rand_copula_gumbel = g05rkc
nag_rand_matrix_multi_students_t = g05ryc
nag_rand_matrix_multi_normal = g05rzc
nag_rand_basic = g05sac
nag_rand_beta = g05sbc
nag_rand_cauchy = g05scc
nag_rand_chi_sq = g05sdc
nag_rand_dirichlet = g05sec
nag_rand_exp = g05sfc
nag_rand_exp_mix = g05sgc
nag_rand_f = g05shc
nag_rand_gamma = g05sjc
nag_rand_normal = g05skc
nag_rand_logistic = g05slc
nag_rand_lognormal = g05smc
nag_rand_students_t = g05snc
nag_rand_triangular = g05spc
nag_rand_uniform = g05sqc
nag_rand_von_mises = g05src
nag_rand_weibull = g05ssc
nag_rand_binomial = g05tac
nag_rand_logical = g05tbc
nag_rand_geom = g05tcc
nag_rand_gen_discrete = g05tdc
nag_rand_hypergeometric = g05tec
nag_rand_logarithmic = g05tfc
nag_rand_gen_multinomial = g05tgc
nag_rand_neg_bin = g05thc
nag_rand_poisson = g05tjc
nag_rand_compd_poisson = g05tkc
nag_rand_discrete_uniform = g05tlc
nag_rand_bb_init = g05xac
nag_rand_bb = g05xbc
nag_rand_bb_inc_init = g05xcc
nag_rand_bb_inc = g05xdc
nag_rand_bb_make_bridge_order = g05xec
nag_quasi_rand_normal = g05yjc
nag_quasi_rand_lognormal = g05ykc
nag_quasi_init = g05ylc
nag_quasi_rand_uniform = g05ymc
nag_quasi_init_scrambled = g05ync
nag_rand_field_1d_user_setup = g05zmc
nag_rand_field_1d_predef_setup = g05znc
nag_rand_field_1d_generate = g05zpc
nag_rand_field_2d_user_setup = g05zqc
nag_rand_field_2d_predef_setup = g05zrc
nag_rand_field_2d_generate = g05zsc
nag_rand_field_fracbm_generate = g05ztc
__all__ = ['g05kfc', 'g05kgc', 'g05khc',
           'g05kjc', 'g05kkc',
           'g05ncc', 'g05ndc', 'g05nec',
           'g05pdc', 'g05pec', 'g05pfc', 'g05pgc', 'g05phc',
           'g05pjc', 'g05pmc', 'g05pxc', 'g05pyc', 'g05pzc',
           'g05rcc', 'g05rdc',
           'g05rec', 'g05rfc', 'g05rgc', 'g05rhc', 'g05rjc', 'g05rkc',
           'g05ryc', 'g05rzc', 'g05sac', 'g05sbc', 'g05scc', 'g05sdc',
           'g05sec', 'g05sfc', 'g05sgc', 'g05shc', 'g05sjc', 'g05skc',
           'g05slc', 'g05smc', 'g05snc', 'g05spc', 'g05sqc', 'g05src',
           'g05ssc', 'g05tac', 'g05tbc', 'g05tcc', 'g05tdc', 'g05tec',
           'g05tfc', 'g05tgc', 'g05thc', 'g05tjc', 'g05tkc', 'g05tlc',
           'g05xac', 'g05xbc', 'g05xcc', 'g05xdc', 'g05xec',
           'g05yjc', 'g05ykc', 'g05ylc', 'g05ymc', 'g05ync',
           'g05zmc', 'g05znc', 'g05zpc', 'g05zqc', 'g05zrc', 'g05zsc',
           'g05ztc', 'nag_quasi_init', 'nag_quasi_init_scrambled',
           'nag_quasi_rand_lognormal', 'nag_quasi_rand_normal',
           'nag_quasi_rand_uniform', 'nag_rand_2_way_table',
           'nag_rand_agarchI', 'nag_rand_agarchII', 'nag_rand_arma',
           'nag_rand_basic', 'nag_rand_bb', 'nag_rand_bb_inc',
           'nag_rand_bb_inc_init', 'nag_rand_bb_init',
           'nag_rand_bb_make_bridge_order', 'nag_rand_beta',
           'nag_rand_binomial', 'nag_rand_bivariate_copula_clayton',
           'nag_rand_bivariate_copula_frank',
           'nag_rand_bivariate_copula_plackett', 'nag_rand_cauchy',
           'nag_rand_chi_sq', 'nag_rand_compd_poisson',
           'nag_rand_copula_clayton', 'nag_rand_copula_frank',
           'nag_rand_copula_gumbel', 'nag_rand_copula_normal',
           'nag_rand_copula_students_t', 'nag_rand_corr_matrix',
           'nag_rand_dirichlet', 'nag_rand_discrete_uniform',
           'nag_rand_egarch', 'nag_rand_exp', 'nag_rand_exp_mix',
           'nag_rand_exp_smooth', 'nag_rand_f',
           'nag_rand_field_1d_generate',
           'nag_rand_field_1d_predef_setup',
           'nag_rand_field_1d_user_setup',
           'nag_rand_field_2d_generate',
           'nag_rand_field_2d_predef_setup',
           'nag_rand_field_2d_user_setup',
           'nag_rand_field_fracbm_generate', 'nag_rand_gamma',
           'nag_rand_garchGJR', 'nag_rand_gen_discrete',
           'nag_rand_gen_multinomial', 'nag_rand_geom',
           'nag_rand_hypergeometric', 'nag_rand_init_nonrepeatable',
           'nag_rand_init_repeatable', 'nag_rand_leap_frog',
           'nag_rand_logarithmic', 'nag_rand_logical',
           'nag_rand_logistic', 'nag_rand_lognormal',
           'nag_rand_matrix_multi_normal',
           'nag_rand_matrix_multi_students_t', 'nag_rand_neg_bin',
           'nag_rand_normal', 'nag_rand_orthog_matrix',
           'nag_rand_permute', 'nag_rand_poisson', 'nag_rand_sample',
           'nag_rand_sample_unequal', 'nag_rand_skip_ahead',
           'nag_rand_skip_ahead_power2', 'nag_rand_students_t',
           'nag_rand_triangular', 'nag_rand_uniform',
           'nag_rand_varma', 'nag_rand_von_mises', 'nag_rand_weibull']
