#!/usr/bin/env python
"""
Integration tests for wrapper functionality in the inteq submodule.

Public use of this module is not supported by NAG.
"""

# NAG Copyright 2018-2019.

# pylint: disable=invalid-name

from math import exp
import unittest

import numpy as np

from naginterfaces.base import inteq as b_chapter
from naginterfaces.library import machine
from test_functionality_core import IntegrationTest

class TestD05ba(IntegrationTest): # pylint: disable=too-few-public-methods
    """
    Abstract suite of integration tests for the d05ba wrapper.
    """

class TestD05baBase(TestD05ba, unittest.TestCase):
    """
    Concrete base tests.
    """

    def setUp(self):
        TestD05ba.set_up(self)
        self.fun = b_chapter.volterra2
        self.machpr = machine.precision()

    def test_good_adams(self):
        """
        Good call.
        """
        # pylint: disable=too-many-locals
        ck = lambda t: exp(-t)
        cg = lambda s, y: y + exp(-y)
        cf = ck
        method = 'A'
        iorder = 6
        nmesh = iorder
        alim = 0.
        tlim = 20.
        yn = np.empty(nmesh)
        errest = np.empty(nmesh)
        tol = 1.e-4
        lwk = 160*nmesh + 6
        work = np.empty(lwk)
        self.fun(
            ck, cg, cf, method, iorder, alim, tlim,
            yn, errest, nmesh, tol, self.machpr, work, lwk,
        )
        np.testing.assert_allclose(
            yn,
            [
                1.80032857, 2.23911479, 2.54304934,
                2.77581867, 2.96450609, 3.12317901,
            ],
        )

    def test_good_bdf(self):
        """
        Good call.
        """
        # pylint: disable=too-many-locals
        ck = lambda t: exp(-t)
        cg = lambda s, y: y + exp(-y)
        cf = ck
        method = 'B'
        iorder = 5
        nmesh = 2*iorder
        alim = 0.
        tlim = 20.
        yn = np.empty(nmesh)
        errest = np.empty(nmesh)
        tol = 1.e-4
        lwk = 160*nmesh + 6
        work = np.empty(lwk)
        self.fun(
            ck, cg, cf, method, iorder, alim, tlim,
            yn, errest, nmesh, tol, self.machpr, work, lwk,
        )
        np.testing.assert_allclose(
            yn,
            [1.55144931, 1.90483886, 2.16542949,
             2.37195871, 2.5430487, 2.68909894,
             2.81651171, 2.92950987, 3.03102601, 3.12317983,
            ],
        )

if __name__ == '__main__': # pragma: no cover
    unittest.main()
