#!/usr/bin/env python
"""
Integration tests for wrapper functionality in the interp submodule.

Public use of this module is not supported by NAG.
"""

# NAG Copyright 2018-2019.

# pylint: disable=invalid-name

import unittest

import numpy as np

from naginterfaces.library import interp as chap
from test_functionality_core import IntegrationTest

class TestE01cf(IntegrationTest): # pylint: disable=too-few-public-methods
    """
    Abstract suite of integration tests for the e01cf wrapper.
    """

class TestE01cfNp(TestE01cf, unittest.TestCase):
    """
    Concrete level-2 tests.
    """

    def setUp(self):
        TestE01cf.set_up(self)
        self.interp = chap.dim1_monconv_disc
        self.fun = chap.dim1_monconv_eval

    def test_good(self):
        """
        Good call.
        """
        x = [
            40., 10., 30., 20., 50.,
        ]
        y = [
            6., 3., 4.7, 4., 6.,
        ]
        comm = self.interp(
            False, False, x, y,
        )
        fit = self.fun([51.8, 51.9], comm)
        np.testing.assert_allclose(
            fit.val,
            [
                5.96612, 5.964306,
            ],
            rtol=1e-7,
        )
        np.testing.assert_allclose(
            fit.fwd,
            [
                5.025, 5.025,
            ],
            rtol=1e-7,
        )

if __name__ == '__main__': # pragma: no cover
    unittest.main()
