#!/usr/bin/env python
"""
Integration tests for wrapper functionality in the smooth submodule.

Public use of this module is not supported by NAG.
"""

# NAG Copyright 2018-2019.

# pylint: disable=invalid-name

import unittest

from naginterfaces.library import smooth as chap
from test_functionality_core import IntegrationTest

class TestG10bb(IntegrationTest): # pylint: disable=too-few-public-methods
    """
    Abstract suite of integration tests for the g10bb wrapper.
    """

class TestG10bbNp(TestG10bb, unittest.TestCase):
    """
    Concrete level-2 tests.
    """

    def setUp(self):
        TestG10bb.set_up(self)
        self.fun = chap.kerndens_gauss

    def test_good(self):
        """
        Good continuation call.
        """
        x = [
            0.114, -0.232, -0.570, 1.853, -0.994,
            -0.374, -1.028, 0.509, 0.881, -0.453,
            0.588, -0.625, -1.622, -0.567, 0.421,
            -0.475, 0.054, 0.817, 1.015, 0.608,
            -1.353, -0.912, -1.136, 1.067, 0.121,
            -0.075, -0.745, 1.217, -1.058, -0.894,
            1.026, -0.967, -1.065, 0.513, 0.969,
            0.582, -0.985, 0.097, 0.416, -0.514,
            0.898, -0.154, 0.617, -0.436, -1.212,
            -1.571, 0.210, -1.101, 1.018, -1.702,
            -2.230, -0.648, -0.350, 0.446, -2.667,
            0.094, -0.380, -2.852, -0.888, -1.481,
            -0.359, -0.554, 1.531, 0.052, -1.715,
            1.255, -0.540, 0.362, -0.654, -0.272,
            -1.810, 0.269, -1.918, 0.001, 1.240,
            -0.368, -0.647, -2.282, 0.498, 0.001,
            -3.059, -1.171, 0.566, 0.948, 0.925,
            0.825, 0.130, 0.930, 0.523, 0.443,
            -0.649, 0.554, -2.823, 0.158, -1.180,
            0.610, 0.877, 0.791, -0.078, 1.412,
        ]
        comm = {}
        self.fun(x, comm, window=2.)
        self.assertAlmostEqual(
            self.fun(x, comm, window=1.).window,
            0.3763835852523296,
        )

if __name__ == '__main__': # pragma: no cover
    unittest.main()
