# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `blast` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

isum = utils._EngineState._get_symbol('f16dlf')
isum.restype = utils._EngineIntScalarType.c_type
isum.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
)

imax_val = utils._EngineState._get_symbol('f16dnf')
imax_val.restype = None
imax_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, i.
)

imin_val = utils._EngineState._get_symbol('f16dpf')
imin_val.restype = None
imin_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, i.
)

iamax_val = utils._EngineState._get_symbol('f16dqf')
iamax_val.restype = None
iamax_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, i.
)

iamin_val = utils._EngineState._get_symbol('f16drf')
iamin_val.restype = None
iamin_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineIntArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, i.
)

ddot = utils._EngineState._get_symbol('blas_ddot')
ddot.restype = None
ddot.argtypes = (
    utils._BYREF_INT, # Input, conj.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input, y[1+(n-1)*abs(incy)].
    utils._BYREF_INT, # Input, incy.
    utils._BYREF_FLOAT64, # Input/Output, r.
)
f16eaf = utils._EngineState._get_symbol('f16eaf')
f16eaf.restype = ddot.restype
f16eaf.argtypes = ddot.argtypes

daxpby = utils._EngineState._get_symbol('blas_daxpby')
daxpby.restype = None
daxpby.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[1+(n-1)*abs(incy)].
    utils._BYREF_INT, # Input, incy.
)
f16ecf = utils._EngineState._get_symbol('f16ecf')
f16ecf.restype = daxpby.restype
f16ecf.argtypes = daxpby.argtypes

dwaxpby = utils._EngineState._get_symbol('blas_dwaxpby')
dwaxpby.restype = None
dwaxpby.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input, y[1+(n-1)*abs(incy)].
    utils._BYREF_INT, # Input, incy.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, w[1+(n-1)*abs(incw)].
    utils._BYREF_INT, # Input, incw.
)
f16ehf = utils._EngineState._get_symbol('f16ehf')
f16ehf.restype = dwaxpby.restype
f16ehf.argtypes = dwaxpby.argtypes

dsum = utils._EngineState._get_symbol('blas_dsum')
dsum.restype = utils._EngineFloat64ScalarType.c_type
dsum.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
)
f16elf = utils._EngineState._get_symbol('f16elf')
f16elf.restype = dsum.restype
f16elf.argtypes = dsum.argtypes

zaxpby = utils._EngineState._get_symbol('blas_zaxpby')
zaxpby.restype = None
zaxpby.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[1+(n-1)*abs(incy)].
    utils._BYREF_INT, # Input, incy.
)
f16gcf = utils._EngineState._get_symbol('f16gcf')
f16gcf.restype = zaxpby.restype
f16gcf.argtypes = zaxpby.argtypes

zwaxpby = utils._EngineState._get_symbol('blas_zwaxpby')
zwaxpby.restype = None
zwaxpby.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input, y[1+(n-1)*abs(incy)].
    utils._BYREF_INT, # Input, incy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, w[1+(n-1)*abs(incw)].
    utils._BYREF_INT, # Input, incw.
)
f16ghf = utils._EngineState._get_symbol('f16ghf')
f16ghf.restype = zwaxpby.restype
f16ghf.argtypes = zwaxpby.argtypes

zsum = None # Not supported: com-valued function

dmax_val = utils._EngineState._get_symbol('blas_dmax_val')
dmax_val.restype = None
dmax_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_FLOAT64, # Output, r.
)
f16jnf = utils._EngineState._get_symbol('f16jnf')
f16jnf.restype = dmax_val.restype
f16jnf.argtypes = dmax_val.argtypes

dmin_val = utils._EngineState._get_symbol('blas_dmin_val')
dmin_val.restype = None
dmin_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_FLOAT64, # Output, r.
)
f16jpf = utils._EngineState._get_symbol('f16jpf')
f16jpf.restype = dmin_val.restype
f16jpf.argtypes = dmin_val.argtypes

damax_val = utils._EngineState._get_symbol('blas_damax_val')
damax_val.restype = None
damax_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_FLOAT64, # Output, r.
)
f16jqf = utils._EngineState._get_symbol('f16jqf')
f16jqf.restype = damax_val.restype
f16jqf.argtypes = damax_val.argtypes

damin_val = utils._EngineState._get_symbol('blas_damin_val')
damin_val.restype = None
damin_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_FLOAT64, # Output, r.
)
f16jrf = utils._EngineState._get_symbol('f16jrf')
f16jrf.restype = damin_val.restype
f16jrf.argtypes = damin_val.argtypes

zamax_val = utils._EngineState._get_symbol('blas_zamax_val')
zamax_val.restype = None
zamax_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_FLOAT64, # Output, r.
)
f16jsf = utils._EngineState._get_symbol('f16jsf')
f16jsf.restype = zamax_val.restype
f16jsf.argtypes = zamax_val.argtypes

zamin_val = utils._EngineState._get_symbol('blas_zamin_val')
zamin_val.restype = None
zamin_val.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, x[1+(n-1)*abs(incx)].
    utils._BYREF_INT, # Input, incx.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_FLOAT64, # Output, r.
)
f16jtf = utils._EngineState._get_symbol('f16jtf')
f16jtf.restype = zamin_val.restype
f16jtf.argtypes = zamin_val.argtypes

dgb_norm = utils._EngineState._get_symbol('f16rbf')
dgb_norm.restype = utils._EngineFloat64ScalarType.c_type
dgb_norm.argtypes = (
    utils._BYREF_INT, # Input, inorm.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
)

zgb_norm = utils._EngineState._get_symbol('f16ubf')
zgb_norm.restype = utils._EngineFloat64ScalarType.c_type
zgb_norm.argtypes = (
    utils._BYREF_INT, # Input, inorm.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
)
