# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `lapackeig` Chapter.
"""

# NAG Copyright 2017-2020.

from ..base import utils

dgels = utils._EngineState._get_symbol('dgels')
dgels.restype = None
dgels.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08aaf = utils._EngineState._get_symbol('f08aaf')
f08aaf.restype = dgels.restype
f08aaf.argtypes = dgels.argtypes

dgeqrt = utils._EngineState._get_symbol('dgeqrt')
dgeqrt.restype = None
dgeqrt.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[nb*n].
    utils._BYREF_INT, # Output, info.
)
f08abf = utils._EngineState._get_symbol('f08abf')
f08abf.restype = dgeqrt.restype
f08abf.argtypes = dgeqrt.argtypes

dgemqrt = utils._EngineState._get_symbol('dgemqrt')
dgemqrt.restype = None
dgemqrt.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, nb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08acf = utils._EngineState._get_symbol('f08acf')
f08acf.restype = dgemqrt.restype
f08acf.argtypes = dgemqrt.argtypes

dgeqrf = utils._EngineState._get_symbol('dgeqrf')
dgeqrf.restype = None
dgeqrf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08aef = utils._EngineState._get_symbol('f08aef')
f08aef.restype = dgeqrf.restype
f08aef.argtypes = dgeqrf.argtypes

dorgqr = utils._EngineState._get_symbol('dorgqr')
dorgqr.restype = None
dorgqr.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08aff = utils._EngineState._get_symbol('f08aff')
f08aff.restype = dorgqr.restype
f08aff.argtypes = dorgqr.argtypes

dormqr = utils._EngineState._get_symbol('dormqr')
dormqr.restype = None
dormqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08agf = utils._EngineState._get_symbol('f08agf')
f08agf.restype = dormqr.restype
f08agf.argtypes = dormqr.argtypes

dgelqf = utils._EngineState._get_symbol('dgelqf')
dgelqf.restype = None
dgelqf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08ahf = utils._EngineState._get_symbol('f08ahf')
f08ahf.restype = dgelqf.restype
f08ahf.argtypes = dgelqf.argtypes

dorglq = utils._EngineState._get_symbol('dorglq')
dorglq.restype = None
dorglq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08ajf = utils._EngineState._get_symbol('f08ajf')
f08ajf.restype = dorglq.restype
f08ajf.argtypes = dorglq.argtypes

dormlq = utils._EngineState._get_symbol('dormlq')
dormlq.restype = None
dormlq.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08akf = utils._EngineState._get_symbol('f08akf')
f08akf.restype = dormlq.restype
f08akf.argtypes = dormlq.argtypes

zgels = utils._EngineState._get_symbol('zgels')
zgels.restype = None
zgels.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08anf = utils._EngineState._get_symbol('f08anf')
f08anf.restype = zgels.restype
f08anf.argtypes = zgels.argtypes

zgeqrt = utils._EngineState._get_symbol('zgeqrt')
zgeqrt.restype = None
zgeqrt.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[nb*n].
    utils._BYREF_INT, # Output, info.
)
f08apf = utils._EngineState._get_symbol('f08apf')
f08apf.restype = zgeqrt.restype
f08apf.argtypes = zgeqrt.argtypes

zgemqrt = utils._EngineState._get_symbol('zgemqrt')
zgemqrt.restype = None
zgemqrt.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, nb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08aqf = utils._EngineState._get_symbol('f08aqf')
f08aqf.restype = zgemqrt.restype
f08aqf.argtypes = zgemqrt.argtypes

zgeqrf = utils._EngineState._get_symbol('zgeqrf')
zgeqrf.restype = None
zgeqrf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08asf = utils._EngineState._get_symbol('f08asf')
f08asf.restype = zgeqrf.restype
f08asf.argtypes = zgeqrf.argtypes

zungqr = utils._EngineState._get_symbol('zungqr')
zungqr.restype = None
zungqr.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08atf = utils._EngineState._get_symbol('f08atf')
f08atf.restype = zungqr.restype
f08atf.argtypes = zungqr.argtypes

zunmqr = utils._EngineState._get_symbol('zunmqr')
zunmqr.restype = None
zunmqr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08auf = utils._EngineState._get_symbol('f08auf')
f08auf.restype = zunmqr.restype
f08auf.argtypes = zunmqr.argtypes

zgelqf = utils._EngineState._get_symbol('zgelqf')
zgelqf.restype = None
zgelqf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08avf = utils._EngineState._get_symbol('f08avf')
f08avf.restype = zgelqf.restype
f08avf.argtypes = zgelqf.argtypes

zunglq = utils._EngineState._get_symbol('zunglq')
zunglq.restype = None
zunglq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08awf = utils._EngineState._get_symbol('f08awf')
f08awf.restype = zunglq.restype
f08awf.argtypes = zunglq.argtypes

zunmlq = utils._EngineState._get_symbol('zunmlq')
zunmlq.restype = None
zunmlq.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08axf = utils._EngineState._get_symbol('f08axf')
f08axf.restype = zunmlq.restype
f08axf.argtypes = zunmlq.argtypes

dgelsy = utils._EngineState._get_symbol('dgelsy')
dgelsy.restype = None
dgelsy.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineIntArrayType.c_type, # Input/Output, jpvt[*].
    utils._BYREF_FLOAT64, # Input, rcond.
    utils._BYREF_INT, # Output, rank.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08baf = utils._EngineState._get_symbol('f08baf')
f08baf.restype = dgelsy.restype
f08baf.argtypes = dgelsy.argtypes

dtpqrt = utils._EngineState._get_symbol('dtpqrt')
dtpqrt.restype = None
dtpqrt.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, l.
    utils._BYREF_INT, # Input, nb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
)
f08bbf = utils._EngineState._get_symbol('f08bbf')
f08bbf.restype = dtpqrt.restype
f08bbf.argtypes = dtpqrt.argtypes

dtpmqrt = utils._EngineState._get_symbol('dtpmqrt')
dtpmqrt.restype = None
dtpmqrt.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, l.
    utils._BYREF_INT, # Input, nb.
    utils._EngineFloat64ArrayType.c_type, # Input, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c1[ldc1, *].
    utils._BYREF_INT, # Input, ldc1.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c2[ldc2, *].
    utils._BYREF_INT, # Input, ldc2.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08bcf = utils._EngineState._get_symbol('f08bcf')
f08bcf.restype = dtpmqrt.restype
f08bcf.argtypes = dtpmqrt.argtypes

dgeqpf = utils._EngineState._get_symbol('dgeqpf')
dgeqpf.restype = None
dgeqpf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input/Output, jpvt[*].
    utils._EngineFloat64ArrayType.c_type, # Output, tau[min(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._BYREF_INT, # Output, info.
)
f08bef = utils._EngineState._get_symbol('f08bef')
f08bef.restype = dgeqpf.restype
f08bef.argtypes = dgeqpf.argtypes

dgeqp3 = utils._EngineState._get_symbol('dgeqp3')
dgeqp3.restype = None
dgeqp3.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input/Output, jpvt[*].
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08bff = utils._EngineState._get_symbol('f08bff')
f08bff.restype = dgeqp3.restype
f08bff.argtypes = dgeqp3.argtypes

dtzrzf = utils._EngineState._get_symbol('dtzrzf')
dtzrzf.restype = None
dtzrzf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08bhf = utils._EngineState._get_symbol('f08bhf')
f08bhf.restype = dtzrzf.restype
f08bhf.argtypes = dtzrzf.argtypes

dormrz = utils._EngineState._get_symbol('dormrz')
dormrz.restype = None
dormrz.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, l.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08bkf = utils._EngineState._get_symbol('f08bkf')
f08bkf.restype = dormrz.restype
f08bkf.argtypes = dormrz.argtypes

zgelsy = utils._EngineState._get_symbol('zgelsy')
zgelsy.restype = None
zgelsy.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineIntArrayType.c_type, # Input/Output, jpvt[*].
    utils._BYREF_FLOAT64, # Input, rcond.
    utils._BYREF_INT, # Output, rank.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
)
f08bnf = utils._EngineState._get_symbol('f08bnf')
f08bnf.restype = zgelsy.restype
f08bnf.argtypes = zgelsy.argtypes

ztpqrt = utils._EngineState._get_symbol('ztpqrt')
ztpqrt.restype = None
ztpqrt.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, l.
    utils._BYREF_INT, # Input, nb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
)
f08bpf = utils._EngineState._get_symbol('f08bpf')
f08bpf.restype = ztpqrt.restype
f08bpf.argtypes = ztpqrt.argtypes

ztpmqrt = utils._EngineState._get_symbol('ztpmqrt')
ztpmqrt.restype = None
ztpmqrt.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, l.
    utils._BYREF_INT, # Input, nb.
    utils._EngineComplex128ArrayType.c_type, # Input, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c1[ldc1, *].
    utils._BYREF_INT, # Input, ldc1.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c2[ldc2, *].
    utils._BYREF_INT, # Input, ldc2.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08bqf = utils._EngineState._get_symbol('f08bqf')
f08bqf.restype = ztpmqrt.restype
f08bqf.argtypes = ztpmqrt.argtypes

zgeqpf = utils._EngineState._get_symbol('zgeqpf')
zgeqpf.restype = None
zgeqpf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input/Output, jpvt[*].
    utils._EngineComplex128ArrayType.c_type, # Output, tau[min(m, n)].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._BYREF_INT, # Output, info.
)
f08bsf = utils._EngineState._get_symbol('f08bsf')
f08bsf.restype = zgeqpf.restype
f08bsf.argtypes = zgeqpf.argtypes

zgeqp3 = utils._EngineState._get_symbol('zgeqp3')
zgeqp3.restype = None
zgeqp3.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineIntArrayType.c_type, # Input/Output, jpvt[*].
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
)
f08btf = utils._EngineState._get_symbol('f08btf')
f08btf.restype = zgeqp3.restype
f08btf.argtypes = zgeqp3.argtypes

ztzrzf = utils._EngineState._get_symbol('ztzrzf')
ztzrzf.restype = None
ztzrzf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08bvf = utils._EngineState._get_symbol('f08bvf')
f08bvf.restype = ztzrzf.restype
f08bvf.argtypes = ztzrzf.argtypes

zunmrz = utils._EngineState._get_symbol('zunmrz')
zunmrz.restype = None
zunmrz.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, l.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08bxf = utils._EngineState._get_symbol('f08bxf')
f08bxf.restype = zunmrz.restype
f08bxf.argtypes = zunmrz.argtypes

dgeqlf = utils._EngineState._get_symbol('dgeqlf')
dgeqlf.restype = None
dgeqlf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08cef = utils._EngineState._get_symbol('f08cef')
f08cef.restype = dgeqlf.restype
f08cef.argtypes = dgeqlf.argtypes

dorgql = utils._EngineState._get_symbol('dorgql')
dorgql.restype = None
dorgql.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08cff = utils._EngineState._get_symbol('f08cff')
f08cff.restype = dorgql.restype
f08cff.argtypes = dorgql.argtypes

dormql = utils._EngineState._get_symbol('dormql')
dormql.restype = None
dormql.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08cgf = utils._EngineState._get_symbol('f08cgf')
f08cgf.restype = dormql.restype
f08cgf.argtypes = dormql.argtypes

dgerqf = utils._EngineState._get_symbol('dgerqf')
dgerqf.restype = None
dgerqf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08chf = utils._EngineState._get_symbol('f08chf')
f08chf.restype = dgerqf.restype
f08chf.argtypes = dgerqf.argtypes

dorgrq = utils._EngineState._get_symbol('dorgrq')
dorgrq.restype = None
dorgrq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08cjf = utils._EngineState._get_symbol('f08cjf')
f08cjf.restype = dorgrq.restype
f08cjf.argtypes = dorgrq.argtypes

dormrq = utils._EngineState._get_symbol('dormrq')
dormrq.restype = None
dormrq.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08ckf = utils._EngineState._get_symbol('f08ckf')
f08ckf.restype = dormrq.restype
f08ckf.argtypes = dormrq.argtypes

zgeqlf = utils._EngineState._get_symbol('zgeqlf')
zgeqlf.restype = None
zgeqlf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08csf = utils._EngineState._get_symbol('f08csf')
f08csf.restype = zgeqlf.restype
f08csf.argtypes = zgeqlf.argtypes

zungql = utils._EngineState._get_symbol('zungql')
zungql.restype = None
zungql.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08ctf = utils._EngineState._get_symbol('f08ctf')
f08ctf.restype = zungql.restype
f08ctf.argtypes = zungql.argtypes

zunmql = utils._EngineState._get_symbol('zunmql')
zunmql.restype = None
zunmql.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08cuf = utils._EngineState._get_symbol('f08cuf')
f08cuf.restype = zunmql.restype
f08cuf.argtypes = zunmql.argtypes

zgerqf = utils._EngineState._get_symbol('zgerqf')
zgerqf.restype = None
zgerqf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08cvf = utils._EngineState._get_symbol('f08cvf')
f08cvf.restype = zgerqf.restype
f08cvf.argtypes = zgerqf.argtypes

zungrq = utils._EngineState._get_symbol('zungrq')
zungrq.restype = None
zungrq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08cwf = utils._EngineState._get_symbol('f08cwf')
f08cwf.restype = zungrq.restype
f08cwf.argtypes = zungrq.argtypes

zunmrq = utils._EngineState._get_symbol('zunmrq')
zunmrq.restype = None
zunmrq.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08cxf = utils._EngineState._get_symbol('f08cxf')
f08cxf.restype = zunmrq.restype
f08cxf.argtypes = zunmrq.argtypes

dsyev = utils._EngineState._get_symbol('dsyev')
dsyev.restype = None
dsyev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08faf = utils._EngineState._get_symbol('f08faf')
f08faf.restype = dsyev.restype
f08faf.argtypes = dsyev.argtypes

dsyevx = utils._EngineState._get_symbol('dsyevx')
dsyevx.restype = None
dsyevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fbf = utils._EngineState._get_symbol('f08fbf')
f08fbf.restype = dsyevx.restype
f08fbf.argtypes = dsyevx.argtypes

dsyevd = utils._EngineState._get_symbol('dsyevd')
dsyevd.restype = None
dsyevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fcf = utils._EngineState._get_symbol('f08fcf')
f08fcf.restype = dsyevd.restype
f08fcf.argtypes = dsyevd.argtypes

dsyevr = utils._EngineState._get_symbol('dsyevr')
dsyevr.restype = None
dsyevr.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Output, isuppz[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fdf = utils._EngineState._get_symbol('f08fdf')
f08fdf.restype = dsyevr.restype
f08fdf.argtypes = dsyevr.argtypes

dsytrd = utils._EngineState._get_symbol('dsytrd')
dsytrd.restype = None
dsytrd.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fef = utils._EngineState._get_symbol('f08fef')
f08fef.restype = dsytrd.restype
f08fef.argtypes = dsytrd.argtypes

dorgtr = utils._EngineState._get_symbol('dorgtr')
dorgtr.restype = None
dorgtr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fff = utils._EngineState._get_symbol('f08fff')
f08fff.restype = dorgtr.restype
f08fff.argtypes = dorgtr.argtypes

dormtr = utils._EngineState._get_symbol('dormtr')
dormtr.restype = None
dormtr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08fgf = utils._EngineState._get_symbol('f08fgf')
f08fgf.restype = dormtr.restype
f08fgf.argtypes = dormtr.argtypes

ddisna = utils._EngineState._get_symbol('ddisna')
ddisna.restype = None
ddisna.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, sep[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
f08flf = utils._EngineState._get_symbol('f08flf')
f08flf.restype = ddisna.restype
f08flf.argtypes = ddisna.argtypes

zheev = utils._EngineState._get_symbol('zheev')
zheev.restype = None
zheev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fnf = utils._EngineState._get_symbol('f08fnf')
f08fnf.restype = zheev.restype
f08fnf.argtypes = zheev.argtypes

zheevx = utils._EngineState._get_symbol('zheevx')
zheevx.restype = None
zheevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fpf = utils._EngineState._get_symbol('f08fpf')
f08fpf.restype = zheevx.restype
f08fpf.argtypes = zheevx.argtypes

zheevd = utils._EngineState._get_symbol('zheevd')
zheevd.restype = None
zheevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fqf = utils._EngineState._get_symbol('f08fqf')
f08fqf.restype = zheevd.restype
f08fqf.argtypes = zheevd.argtypes

zheevr = utils._EngineState._get_symbol('zheevr')
zheevr.restype = None
zheevr.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Output, isuppz[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08frf = utils._EngineState._get_symbol('f08frf')
f08frf.restype = zheevr.restype
f08frf.argtypes = zheevr.argtypes

zhetrd = utils._EngineState._get_symbol('zhetrd')
zhetrd.restype = None
zhetrd.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08fsf = utils._EngineState._get_symbol('f08fsf')
f08fsf.restype = zhetrd.restype
f08fsf.argtypes = zhetrd.argtypes

zungtr = utils._EngineState._get_symbol('zungtr')
zungtr.restype = None
zungtr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08ftf = utils._EngineState._get_symbol('f08ftf')
f08ftf.restype = zungtr.restype
f08ftf.argtypes = zungtr.argtypes

zunmtr = utils._EngineState._get_symbol('zunmtr')
zunmtr.restype = None
zunmtr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08fuf = utils._EngineState._get_symbol('f08fuf')
f08fuf.restype = zunmtr.restype
f08fuf.argtypes = zunmtr.argtypes

dspev = utils._EngineState._get_symbol('dspev')
dspev.restype = None
dspev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gaf = utils._EngineState._get_symbol('f08gaf')
f08gaf.restype = dspev.restype
f08gaf.argtypes = dspev.argtypes

dspevx = utils._EngineState._get_symbol('dspevx')
dspevx.restype = None
dspevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[8*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gbf = utils._EngineState._get_symbol('f08gbf')
f08gbf.restype = dspevx.restype
f08gbf.argtypes = dspevx.argtypes

dspevd = utils._EngineState._get_symbol('dspevd')
dspevd.restype = None
dspevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gcf = utils._EngineState._get_symbol('f08gcf')
f08gcf.restype = dspevd.restype
f08gcf.argtypes = dspevd.argtypes

dsptrd = utils._EngineState._get_symbol('dsptrd')
dsptrd.restype = None
dsptrd.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gef = utils._EngineState._get_symbol('f08gef')
f08gef.restype = dsptrd.restype
f08gef.argtypes = dsptrd.argtypes

dopgtr = utils._EngineState._get_symbol('dopgtr')
dopgtr.restype = None
dopgtr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n-1].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gff = utils._EngineState._get_symbol('f08gff')
f08gff.restype = dopgtr.restype
f08gff.argtypes = dopgtr.argtypes

dopmtr = utils._EngineState._get_symbol('dopmtr')
dopmtr.restype = None
dopmtr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08ggf = utils._EngineState._get_symbol('f08ggf')
f08ggf.restype = dopmtr.restype
f08ggf.argtypes = dopmtr.argtypes

zhpev = utils._EngineState._get_symbol('zhpev')
zhpev.restype = None
zhpev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n-1].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[3*n-2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gnf = utils._EngineState._get_symbol('f08gnf')
f08gnf.restype = zhpev.restype
f08gnf.argtypes = zhpev.argtypes

zhpevx = utils._EngineState._get_symbol('zhpevx')
zhpevx.restype = None
zhpevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gpf = utils._EngineState._get_symbol('f08gpf')
f08gpf.restype = zhpevx.restype
f08gpf.argtypes = zhpevx.argtypes

zhpevd = utils._EngineState._get_symbol('zhpevd')
zhpevd.restype = None
zhpevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gqf = utils._EngineState._get_symbol('f08gqf')
f08gqf.restype = zhpevd.restype
f08gqf.argtypes = zhpevd.argtypes

zhptrd = utils._EngineState._get_symbol('zhptrd')
zhptrd.restype = None
zhptrd.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gsf = utils._EngineState._get_symbol('f08gsf')
f08gsf.restype = zhptrd.restype
f08gsf.argtypes = zhptrd.argtypes

zupgtr = utils._EngineState._get_symbol('zupgtr')
zupgtr.restype = None
zupgtr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n-1].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08gtf = utils._EngineState._get_symbol('f08gtf')
f08gtf.restype = zupgtr.restype
f08gtf.argtypes = zupgtr.argtypes

zupmtr = utils._EngineState._get_symbol('zupmtr')
zupmtr.restype = None
zupmtr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08guf = utils._EngineState._get_symbol('f08guf')
f08guf.restype = zupmtr.restype
f08guf.argtypes = zupmtr.argtypes

dsbev = utils._EngineState._get_symbol('dsbev')
dsbev.restype = None
dsbev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n-2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08haf = utils._EngineState._get_symbol('f08haf')
f08haf.restype = dsbev.restype
f08haf.argtypes = dsbev.argtypes

dsbevx = utils._EngineState._get_symbol('dsbevx')
dsbevx.restype = None
dsbevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hbf = utils._EngineState._get_symbol('f08hbf')
f08hbf.restype = dsbevx.restype
f08hbf.argtypes = dsbevx.argtypes

dsbevd = utils._EngineState._get_symbol('dsbevd')
dsbevd.restype = None
dsbevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hcf = utils._EngineState._get_symbol('f08hcf')
f08hcf.restype = dsbevd.restype
f08hcf.argtypes = dsbevd.argtypes

dsbtrd = utils._EngineState._get_symbol('dsbtrd')
dsbtrd.restype = None
dsbtrd.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hef = utils._EngineState._get_symbol('f08hef')
f08hef.restype = dsbtrd.restype
f08hef.argtypes = dsbtrd.argtypes

zhbev = utils._EngineState._get_symbol('zhbev')
zhbev.restype = None
zhbev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[3*n-2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hnf = utils._EngineState._get_symbol('f08hnf')
f08hnf.restype = zhbev.restype
f08hnf.argtypes = zhbev.argtypes

zhbevx = utils._EngineState._get_symbol('zhbevx')
zhbevx.restype = None
zhbevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hpf = utils._EngineState._get_symbol('f08hpf')
f08hpf.restype = zhbevx.restype
f08hpf.argtypes = zhbevx.argtypes

zhbevd = utils._EngineState._get_symbol('zhbevd')
zhbevd.restype = None
zhbevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hqf = utils._EngineState._get_symbol('f08hqf')
f08hqf.restype = zhbevd.restype
f08hqf.argtypes = zhbevd.argtypes

zhbtrd = utils._EngineState._get_symbol('zhbtrd')
zhbtrd.restype = None
zhbtrd.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kd.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08hsf = utils._EngineState._get_symbol('f08hsf')
f08hsf.restype = zhbtrd.restype
f08hsf.argtypes = zhbtrd.argtypes

dstev = utils._EngineState._get_symbol('dstev')
dstev.restype = None
dstev.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
)
f08jaf = utils._EngineState._get_symbol('f08jaf')
f08jaf.restype = dstev.restype
f08jaf.argtypes = dstev.argtypes

dstevx = utils._EngineState._get_symbol('dstevx')
dstevx.restype = None
dstevx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[5*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08jbf = utils._EngineState._get_symbol('f08jbf')
f08jbf.restype = dstevx.restype
f08jbf.argtypes = dstevx.argtypes

dstevd = utils._EngineState._get_symbol('dstevd')
dstevd.restype = None
dstevd.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
f08jcf = utils._EngineState._get_symbol('f08jcf')
f08jcf.restype = dstevd.restype
f08jcf.argtypes = dstevd.argtypes

dstevr = utils._EngineState._get_symbol('dstevr')
dstevr.restype = None
dstevr.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Output, isuppz[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08jdf = utils._EngineState._get_symbol('f08jdf')
f08jdf.restype = dstevr.restype
f08jdf.argtypes = dstevr.argtypes

dsteqr = utils._EngineState._get_symbol('dsteqr')
dsteqr.restype = None
dsteqr.argtypes = (
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08jef = utils._EngineState._get_symbol('f08jef')
f08jef.restype = dsteqr.restype
f08jef.argtypes = dsteqr.argtypes

dsterf = utils._EngineState._get_symbol('dsterf')
dsterf.restype = None
dsterf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_INT, # Output, info.
)
f08jff = utils._EngineState._get_symbol('f08jff')
f08jff.restype = dsterf.restype
f08jff.argtypes = dsterf.argtypes

dpteqr = utils._EngineState._get_symbol('dpteqr')
dpteqr.restype = None
dpteqr.argtypes = (
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[4*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08jgf = utils._EngineState._get_symbol('f08jgf')
f08jgf.restype = dpteqr.restype
f08jgf.argtypes = dpteqr.argtypes

dstedc = utils._EngineState._get_symbol('dstedc')
dstedc.restype = None
dstedc.argtypes = (
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08jhf = utils._EngineState._get_symbol('f08jhf')
f08jhf.restype = dstedc.restype
f08jhf.argtypes = dstedc.argtypes

dstebz = utils._EngineState._get_symbol('dstebz')
dstebz.restype = None
dstebz.argtypes = (
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, order(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._BYREF_INT, # Output, m.
    utils._BYREF_INT, # Output, nsplit.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineIntArrayType.c_type, # Output, iblock[n].
    utils._EngineIntArrayType.c_type, # Output, isplit[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[4*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)
f08jjf = utils._EngineState._get_symbol('f08jjf')
f08jjf.restype = dstebz.restype
f08jjf.argtypes = dstebz.argtypes

dstein = utils._EngineState._get_symbol('dstein')
dstein.restype = None
dstein.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, w[*].
    utils._EngineIntArrayType.c_type, # Input, iblock[*].
    utils._EngineIntArrayType.c_type, # Input, isplit[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[5*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineIntArrayType.c_type, # Output, ifailv[m].
    utils._BYREF_INT, # Output, info.
)
f08jkf = utils._EngineState._get_symbol('f08jkf')
f08jkf.restype = dstein.restype
f08jkf.argtypes = dstein.argtypes

dstegr = utils._EngineState._get_symbol('dstegr')
dstegr.restype = None
dstegr.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Output, isuppz[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08jlf = utils._EngineState._get_symbol('f08jlf')
f08jlf.restype = dstegr.restype
f08jlf.argtypes = dstegr.argtypes

zsteqr = utils._EngineState._get_symbol('zsteqr')
zsteqr.restype = None
zsteqr.argtypes = (
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08jsf = utils._EngineState._get_symbol('f08jsf')
f08jsf.restype = zsteqr.restype
f08jsf.argtypes = zsteqr.argtypes

zpteqr = utils._EngineState._get_symbol('zpteqr')
zpteqr.restype = None
zpteqr.argtypes = (
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[4*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08juf = utils._EngineState._get_symbol('f08juf')
f08juf.restype = zpteqr.restype
f08juf.argtypes = zpteqr.argtypes

zstedc = utils._EngineState._get_symbol('zstedc')
zstedc.restype = None
zstedc.argtypes = (
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08jvf = utils._EngineState._get_symbol('f08jvf')
f08jvf.restype = zstedc.restype
f08jvf.argtypes = zstedc.argtypes

zstein = utils._EngineState._get_symbol('zstein')
zstein.restype = None
zstein.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input, e[*].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, w[*].
    utils._EngineIntArrayType.c_type, # Input, iblock[*].
    utils._EngineIntArrayType.c_type, # Input, isplit[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[5*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineIntArrayType.c_type, # Output, ifailv[m].
    utils._BYREF_INT, # Output, info.
)
f08jxf = utils._EngineState._get_symbol('f08jxf')
f08jxf.restype = zstein.restype
f08jxf.argtypes = zstein.argtypes

zstegr = utils._EngineState._get_symbol('zstegr')
zstegr.restype = None
zstegr.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Output, isuppz[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08jyf = utils._EngineState._get_symbol('f08jyf')
f08jyf.restype = zstegr.restype
f08jyf.argtypes = zstegr.argtypes

dgelss = utils._EngineState._get_symbol('dgelss')
dgelss.restype = None
dgelss.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._BYREF_FLOAT64, # Input, rcond.
    utils._BYREF_INT, # Output, rank.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08kaf = utils._EngineState._get_symbol('f08kaf')
f08kaf.restype = dgelss.restype
f08kaf.argtypes = dgelss.argtypes

dgesvd = utils._EngineState._get_symbol('dgesvd')
dgesvd.restype = None
dgesvd.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobvt(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineFloat64ArrayType.c_type, # Output, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvt.
)
f08kbf = utils._EngineState._get_symbol('f08kbf')
f08kbf.restype = dgesvd.restype
f08kbf.argtypes = dgesvd.argtypes

dgelsd = utils._EngineState._get_symbol('dgelsd')
dgelsd.restype = None
dgelsd.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._BYREF_FLOAT64, # Input, rcond.
    utils._BYREF_INT, # Output, rank.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
)
f08kcf = utils._EngineState._get_symbol('f08kcf')
f08kcf.restype = dgelsd.restype
f08kcf.argtypes = dgelsd.argtypes

dgesdd = utils._EngineState._get_symbol('dgesdd')
dgesdd.restype = None
dgesdd.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, s[min(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[8*min(m, n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
)
f08kdf = utils._EngineState._get_symbol('f08kdf')
f08kdf.restype = dgesdd.restype
f08kdf.argtypes = dgesdd.argtypes

dgebrd = utils._EngineState._get_symbol('dgebrd')
dgebrd.restype = None
dgebrd.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Output, tauq[*].
    utils._EngineFloat64ArrayType.c_type, # Output, taup[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08kef = utils._EngineState._get_symbol('f08kef')
f08kef.restype = dgebrd.restype
f08kef.argtypes = dgebrd.argtypes

dorgbr = utils._EngineState._get_symbol('dorgbr')
dorgbr.restype = None
dorgbr.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
)
f08kff = utils._EngineState._get_symbol('f08kff')
f08kff.restype = dorgbr.restype
f08kff.argtypes = dorgbr.argtypes

dormbr = utils._EngineState._get_symbol('dormbr')
dormbr.restype = None
dormbr.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08kgf = utils._EngineState._get_symbol('f08kgf')
f08kgf.restype = dormbr.restype
f08kgf.argtypes = dormbr.argtypes

dgejsv = utils._EngineState._get_symbol('dgejsv')
dgejsv.restype = None
dgejsv.argtypes = (
    utils._BYREF_STRING, # Input, joba(len=1).
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobr(len=1).
    utils._BYREF_STRING, # Input, jobt(len=1).
    utils._BYREF_STRING, # Input, jobp(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, sva[n].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, work[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Output, iwork[m+3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of joba.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobp.
)
f08khf = utils._EngineState._get_symbol('f08khf')
f08khf.restype = dgejsv.restype
f08khf.argtypes = dgejsv.argtypes

dgesvj = utils._EngineState._get_symbol('dgesvj')
dgesvj.restype = None
dgesvj.argtypes = (
    utils._BYREF_STRING, # Input, joba(len=1).
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, sva[n].
    utils._BYREF_INT, # Input, mv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, work[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of joba.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
)
f08kjf = utils._EngineState._get_symbol('f08kjf')
f08kjf.restype = dgesvj.restype
f08kjf.argtypes = dgesvj.argtypes

dgesvdx = utils._EngineState._get_symbol('dgesvdx')
dgesvdx.restype = None
dgesvdx.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobvt(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_INT, # Output, ns.
    utils._EngineFloat64ArrayType.c_type, # Output, s[min(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineFloat64ArrayType.c_type, # Output, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Output, iwork[12*min(n, m)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08kmf = utils._EngineState._get_symbol('f08kmf')
f08kmf.restype = dgesvdx.restype
f08kmf.argtypes = dgesvdx.argtypes

zgelss = utils._EngineState._get_symbol('zgelss')
zgelss.restype = None
zgelss.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._BYREF_FLOAT64, # Input, rcond.
    utils._BYREF_INT, # Output, rank.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
)
f08knf = utils._EngineState._get_symbol('f08knf')
f08knf.restype = zgelss.restype
f08knf.argtypes = zgelss.argtypes

zgesvd = utils._EngineState._get_symbol('zgesvd')
zgesvd.restype = None
zgesvd.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobvt(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Output, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvt.
)
f08kpf = utils._EngineState._get_symbol('f08kpf')
f08kpf.restype = zgesvd.restype
f08kpf.argtypes = zgesvd.argtypes

zgelsd = utils._EngineState._get_symbol('zgelsd')
zgelsd.restype = None
zgelsd.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrhs.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._BYREF_FLOAT64, # Input, rcond.
    utils._BYREF_INT, # Output, rank.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
)
f08kqf = utils._EngineState._get_symbol('f08kqf')
f08kqf.restype = zgelsd.restype
f08kqf.argtypes = zgelsd.argtypes

zgesdd = utils._EngineState._get_symbol('zgesdd')
zgesdd.restype = None
zgesdd.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, s[min(m, n)].
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[8*min(m, n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
)
f08krf = utils._EngineState._get_symbol('f08krf')
f08krf.restype = zgesdd.restype
f08krf.argtypes = zgesdd.argtypes

zgebrd = utils._EngineState._get_symbol('zgebrd')
zgebrd.restype = None
zgebrd.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Output, tauq[*].
    utils._EngineComplex128ArrayType.c_type, # Output, taup[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08ksf = utils._EngineState._get_symbol('f08ksf')
f08ksf.restype = zgebrd.restype
f08ksf.argtypes = zgebrd.argtypes

zungbr = utils._EngineState._get_symbol('zungbr')
zungbr.restype = None
zungbr.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
)
f08ktf = utils._EngineState._get_symbol('f08ktf')
f08ktf.restype = zungbr.restype
f08ktf.argtypes = zungbr.argtypes

zunmbr = utils._EngineState._get_symbol('zunmbr')
zunmbr.restype = None
zunmbr.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08kuf = utils._EngineState._get_symbol('f08kuf')
f08kuf.restype = zunmbr.restype
f08kuf.argtypes = zunmbr.argtypes

zgejsv = utils._EngineState._get_symbol('zgejsv')
zgejsv.restype = None
zgejsv.argtypes = (
    utils._BYREF_STRING, # Input, joba(len=1).
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobr(len=1).
    utils._BYREF_STRING, # Input, jobt(len=1).
    utils._BYREF_STRING, # Input, jobp(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, sva[n].
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Workspace, cwork[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Output, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Output, iwork[m+3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of joba.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobp.
)
f08kvf = utils._EngineState._get_symbol('f08kvf')
f08kvf.restype = zgejsv.restype
f08kvf.argtypes = zgejsv.argtypes

zgesvj = utils._EngineState._get_symbol('zgesvj')
zgesvj.restype = None
zgesvj.argtypes = (
    utils._BYREF_STRING, # Input, joba(len=1).
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, sva[n].
    utils._BYREF_INT, # Input, mv.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Workspace, cwork[lwork].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rwork[lrwork].
    utils._BYREF_INT, # Input, lrwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of joba.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
)
f08kwf = utils._EngineState._get_symbol('f08kwf')
f08kwf.restype = zgesvj.restype
f08kwf.argtypes = zgesvj.argtypes

zgesvdx = utils._EngineState._get_symbol('zgesvdx')
zgesvdx.restype = None
zgesvdx.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobvt(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_INT, # Output, ns.
    utils._EngineFloat64ArrayType.c_type, # Output, s[min(m, n)].
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Output, rwork[*].
    utils._EngineIntArrayType.c_type, # Output, iwork[12*min(n, m)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvt.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08kzf = utils._EngineState._get_symbol('f08kzf')
f08kzf.restype = zgesvdx.restype
f08kzf.argtypes = zgesvdx.argtypes

dgbbrd = utils._EngineState._get_symbol('dgbbrd')
dgbbrd.restype = None
dgbbrd.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ncc.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, d[min(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Output, e[min(m, n)-1].
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Output, pt[ldpt, *].
    utils._BYREF_INT, # Input, ldpt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*max(m, n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
)
f08lef = utils._EngineState._get_symbol('f08lef')
f08lef.restype = dgbbrd.restype
f08lef.argtypes = dgbbrd.argtypes

zgbbrd = utils._EngineState._get_symbol('zgbbrd')
zgbbrd.restype = None
zgbbrd.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ncc.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Output, d[min(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Output, e[min(m, n)-1].
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Output, pt[ldpt, *].
    utils._BYREF_INT, # Input, ldpt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(m, n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
)
f08lsf = utils._EngineState._get_symbol('f08lsf')
f08lsf.restype = zgbbrd.restype
f08lsf.argtypes = zgbbrd.argtypes

dbdsvdx = utils._EngineState._get_symbol('dbdsvdx')
dbdsvdx.restype = None
dbdsvdx.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[n].
    utils._EngineFloat64ArrayType.c_type, # Input, e[n-1].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_INT, # Output, ns.
    utils._EngineFloat64ArrayType.c_type, # Output, s[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[14*n].
    utils._EngineIntArrayType.c_type, # Output, iwork[12*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
)
f08mbf = utils._EngineState._get_symbol('f08mbf')
f08mbf.restype = dbdsvdx.restype
f08mbf.argtypes = dbdsvdx.argtypes

dbdsdc = utils._EngineState._get_symbol('dbdsdc')
dbdsdc.restype = None
dbdsdc.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineFloat64ArrayType.c_type, # Output, q[*].
    utils._EngineIntArrayType.c_type, # Output, iq[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[8*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
)
f08mdf = utils._EngineState._get_symbol('f08mdf')
f08mdf.restype = dbdsdc.restype
f08mdf.argtypes = dbdsdc.argtypes

dbdsqr = utils._EngineState._get_symbol('dbdsqr')
dbdsqr.restype = None
dbdsqr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ncvt.
    utils._BYREF_INT, # Input, nru.
    utils._BYREF_INT, # Input, ncc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08mef = utils._EngineState._get_symbol('f08mef')
f08mef.restype = dbdsqr.restype
f08mef.argtypes = dbdsqr.argtypes

zbdsqr = utils._EngineState._get_symbol('zbdsqr')
zbdsqr.restype = None
zbdsqr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ncvt.
    utils._BYREF_INT, # Input, nru.
    utils._BYREF_INT, # Input, ncc.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vt[ldvt, *].
    utils._BYREF_INT, # Input, ldvt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08msf = utils._EngineState._get_symbol('f08msf')
f08msf.restype = zbdsqr.restype
f08msf.argtypes = zbdsqr.argtypes

dgeev = utils._EngineState._get_symbol('dgeev')
dgeev.restype = None
dgeev.argtypes = (
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[*].
    utils._EngineFloat64ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)
f08naf = utils._EngineState._get_symbol('f08naf')
f08naf.restype = dgeev.restype
f08naf.argtypes = dgeev.argtypes

dgeevx = utils._EngineState._get_symbol('dgeevx')
dgeevx.restype = None
dgeevx.argtypes = (
    utils._BYREF_STRING, # Input, balanc(len=1).
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[*].
    utils._EngineFloat64ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, scale[*].
    utils._BYREF_FLOAT64, # Output, abnrm.
    utils._EngineFloat64ArrayType.c_type, # Output, rconde[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rcondv[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of balanc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08nbf = utils._EngineState._get_symbol('f08nbf')
f08nbf.restype = dgeevx.restype
f08nbf.argtypes = dgeevx.argtypes

dgehrd = utils._EngineState._get_symbol('dgehrd')
dgehrd.restype = None
dgehrd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08nef = utils._EngineState._get_symbol('f08nef')
f08nef.restype = dgehrd.restype
f08nef.argtypes = dgehrd.argtypes

dorghr = utils._EngineState._get_symbol('dorghr')
dorghr.restype = None
dorghr.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08nff = utils._EngineState._get_symbol('f08nff')
f08nff.restype = dorghr.restype
f08nff.argtypes = dorghr.argtypes

dormhr = utils._EngineState._get_symbol('dormhr')
dormhr.restype = None
dormhr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, tau[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08ngf = utils._EngineState._get_symbol('f08ngf')
f08ngf.restype = dormhr.restype
f08ngf.argtypes = dormhr.argtypes

dgebal = utils._EngineState._get_symbol('dgebal')
dgebal.restype = None
dgebal.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, scale[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
f08nhf = utils._EngineState._get_symbol('f08nhf')
f08nhf.restype = dgebal.restype
f08nhf.argtypes = dgebal.argtypes

dgebak = utils._EngineState._get_symbol('dgebak')
dgebak.restype = None
dgebak.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input, scale[*].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)
f08njf = utils._EngineState._get_symbol('f08njf')
f08njf.restype = dgebak.restype
f08njf.argtypes = dgebak.argtypes

zgeev = utils._EngineState._get_symbol('zgeev')
zgeev.restype = None
zgeev.argtypes = (
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)
f08nnf = utils._EngineState._get_symbol('f08nnf')
f08nnf.restype = zgeev.restype
f08nnf.argtypes = zgeev.argtypes

zgeevx = utils._EngineState._get_symbol('zgeevx')
zgeevx.restype = None
zgeevx.argtypes = (
    utils._BYREF_STRING, # Input, balanc(len=1).
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, scale[*].
    utils._BYREF_FLOAT64, # Output, abnrm.
    utils._EngineFloat64ArrayType.c_type, # Output, rconde[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rcondv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of balanc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08npf = utils._EngineState._get_symbol('f08npf')
f08npf.restype = zgeevx.restype
f08npf.argtypes = zgeevx.argtypes

zgehrd = utils._EngineState._get_symbol('zgehrd')
zgehrd.restype = None
zgehrd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08nsf = utils._EngineState._get_symbol('f08nsf')
f08nsf.restype = zgehrd.restype
f08nsf.argtypes = zgehrd.argtypes

zunghr = utils._EngineState._get_symbol('zunghr')
zunghr.restype = None
zunghr.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08ntf = utils._EngineState._get_symbol('f08ntf')
f08ntf.restype = zunghr.restype
f08ntf.argtypes = zunghr.argtypes

zunmhr = utils._EngineState._get_symbol('zunmhr')
zunmhr.restype = None
zunmhr.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, tau[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08nuf = utils._EngineState._get_symbol('f08nuf')
f08nuf.restype = zunmhr.restype
f08nuf.argtypes = zunmhr.argtypes

zgebal = utils._EngineState._get_symbol('zgebal')
zgebal.restype = None
zgebal.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, scale[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
f08nvf = utils._EngineState._get_symbol('f08nvf')
f08nvf.restype = zgebal.restype
f08nvf.argtypes = zgebal.argtypes

zgebak = utils._EngineState._get_symbol('zgebak')
zgebak.restype = None
zgebak.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input, scale[*].
    utils._BYREF_INT, # Input, m.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)
f08nwf = utils._EngineState._get_symbol('f08nwf')
f08nwf.restype = zgebak.restype
f08nwf.argtypes = zgebak.argtypes

dgees_select = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, wr.
    utils._BYREF_FLOAT64, # Input, wi.
)
dgees = utils._EngineState._get_symbol('dgees')
dgees.restype = None
dgees.argtypes = (
    utils._BYREF_STRING, # Input, jobvs(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    dgees_select,
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[*].
    utils._EngineFloat64ArrayType.c_type, # Output, vs[ldvs, *].
    utils._BYREF_INT, # Input, ldvs.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvs.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
)
f08paf = utils._EngineState._get_symbol('f08paf')
f08paf.restype = dgees.restype
f08paf.argtypes = dgees.argtypes

dgees_dummy_select = utils._EngineState._get_symbol('f08paz')
dgees_dummy_select.restype = utils._EngineLogicalScalarType.c_type
dgees_dummy_select.argtypes = (
    utils._BYREF_FLOAT64, # Input, wr.
    utils._BYREF_FLOAT64, # Input, wi.
)

dgeesx_select = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, wr.
    utils._BYREF_FLOAT64, # Input, wi.
)
dgeesx = utils._EngineState._get_symbol('dgeesx')
dgeesx.restype = None
dgeesx.argtypes = (
    utils._BYREF_STRING, # Input, jobvs(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    dgeesx_select,
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[*].
    utils._EngineFloat64ArrayType.c_type, # Output, vs[ldvs, *].
    utils._BYREF_INT, # Input, ldvs.
    utils._BYREF_FLOAT64, # Output, rconde.
    utils._BYREF_FLOAT64, # Output, rcondv.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvs.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08pbf = utils._EngineState._get_symbol('f08pbf')
f08pbf.restype = dgeesx.restype
f08pbf.argtypes = dgeesx.argtypes

dhseqr = utils._EngineState._get_symbol('dhseqr')
dhseqr.restype = None
dhseqr.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, h[ldh, *].
    utils._BYREF_INT, # Input, ldh.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08pef = utils._EngineState._get_symbol('f08pef')
f08pef.restype = dhseqr.restype
f08pef.argtypes = dhseqr.argtypes

dhsein = utils._EngineState._get_symbol('dhsein')
dhsein.restype = None
dhsein.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, eigsrc(len=1).
    utils._BYREF_STRING, # Input, initv(len=1).
    utils._EngineLogicalArrayType.c_type, # Input/Output, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, h[ldh, *].
    utils._BYREF_INT, # Input, ldh.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Input, wi[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[(n+2)*n].
    utils._EngineIntArrayType.c_type, # Output, ifaill[*].
    utils._EngineIntArrayType.c_type, # Output, ifailr[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of eigsrc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of initv.
)
f08pkf = utils._EngineState._get_symbol('f08pkf')
f08pkf.restype = dhsein.restype
f08pkf.argtypes = dhsein.argtypes

zgees_select = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_COMPLEX128, # Input, w.
)
zgees = utils._EngineState._get_symbol('zgees')
zgees.restype = None
zgees.argtypes = (
    utils._BYREF_STRING, # Input, jobvs(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    zgees_select,
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineComplex128ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, vs[ldvs, *].
    utils._BYREF_INT, # Input, ldvs.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvs.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
)
f08pnf = utils._EngineState._get_symbol('f08pnf')
f08pnf.restype = zgees.restype
f08pnf.argtypes = zgees.argtypes

zgees_dummy_select = utils._EngineState._get_symbol('f08pnz')
zgees_dummy_select.restype = utils._EngineLogicalScalarType.c_type
zgees_dummy_select.argtypes = (
    utils._BYREF_COMPLEX128, # Input, w.
)

zgeesx_select = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_COMPLEX128, # Input, w.
)
zgeesx = utils._EngineState._get_symbol('zgeesx')
zgeesx.restype = None
zgeesx.argtypes = (
    utils._BYREF_STRING, # Input, jobvs(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    zgeesx_select,
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineComplex128ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Output, vs[ldvs, *].
    utils._BYREF_INT, # Input, ldvs.
    utils._BYREF_FLOAT64, # Output, rconde.
    utils._BYREF_FLOAT64, # Output, rcondv.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvs.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08ppf = utils._EngineState._get_symbol('f08ppf')
f08ppf.restype = zgeesx.restype
f08ppf.argtypes = zgeesx.argtypes

zhseqr = utils._EngineState._get_symbol('zhseqr')
zhseqr.restype = None
zhseqr.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, h[ldh, *].
    utils._BYREF_INT, # Input, ldh.
    utils._EngineComplex128ArrayType.c_type, # Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08psf = utils._EngineState._get_symbol('f08psf')
f08psf.restype = zhseqr.restype
f08psf.argtypes = zhseqr.argtypes

zhsein = utils._EngineState._get_symbol('zhsein')
zhsein.restype = None
zhsein.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, eigsrc(len=1).
    utils._BYREF_STRING, # Input, initv(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, h[ldh, *].
    utils._BYREF_INT, # Input, ldh.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, w[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._EngineIntArrayType.c_type, # Output, ifaill[*].
    utils._EngineIntArrayType.c_type, # Output, ifailr[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of eigsrc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of initv.
)
f08pxf = utils._EngineState._get_symbol('f08pxf')
f08pxf.restype = zhsein.restype
f08pxf.argtypes = zhsein.argtypes

dtrexc = utils._EngineState._get_symbol('dtrexc')
dtrexc.restype = None
dtrexc.argtypes = (
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._BYREF_INT, # Input/Output, ifst.
    utils._BYREF_INT, # Input/Output, ilst.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
)
f08qff = utils._EngineState._get_symbol('f08qff')
f08qff.restype = dtrexc.restype
f08qff.argtypes = dtrexc.argtypes

dtrsen = utils._EngineState._get_symbol('dtrsen')
dtrsen.restype = None
dtrsen.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Output, wr[*].
    utils._EngineFloat64ArrayType.c_type, # Output, wi[*].
    utils._BYREF_INT, # Output, m.
    utils._BYREF_FLOAT64, # Output, s.
    utils._BYREF_FLOAT64, # Output, sep.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
)
f08qgf = utils._EngineState._get_symbol('f08qgf')
f08qgf.restype = dtrsen.restype
f08qgf.argtypes = dtrsen.argtypes

dtrsyl = utils._EngineState._get_symbol('dtrsyl')
dtrsyl.restype = None
dtrsyl.argtypes = (
    utils._BYREF_STRING, # Input, trana(len=1).
    utils._BYREF_STRING, # Input, tranb(len=1).
    utils._BYREF_INT, # Input, isgn.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_FLOAT64, # Output, scale.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trana.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tranb.
)
f08qhf = utils._EngineState._get_symbol('f08qhf')
f08qhf.restype = dtrsyl.restype
f08qhf.argtypes = dtrsyl.argtypes

dtrevc = utils._EngineState._get_symbol('dtrevc')
dtrevc.restype = None
dtrevc.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input/Output, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08qkf = utils._EngineState._get_symbol('f08qkf')
f08qkf.restype = dtrevc.restype
f08qkf.argtypes = dtrevc.argtypes

dtrsna = utils._EngineState._get_symbol('dtrsna')
dtrsna.restype = None
dtrsna.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineFloat64ArrayType.c_type, # Input, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Input, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, sep[*].
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[ldwork, *].
    utils._BYREF_INT, # Input, ldwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08qlf = utils._EngineState._get_symbol('f08qlf')
f08qlf.restype = dtrsna.restype
f08qlf.argtypes = dtrsna.argtypes

ztrexc = utils._EngineState._get_symbol('ztrexc')
ztrexc.restype = None
ztrexc.argtypes = (
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._BYREF_INT, # Input, ifst.
    utils._BYREF_INT, # Input, ilst.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
)
f08qtf = utils._EngineState._get_symbol('f08qtf')
f08qtf.restype = ztrexc.restype
f08qtf.argtypes = ztrexc.argtypes

ztrsen = utils._EngineState._get_symbol('ztrsen')
ztrsen.restype = None
ztrsen.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Output, w[*].
    utils._BYREF_INT, # Output, m.
    utils._BYREF_FLOAT64, # Output, s.
    utils._BYREF_FLOAT64, # Output, sep.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
)
f08quf = utils._EngineState._get_symbol('f08quf')
f08quf.restype = ztrsen.restype
f08quf.argtypes = ztrsen.argtypes

ztrsyl = utils._EngineState._get_symbol('ztrsyl')
ztrsyl.restype = None
ztrsyl.argtypes = (
    utils._BYREF_STRING, # Input, trana(len=1).
    utils._BYREF_STRING, # Input, tranb(len=1).
    utils._BYREF_INT, # Input, isgn.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_FLOAT64, # Output, scal.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trana.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of tranb.
)
f08qvf = utils._EngineState._get_symbol('f08qvf')
f08qvf.restype = ztrsyl.restype
f08qvf.argtypes = ztrsyl.argtypes

ztrevc = utils._EngineState._get_symbol('ztrevc')
ztrevc.restype = None
ztrevc.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08qxf = utils._EngineState._get_symbol('f08qxf')
f08qxf.restype = ztrevc.restype
f08qxf.argtypes = ztrevc.argtypes

ztrsna = utils._EngineState._get_symbol('ztrsna')
ztrsna.restype = None
ztrsna.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, t[ldt, *].
    utils._BYREF_INT, # Input, ldt.
    utils._EngineComplex128ArrayType.c_type, # Input, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Input, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, sep[*].
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[ldwork, *].
    utils._BYREF_INT, # Input, ldwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08qyf = utils._EngineState._get_symbol('f08qyf')
f08qyf.restype = ztrsna.restype
f08qyf.argtypes = ztrsna.argtypes

dorcsd = utils._EngineState._get_symbol('dorcsd')
dorcsd.restype = None
dorcsd.argtypes = (
    utils._BYREF_STRING, # Input, jobu1(len=1).
    utils._BYREF_STRING, # Input, jobu2(len=1).
    utils._BYREF_STRING, # Input, jobv1t(len=1).
    utils._BYREF_STRING, # Input, jobv2t(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, signs(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, q.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x11[ldx11, *].
    utils._BYREF_INT, # Input, ldx11.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x12[ldx12, *].
    utils._BYREF_INT, # Input, ldx12.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x21[ldx21, *].
    utils._BYREF_INT, # Input, ldx21.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x22[ldx22, *].
    utils._BYREF_INT, # Input, ldx22.
    utils._EngineFloat64ArrayType.c_type, # Output, theta[min(p, m-p, q, m-q)].
    utils._EngineFloat64ArrayType.c_type, # Output, u1[ldu1, *].
    utils._BYREF_INT, # Input, ldu1.
    utils._EngineFloat64ArrayType.c_type, # Output, u2[ldu2, *].
    utils._BYREF_INT, # Input, ldu2.
    utils._EngineFloat64ArrayType.c_type, # Output, v1t[ldv1t, *].
    utils._BYREF_INT, # Input, ldv1t.
    utils._EngineFloat64ArrayType.c_type, # Output, v2t[ldv2t, *].
    utils._BYREF_INT, # Input, ldv2t.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[m-min(p, m-p, q, m-q)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu1.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu2.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv1t.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv2t.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of signs.
)
f08raf = utils._EngineState._get_symbol('f08raf')
f08raf.restype = dorcsd.restype
f08raf.argtypes = dorcsd.argtypes

zuncsd = utils._EngineState._get_symbol('zuncsd')
zuncsd.restype = None
zuncsd.argtypes = (
    utils._BYREF_STRING, # Input, jobu1(len=1).
    utils._BYREF_STRING, # Input, jobu2(len=1).
    utils._BYREF_STRING, # Input, jobv1t(len=1).
    utils._BYREF_STRING, # Input, jobv2t(len=1).
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_STRING, # Input, signs(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, q.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x11[ldx11, *].
    utils._BYREF_INT, # Input, ldx11.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x12[ldx12, *].
    utils._BYREF_INT, # Input, ldx12.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x21[ldx21, *].
    utils._BYREF_INT, # Input, ldx21.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x22[ldx22, *].
    utils._BYREF_INT, # Input, ldx22.
    utils._EngineFloat64ArrayType.c_type, # Output, theta[min(p, m-p, q, m-q)].
    utils._EngineComplex128ArrayType.c_type, # Output, u1[ldu1, *].
    utils._BYREF_INT, # Input, ldu1.
    utils._EngineComplex128ArrayType.c_type, # Output, u2[ldu2, *].
    utils._BYREF_INT, # Input, ldu2.
    utils._EngineComplex128ArrayType.c_type, # Output, v1t[ldv1t, *].
    utils._BYREF_INT, # Input, ldv1t.
    utils._EngineComplex128ArrayType.c_type, # Output, v2t[ldv2t, *].
    utils._BYREF_INT, # Input, ldv2t.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[m-min(p, m-p, q, m-q)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu1.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu2.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv1t.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv2t.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of signs.
)
f08rnf = utils._EngineState._get_symbol('f08rnf')
f08rnf.restype = zuncsd.restype
f08rnf.argtypes = zuncsd.argtypes

dsygv = utils._EngineState._get_symbol('dsygv')
dsygv.restype = None
dsygv.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08saf = utils._EngineState._get_symbol('f08saf')
f08saf.restype = dsygv.restype
f08saf.argtypes = dsygv.argtypes

dsygvx = utils._EngineState._get_symbol('dsygvx')
dsygvx.restype = None
dsygvx.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08sbf = utils._EngineState._get_symbol('f08sbf')
f08sbf.restype = dsygvx.restype
f08sbf.argtypes = dsygvx.argtypes

dsygvd = utils._EngineState._get_symbol('dsygvd')
dsygvd.restype = None
dsygvd.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08scf = utils._EngineState._get_symbol('f08scf')
f08scf.restype = dsygvd.restype
f08scf.argtypes = dsygvd.argtypes

dsygst = utils._EngineState._get_symbol('dsygst')
dsygst.restype = None
dsygst.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08sef = utils._EngineState._get_symbol('f08sef')
f08sef.restype = dsygst.restype
f08sef.argtypes = dsygst.argtypes

zhegv = utils._EngineState._get_symbol('zhegv')
zhegv.restype = None
zhegv.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[3*n-2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08snf = utils._EngineState._get_symbol('f08snf')
f08snf.restype = zhegv.restype
f08snf.argtypes = zhegv.argtypes

zhegvx = utils._EngineState._get_symbol('zhegvx')
zhegvx.restype = None
zhegvx.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08spf = utils._EngineState._get_symbol('f08spf')
f08spf.restype = zhegvx.restype
f08spf.argtypes = zhegvx.argtypes

zhegvd = utils._EngineState._get_symbol('zhegvd')
zhegvd.restype = None
zhegvd.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08sqf = utils._EngineState._get_symbol('f08sqf')
f08sqf.restype = zhegvd.restype
f08sqf.argtypes = zhegvd.argtypes

zhegst = utils._EngineState._get_symbol('zhegst')
zhegst.restype = None
zhegst.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08ssf = utils._EngineState._get_symbol('f08ssf')
f08ssf.restype = zhegst.restype
f08ssf.argtypes = zhegst.argtypes

dspgv = utils._EngineState._get_symbol('dspgv')
dspgv.restype = None
dspgv.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bp[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08taf = utils._EngineState._get_symbol('f08taf')
f08taf.restype = dspgv.restype
f08taf.argtypes = dspgv.argtypes

dspgvx = utils._EngineState._get_symbol('dspgvx')
dspgvx.restype = None
dspgvx.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bp[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[8*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tbf = utils._EngineState._get_symbol('f08tbf')
f08tbf.restype = dspgvx.restype
f08tbf.argtypes = dspgvx.argtypes

dspgvd = utils._EngineState._get_symbol('dspgvd')
dspgvd.restype = None
dspgvd.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bp[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tcf = utils._EngineState._get_symbol('f08tcf')
f08tcf.restype = dspgvd.restype
f08tcf.argtypes = dspgvd.argtypes

dspgst = utils._EngineState._get_symbol('dspgst')
dspgst.restype = None
dspgst.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineFloat64ArrayType.c_type, # Input, bp[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tef = utils._EngineState._get_symbol('f08tef')
f08tef.restype = dspgst.restype
f08tef.argtypes = dspgst.argtypes

zhpgv = utils._EngineState._get_symbol('zhpgv')
zhpgv.restype = None
zhpgv.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bp[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n-1].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[3*n-2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tnf = utils._EngineState._get_symbol('f08tnf')
f08tnf.restype = zhpgv.restype
f08tnf.argtypes = zhpgv.argtypes

zhpgvx = utils._EngineState._get_symbol('zhpgvx')
zhpgvx.restype = None
zhpgvx.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bp[*].
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tpf = utils._EngineState._get_symbol('f08tpf')
f08tpf.restype = zhpgvx.restype
f08tpf.argtypes = zhpgvx.argtypes

zhpgvd = utils._EngineState._get_symbol('zhpgvd')
zhpgvd.restype = None
zhpgvd.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bp[*].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tqf = utils._EngineState._get_symbol('f08tqf')
f08tqf.restype = zhpgvd.restype
f08tqf.argtypes = zhpgvd.argtypes

zhpgst = utils._EngineState._get_symbol('zhpgst')
zhpgst.restype = None
zhpgst.argtypes = (
    utils._BYREF_INT, # Input, itype.
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ap[*].
    utils._EngineComplex128ArrayType.c_type, # Input, bp[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08tsf = utils._EngineState._get_symbol('f08tsf')
f08tsf.restype = zhpgst.restype
f08tsf.argtypes = zhpgst.argtypes

dsbgv = utils._EngineState._get_symbol('dsbgv')
dsbgv.restype = None
dsbgv.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08uaf = utils._EngineState._get_symbol('f08uaf')
f08uaf.restype = dsbgv.restype
f08uaf.argtypes = dsbgv.argtypes

dsbgvx = utils._EngineState._get_symbol('dsbgvx')
dsbgvx.restype = None
dsbgvx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08ubf = utils._EngineState._get_symbol('f08ubf')
f08ubf.restype = dsbgvx.restype
f08ubf.argtypes = dsbgvx.argtypes

dsbgvd = utils._EngineState._get_symbol('dsbgvd')
dsbgvd.restype = None
dsbgvd.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08ucf = utils._EngineState._get_symbol('f08ucf')
f08ucf.restype = dsbgvd.restype
f08ucf.argtypes = dsbgvd.argtypes

dsbgst = utils._EngineState._get_symbol('dsbgst')
dsbgst.restype = None
dsbgst.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineFloat64ArrayType.c_type, # Input, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08uef = utils._EngineState._get_symbol('f08uef')
f08uef.restype = dsbgst.restype
f08uef.argtypes = dsbgst.argtypes

dpbstf = utils._EngineState._get_symbol('dpbstf')
dpbstf.restype = None
dpbstf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08uff = utils._EngineState._get_symbol('f08uff')
f08uff.restype = dpbstf.restype
f08uff.argtypes = dpbstf.argtypes

zhbgv = utils._EngineState._get_symbol('zhbgv')
zhbgv.restype = None
zhbgv.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[3*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08unf = utils._EngineState._get_symbol('f08unf')
f08unf.restype = zhbgv.restype
f08unf.argtypes = zhbgv.argtypes

zhbgvx = utils._EngineState._get_symbol('zhbgvx')
zhbgvx.restype = None
zhbgvx.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, range(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._BYREF_FLOAT64, # Input, vl.
    utils._BYREF_FLOAT64, # Input, vu.
    utils._BYREF_INT, # Input, il.
    utils._BYREF_INT, # Input, iu.
    utils._BYREF_FLOAT64, # Input, abstol.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[7*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[5*n].
    utils._EngineIntArrayType.c_type, # Output, jfail[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of range.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08upf = utils._EngineState._get_symbol('f08upf')
f08upf.restype = zhbgvx.restype
f08upf.argtypes = zhbgvx.argtypes

zhbgvd = utils._EngineState._get_symbol('zhbgvd')
zhbgvd.restype = None
zhbgvd.argtypes = (
    utils._BYREF_STRING, # Input, jobz(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._EngineComplex128ArrayType.c_type, # Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, lrwork)].
    utils._BYREF_INT, # Input, lrwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobz.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08uqf = utils._EngineState._get_symbol('f08uqf')
f08uqf.restype = zhbgvd.restype
f08uqf.argtypes = zhbgvd.argtypes

zhbgst = utils._EngineState._get_symbol('zhbgst')
zhbgst.restype = None
zhbgst.argtypes = (
    utils._BYREF_STRING, # Input, vect(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ka.
    utils._BYREF_INT, # Input, kb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ab[ldab, *].
    utils._BYREF_INT, # Input, ldab.
    utils._EngineComplex128ArrayType.c_type, # Input, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._EngineComplex128ArrayType.c_type, # Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of vect.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08usf = utils._EngineState._get_symbol('f08usf')
f08usf.restype = zhbgst.restype
f08usf.argtypes = zhbgst.argtypes

zpbstf = utils._EngineState._get_symbol('zpbstf')
zpbstf.restype = None
zpbstf.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, bb[ldbb, *].
    utils._BYREF_INT, # Input, ldbb.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f08utf = utils._EngineState._get_symbol('f08utf')
f08utf.restype = zpbstf.restype
f08utf.argtypes = zpbstf.argtypes

dggsvd = utils._EngineState._get_symbol('dggsvd')
dggsvd.restype = None
dggsvd.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(3*n, m, p)+n].
    utils._EngineIntArrayType.c_type, # Output, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vaf = utils._EngineState._get_symbol('f08vaf')
f08vaf.restype = dggsvd.restype
f08vaf.argtypes = dggsvd.argtypes

dggsvd3 = utils._EngineState._get_symbol('dggsvd3')
dggsvd3.restype = None
dggsvd3.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Output, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vcf = utils._EngineState._get_symbol('f08vcf')
f08vcf.restype = dggsvd3.restype
f08vcf.argtypes = dggsvd3.argtypes

dggsvp = utils._EngineState._get_symbol('dggsvp')
dggsvp.restype = None
dggsvp.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, tola.
    utils._BYREF_FLOAT64, # Input, tolb.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, tau[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(3*n, m, p)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vef = utils._EngineState._get_symbol('f08vef')
f08vef.restype = dggsvp.restype
f08vef.argtypes = dggsvp.argtypes

dggsvp3 = utils._EngineState._get_symbol('dggsvp3')
dggsvp3.restype = None
dggsvp3.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, tola.
    utils._BYREF_FLOAT64, # Input, tolb.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineFloat64ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, tau[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vgf = utils._EngineState._get_symbol('f08vgf')
f08vgf.restype = dggsvp3.restype
f08vgf.argtypes = dggsvp3.argtypes

zggsvd = utils._EngineState._get_symbol('zggsvd')
zggsvd.restype = None
zggsvd.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(3*n, m, p)+n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._EngineIntArrayType.c_type, # Output, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vnf = utils._EngineState._get_symbol('f08vnf')
f08vnf.restype = zggsvd.restype
f08vnf.argtypes = zggsvd.argtypes

zggsvd3 = utils._EngineState._get_symbol('zggsvd3')
zggsvd3.restype = None
zggsvd3.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._EngineIntArrayType.c_type, # Output, iwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vqf = utils._EngineState._get_symbol('f08vqf')
f08vqf.restype = zggsvd3.restype
f08vqf.argtypes = zggsvd3.argtypes

zggsvp = utils._EngineState._get_symbol('zggsvp')
zggsvp.restype = None
zggsvp.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, tola.
    utils._BYREF_FLOAT64, # Input, tolb.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, tau[n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(3*n, m, p)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vsf = utils._EngineState._get_symbol('f08vsf')
f08vsf.restype = zggsvp.restype
f08vsf.argtypes = zggsvp.argtypes

zggsvp3 = utils._EngineState._get_symbol('zggsvp3')
zggsvp3.restype = None
zggsvp3.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, tola.
    utils._BYREF_FLOAT64, # Input, tolb.
    utils._BYREF_INT, # Output, k.
    utils._BYREF_INT, # Output, l.
    utils._EngineComplex128ArrayType.c_type, # Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, tau[n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08vuf = utils._EngineState._get_symbol('f08vuf')
f08vuf.restype = zggsvp3.restype
f08vuf.argtypes = zggsvp3.argtypes

dggev = utils._EngineState._get_symbol('dggev')
dggev.restype = None
dggev.argtypes = (
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)
f08waf = utils._EngineState._get_symbol('f08waf')
f08waf.restype = dggev.restype
f08waf.argtypes = dggev.argtypes

dggevx = utils._EngineState._get_symbol('dggevx')
dggevx.restype = None
dggevx.argtypes = (
    utils._BYREF_STRING, # Input, balanc(len=1).
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, lscale[n].
    utils._EngineFloat64ArrayType.c_type, # Output, rscale[n].
    utils._BYREF_FLOAT64, # Output, abnrm.
    utils._BYREF_FLOAT64, # Output, bbnrm.
    utils._EngineFloat64ArrayType.c_type, # Output, rconde[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rcondv[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of balanc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08wbf = utils._EngineState._get_symbol('f08wbf')
f08wbf.restype = dggevx.restype
f08wbf.argtypes = dggevx.argtypes

dggev3 = utils._EngineState._get_symbol('dggev3')
dggev3.restype = None
dggev3.argtypes = (
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)
f08wcf = utils._EngineState._get_symbol('f08wcf')
f08wcf.restype = dggev3.restype
f08wcf.argtypes = dggev3.argtypes

dgghrd = utils._EngineState._get_symbol('dgghrd')
dgghrd.restype = None
dgghrd.argtypes = (
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08wef = utils._EngineState._get_symbol('f08wef')
f08wef.restype = dgghrd.restype
f08wef.argtypes = dgghrd.argtypes

dgghd3 = utils._EngineState._get_symbol('dgghd3')
dgghd3.restype = None
dgghd3.argtypes = (
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08wff = utils._EngineState._get_symbol('f08wff')
f08wff.restype = dgghd3.restype
f08wff.argtypes = dgghd3.argtypes

dggbal = utils._EngineState._get_symbol('dggbal')
dggbal.restype = None
dggbal.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, lscale[n].
    utils._EngineFloat64ArrayType.c_type, # Output, rscale[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
f08whf = utils._EngineState._get_symbol('f08whf')
f08whf.restype = dggbal.restype
f08whf.argtypes = dggbal.argtypes

dggbak = utils._EngineState._get_symbol('dggbak')
dggbak.restype = None
dggbak.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input, lscale[*].
    utils._EngineFloat64ArrayType.c_type, # Input, rscale[*].
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)
f08wjf = utils._EngineState._get_symbol('f08wjf')
f08wjf.restype = dggbak.restype
f08wjf.argtypes = dggbak.argtypes

zggev = utils._EngineState._get_symbol('zggev')
zggev.restype = None
zggev.argtypes = (
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, 8*n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)
f08wnf = utils._EngineState._get_symbol('f08wnf')
f08wnf.restype = zggev.restype
f08wnf.argtypes = zggev.argtypes

zggevx = utils._EngineState._get_symbol('zggevx')
zggevx.restype = None
zggevx.argtypes = (
    utils._BYREF_STRING, # Input, balanc(len=1).
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, lscale[n].
    utils._EngineFloat64ArrayType.c_type, # Output, rscale[n].
    utils._BYREF_FLOAT64, # Output, abnrm.
    utils._BYREF_FLOAT64, # Output, bbnrm.
    utils._EngineFloat64ArrayType.c_type, # Output, rconde[*].
    utils._EngineFloat64ArrayType.c_type, # Output, rcondv[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[6*n].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of balanc.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08wpf = utils._EngineState._get_symbol('f08wpf')
f08wpf.restype = zggevx.restype
f08wpf.argtypes = zggevx.argtypes

zggev3 = utils._EngineState._get_symbol('zggev3')
zggev3.restype = None
zggev3.argtypes = (
    utils._BYREF_STRING, # Input, jobvl(len=1).
    utils._BYREF_STRING, # Input, jobvr(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, 8*n)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvr.
)
f08wqf = utils._EngineState._get_symbol('f08wqf')
f08wqf.restype = zggev3.restype
f08wqf.argtypes = zggev3.argtypes

zgghrd = utils._EngineState._get_symbol('zgghrd')
zgghrd.restype = None
zgghrd.argtypes = (
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08wsf = utils._EngineState._get_symbol('f08wsf')
f08wsf.restype = zgghrd.restype
f08wsf.argtypes = zgghrd.argtypes

zgghd3 = utils._EngineState._get_symbol('zgghd3')
zgghd3.restype = None
zgghd3.argtypes = (
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08wtf = utils._EngineState._get_symbol('f08wtf')
f08wtf.restype = zgghd3.restype
f08wtf.argtypes = zgghd3.argtypes

zggbal = utils._EngineState._get_symbol('zggbal')
zggbal.restype = None
zggbal.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, ilo.
    utils._BYREF_INT, # Output, ihi.
    utils._EngineFloat64ArrayType.c_type, # Output, lscale[n].
    utils._EngineFloat64ArrayType.c_type, # Output, rscale[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[6*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
f08wvf = utils._EngineState._get_symbol('f08wvf')
f08wvf.restype = zggbal.restype
f08wvf.argtypes = zggbal.argtypes

zggbak = utils._EngineState._get_symbol('zggbak')
zggbak.restype = None
zggbak.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input, lscale[*].
    utils._EngineFloat64ArrayType.c_type, # Input, rscale[*].
    utils._BYREF_INT, # Input, m.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
)
f08wwf = utils._EngineState._get_symbol('f08wwf')
f08wwf.restype = zggbak.restype
f08wwf.argtypes = zggbak.argtypes

dgges_selctg = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, ar.
    utils._BYREF_FLOAT64, # Input, ai.
    utils._BYREF_FLOAT64, # Input, b.
)
dgges = utils._EngineState._get_symbol('dgges')
dgges.restype = None
dgges.argtypes = (
    utils._BYREF_STRING, # Input, jobvsl(len=1).
    utils._BYREF_STRING, # Input, jobvsr(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    dgges_selctg,
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vsl[ldvsl, *].
    utils._BYREF_INT, # Input, ldvsl.
    utils._EngineFloat64ArrayType.c_type, # Output, vsr[ldvsr, *].
    utils._BYREF_INT, # Input, ldvsr.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
)
f08xaf = utils._EngineState._get_symbol('f08xaf')
f08xaf.restype = dgges.restype
f08xaf.argtypes = dgges.argtypes

dgges_dummy_selctg = utils._EngineState._get_symbol('f08xaz')
dgges_dummy_selctg.restype = utils._EngineLogicalScalarType.c_type
dgges_dummy_selctg.argtypes = (
    utils._BYREF_FLOAT64, # Input, ar.
    utils._BYREF_FLOAT64, # Input, ai.
    utils._BYREF_FLOAT64, # Input, b.
)

dggesx_selctg = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, ar.
    utils._BYREF_FLOAT64, # Input, ai.
    utils._BYREF_FLOAT64, # Input, b.
)
dggesx = utils._EngineState._get_symbol('dggesx')
dggesx.restype = None
dggesx.argtypes = (
    utils._BYREF_STRING, # Input, jobvsl(len=1).
    utils._BYREF_STRING, # Input, jobvsr(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    dggesx_selctg,
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vsl[ldvsl, *].
    utils._BYREF_INT, # Input, ldvsl.
    utils._EngineFloat64ArrayType.c_type, # Output, vsr[ldvsr, *].
    utils._BYREF_INT, # Input, ldvsr.
    utils._EngineFloat64ArrayType.c_type, # Output, rconde[2].
    utils._EngineFloat64ArrayType.c_type, # Output, rcondv[2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08xbf = utils._EngineState._get_symbol('f08xbf')
f08xbf.restype = dggesx.restype
f08xbf.argtypes = dggesx.argtypes

dgges3_selctg = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_FLOAT64, # Input, ar.
    utils._BYREF_FLOAT64, # Input, ai.
    utils._BYREF_FLOAT64, # Input, b.
)
dgges3 = utils._EngineState._get_symbol('dgges3')
dgges3.restype = None
dgges3.argtypes = (
    utils._BYREF_STRING, # Input, jobvsl(len=1).
    utils._BYREF_STRING, # Input, jobvsr(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    dgges3_selctg,
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Output, vsl[ldvsl, *].
    utils._BYREF_INT, # Input, ldvsl.
    utils._EngineFloat64ArrayType.c_type, # Output, vsr[ldvsr, *].
    utils._BYREF_INT, # Input, ldvsr.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
)
f08xcf = utils._EngineState._get_symbol('f08xcf')
f08xcf.restype = dgges3.restype
f08xcf.argtypes = dgges3.argtypes

dhgeqz = utils._EngineState._get_symbol('dhgeqz')
dhgeqz.restype = None
dhgeqz.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08xef = utils._EngineState._get_symbol('f08xef')
f08xef.restype = dhgeqz.restype
f08xef.argtypes = dhgeqz.argtypes

zgges_selctg = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_COMPLEX128, # Input, a.
    utils._BYREF_COMPLEX128, # Input, b.
)
zgges = utils._EngineState._get_symbol('zgges')
zgges.restype = None
zgges.argtypes = (
    utils._BYREF_STRING, # Input, jobvsl(len=1).
    utils._BYREF_STRING, # Input, jobvsr(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    zgges_selctg,
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, vsl[ldvsl, *].
    utils._BYREF_INT, # Input, ldvsl.
    utils._EngineComplex128ArrayType.c_type, # Output, vsr[ldvsr, *].
    utils._BYREF_INT, # Input, ldvsr.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, 8*n)].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
)
f08xnf = utils._EngineState._get_symbol('f08xnf')
f08xnf.restype = zgges.restype
f08xnf.argtypes = zgges.argtypes

zgges_dummy_selctg = utils._EngineState._get_symbol('f08xnz')
zgges_dummy_selctg.restype = utils._EngineLogicalScalarType.c_type
zgges_dummy_selctg.argtypes = (
    utils._BYREF_COMPLEX128, # Input, a.
    utils._BYREF_COMPLEX128, # Input, b.
)

zggesx_selctg = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_COMPLEX128, # Input, a.
    utils._BYREF_COMPLEX128, # Input, b.
)
zggesx = utils._EngineState._get_symbol('zggesx')
zggesx.restype = None
zggesx.argtypes = (
    utils._BYREF_STRING, # Input, jobvsl(len=1).
    utils._BYREF_STRING, # Input, jobvsr(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    zggesx_selctg,
    utils._BYREF_STRING, # Input, sense(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, vsl[ldvsl, *].
    utils._BYREF_INT, # Input, ldvsl.
    utils._EngineComplex128ArrayType.c_type, # Output, vsr[ldvsr, *].
    utils._BYREF_INT, # Input, ldvsr.
    utils._EngineFloat64ArrayType.c_type, # Output, rconde[2].
    utils._EngineFloat64ArrayType.c_type, # Output, rcondv[2].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, 8*n)].
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sense.
)
f08xpf = utils._EngineState._get_symbol('f08xpf')
f08xpf.restype = zggesx.restype
f08xpf.argtypes = zggesx.argtypes

zgges3_selctg = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_COMPLEX128, # Input, a.
    utils._BYREF_COMPLEX128, # Input, b.
)
zgges3 = utils._EngineState._get_symbol('zgges3')
zgges3.restype = None
zgges3.argtypes = (
    utils._BYREF_STRING, # Input, jobvsl(len=1).
    utils._BYREF_STRING, # Input, jobvsr(len=1).
    utils._BYREF_STRING, # Input, sort(len=1).
    zgges3_selctg,
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Output, sdim.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Output, vsl[ldvsl, *].
    utils._BYREF_INT, # Input, ldvsl.
    utils._EngineComplex128ArrayType.c_type, # Output, vsr[ldvsr, *].
    utils._BYREF_INT, # Input, ldvsr.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[max(1, 8*n)].
    utils._EngineLogicalArrayType.c_type, # Workspace, bwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsl.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobvsr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of sort.
)
f08xqf = utils._EngineState._get_symbol('f08xqf')
f08xqf.restype = zgges3.restype
f08xqf.argtypes = zgges3.argtypes

zhgeqz = utils._EngineState._get_symbol('zhgeqz')
zhgeqz.restype = None
zhgeqz.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, compq(len=1).
    utils._BYREF_STRING, # Input, compz(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ilo.
    utils._BYREF_INT, # Input, ihi.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compq.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of compz.
)
f08xsf = utils._EngineState._get_symbol('f08xsf')
f08xsf.restype = zhgeqz.restype
f08xsf.argtypes = zhgeqz.argtypes

dtgsja = utils._EngineState._get_symbol('dtgsja')
dtgsja.restype = None
dtgsja.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, l.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, tola.
    utils._BYREF_FLOAT64, # Input, tolb.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, ncycle.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08yef = utils._EngineState._get_symbol('f08yef')
f08yef.restype = dtgsja.restype
f08yef.argtypes = dtgsja.argtypes

dtgexc = utils._EngineState._get_symbol('dtgexc')
dtgexc.restype = None
dtgexc.argtypes = (
    utils._BYREF_LOGICAL, # Input, wantq.
    utils._BYREF_LOGICAL, # Input, wantz.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Input/Output, ifst.
    utils._BYREF_INT, # Input/Output, ilst.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08yff = utils._EngineState._get_symbol('f08yff')
f08yff.restype = dtgexc.restype
f08yff.argtypes = dtgexc.argtypes

dtgsen = utils._EngineState._get_symbol('dtgsen')
dtgsen.restype = None
dtgsen.argtypes = (
    utils._BYREF_INT, # Input, ijob.
    utils._BYREF_LOGICAL, # Input, wantq.
    utils._BYREF_LOGICAL, # Input, wantz.
    utils._EngineLogicalArrayType.c_type, # Input, select[n].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, alphar[n].
    utils._EngineFloat64ArrayType.c_type, # Output, alphai[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Output, m.
    utils._BYREF_FLOAT64, # Output, pl.
    utils._BYREF_FLOAT64, # Output, pr.
    utils._EngineFloat64ArrayType.c_type, # Output, dif[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
)
f08ygf = utils._EngineState._get_symbol('f08ygf')
f08ygf.restype = dtgsen.restype
f08ygf.argtypes = dtgsen.argtypes

dtgsyl = utils._EngineState._get_symbol('dtgsyl')
dtgsyl.restype = None
dtgsyl.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, ijob.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Input, d[ldd, *].
    utils._BYREF_INT, # Input, ldd.
    utils._EngineFloat64ArrayType.c_type, # Input, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, f[ldf, *].
    utils._BYREF_INT, # Input, ldf.
    utils._BYREF_FLOAT64, # Output, scale.
    utils._BYREF_FLOAT64, # Output, dif.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, m+n+6)].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08yhf = utils._EngineState._get_symbol('f08yhf')
f08yhf.restype = dtgsyl.restype
f08yhf.argtypes = dtgsyl.argtypes

dtgevc = utils._EngineState._get_symbol('dtgevc')
dtgevc.restype = None
dtgevc.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[6*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08ykf = utils._EngineState._get_symbol('f08ykf')
f08ykf.restype = dtgevc.restype
f08ykf.argtypes = dtgevc.argtypes

dtgsna = utils._EngineState._get_symbol('dtgsna')
dtgsna.restype = None
dtgsna.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineFloat64ArrayType.c_type, # Input, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, dif[*].
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08ylf = utils._EngineState._get_symbol('f08ylf')
f08ylf.restype = dtgsna.restype
f08ylf.argtypes = dtgsna.argtypes

ztgsja = utils._EngineState._get_symbol('ztgsja')
ztgsja.restype = None
ztgsja.argtypes = (
    utils._BYREF_STRING, # Input, jobu(len=1).
    utils._BYREF_STRING, # Input, jobv(len=1).
    utils._BYREF_STRING, # Input, jobq(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._BYREF_INT, # Input, l.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, tola.
    utils._BYREF_FLOAT64, # Input, tolb.
    utils._EngineFloat64ArrayType.c_type, # Output, alpha[n].
    utils._EngineFloat64ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, u[ldu, *].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, v[ldv, *].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._BYREF_INT, # Output, ncycle.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobu.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobv.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of jobq.
)
f08ysf = utils._EngineState._get_symbol('f08ysf')
f08ysf.restype = ztgsja.restype
f08ysf.argtypes = ztgsja.argtypes

ztgexc = utils._EngineState._get_symbol('ztgexc')
ztgexc.restype = None
ztgexc.argtypes = (
    utils._BYREF_LOGICAL, # Input, wantq.
    utils._BYREF_LOGICAL, # Input, wantz.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Input, ifst.
    utils._BYREF_INT, # Input/Output, ilst.
    utils._BYREF_INT, # Output, info.
)
f08ytf = utils._EngineState._get_symbol('f08ytf')
f08ytf.restype = ztgexc.restype
f08ytf.argtypes = ztgexc.argtypes

ztgsen = utils._EngineState._get_symbol('ztgsen')
ztgsen.restype = None
ztgsen.argtypes = (
    utils._BYREF_INT, # Input, ijob.
    utils._BYREF_LOGICAL, # Input, wantq.
    utils._BYREF_LOGICAL, # Input, wantz.
    utils._EngineLogicalArrayType.c_type, # Input, select[n].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, alpha[n].
    utils._EngineComplex128ArrayType.c_type, # Output, beta[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, q[ldq, *].
    utils._BYREF_INT, # Input, ldq.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[ldz, *].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Output, m.
    utils._BYREF_FLOAT64, # Output, pl.
    utils._BYREF_FLOAT64, # Output, pr.
    utils._EngineFloat64ArrayType.c_type, # Output, dif[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[max(1, liwork)].
    utils._BYREF_INT, # Input, liwork.
    utils._BYREF_INT, # Output, info.
)
f08yuf = utils._EngineState._get_symbol('f08yuf')
f08yuf.restype = ztgsen.restype
f08yuf.argtypes = ztgsen.argtypes

ztgsyl = utils._EngineState._get_symbol('ztgsyl')
ztgsyl.restype = None
ztgsyl.argtypes = (
    utils._BYREF_STRING, # Input, trans(len=1).
    utils._BYREF_INT, # Input, ijob.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineComplex128ArrayType.c_type, # Input, d[ldd, *].
    utils._BYREF_INT, # Input, ldd.
    utils._EngineComplex128ArrayType.c_type, # Input, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, f[ldf, *].
    utils._BYREF_INT, # Input, ldf.
    utils._BYREF_FLOAT64, # Output, scale.
    utils._BYREF_FLOAT64, # Output, dif.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[m+n+2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of trans.
)
f08yvf = utils._EngineState._get_symbol('f08yvf')
f08yvf.restype = ztgsyl.restype
f08yvf.argtypes = ztgsyl.argtypes

ztgevc = utils._EngineState._get_symbol('ztgevc')
ztgevc.restype = None
ztgevc.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[2*n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, rwork[2*n].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08yxf = utils._EngineState._get_symbol('f08yxf')
f08yxf.restype = ztgevc.restype
f08yxf.argtypes = ztgevc.argtypes

ztgsna = utils._EngineState._get_symbol('ztgsna')
ztgsna.restype = None
ztgsna.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, howmny(len=1).
    utils._EngineLogicalArrayType.c_type, # Input, select[*].
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input, vl[ldvl, *].
    utils._BYREF_INT, # Input, ldvl.
    utils._EngineComplex128ArrayType.c_type, # Input, vr[ldvr, *].
    utils._BYREF_INT, # Input, ldvr.
    utils._EngineFloat64ArrayType.c_type, # Output, s[*].
    utils._EngineFloat64ArrayType.c_type, # Output, dif[*].
    utils._BYREF_INT, # Input, mm.
    utils._BYREF_INT, # Output, m.
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._EngineIntArrayType.c_type, # Workspace, iwork[*].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of howmny.
)
f08yyf = utils._EngineState._get_symbol('f08yyf')
f08yyf.restype = ztgsna.restype
f08yyf.argtypes = ztgsna.argtypes

dgglse = utils._EngineState._get_symbol('dgglse')
dgglse.restype = None
dgglse.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[m].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[p].
    utils._EngineFloat64ArrayType.c_type, # Output, x[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08zaf = utils._EngineState._get_symbol('f08zaf')
f08zaf.restype = dgglse.restype
f08zaf.argtypes = dgglse.argtypes

dggglm = utils._EngineState._get_symbol('dggglm')
dggglm.restype = None
dggglm.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[m].
    utils._EngineFloat64ArrayType.c_type, # Output, x[n].
    utils._EngineFloat64ArrayType.c_type, # Output, y[p].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08zbf = utils._EngineState._get_symbol('f08zbf')
f08zbf.restype = dggglm.restype
f08zbf.argtypes = dggglm.argtypes

dggqrf = utils._EngineState._get_symbol('dggqrf')
dggqrf.restype = None
dggqrf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, taua[min(n, m)].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, taub[min(n, p)].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08zef = utils._EngineState._get_symbol('f08zef')
f08zef.restype = dggqrf.restype
f08zef.argtypes = dggqrf.argtypes

dggrqf = utils._EngineState._get_symbol('dggrqf')
dggrqf.restype = None
dggrqf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, taua[min(m, n)].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, taub[min(p, n)].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08zff = utils._EngineState._get_symbol('f08zff')
f08zff.restype = dggrqf.restype
f08zff.argtypes = dggrqf.argtypes

zgglse = utils._EngineState._get_symbol('zgglse')
zgglse.restype = None
zgglse.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, c[m].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, d[p].
    utils._EngineComplex128ArrayType.c_type, # Output, x[n].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08znf = utils._EngineState._get_symbol('f08znf')
f08znf.restype = zgglse.restype
f08znf.argtypes = zgglse.argtypes

zggglm = utils._EngineState._get_symbol('zggglm')
zggglm.restype = None
zggglm.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, d[m].
    utils._EngineComplex128ArrayType.c_type, # Output, x[n].
    utils._EngineComplex128ArrayType.c_type, # Output, y[p].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08zpf = utils._EngineState._get_symbol('f08zpf')
f08zpf.restype = zggglm.restype
f08zpf.argtypes = zggglm.argtypes

zggqrf = utils._EngineState._get_symbol('zggqrf')
zggqrf.restype = None
zggqrf.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, taua[min(n, m)].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, taub[min(n, p)].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08zsf = utils._EngineState._get_symbol('f08zsf')
f08zsf.restype = zggqrf.restype
f08zsf.argtypes = zggqrf.argtypes

zggrqf = utils._EngineState._get_symbol('zggrqf')
zggrqf.restype = None
zggrqf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, taua[min(m, n)].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, taub[min(p, n)].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(1, lwork)].
    utils._BYREF_INT, # Input, lwork.
    utils._BYREF_INT, # Output, info.
)
f08ztf = utils._EngineState._get_symbol('f08ztf')
f08ztf.restype = zggrqf.restype
f08ztf.argtypes = zggrqf.argtypes
